import contextlib

import construct
import pytest

from mercury_engine_data_structures.formats.bcmdl import BCMDL, Bcmdl
from mercury_engine_data_structures.game_check import Game
from test.test_lib import parse_and_build_compare, parse_build_compare_editor

ALL_BCMDL_NO_TOC9 = [
	"system/minimap/maproom/s010_cave/s010_cave.bcmdl",
	"system/minimap/maproom/s020_magma/s020_magma.bcmdl",
	"system/minimap/maproom/s030_baselab/s030_baselab.bcmdl",
	"system/minimap/maproom/s040_aqua/s040_aqua.bcmdl",
	"system/minimap/maproom/s050_forest/s050_forest.bcmdl",
	"system/minimap/maproom/s060_quarantine/s060_quarantine.bcmdl",
	"system/minimap/maproom/s070_basesanc/s070_basesanc.bcmdl",
	"system/minimap/maproom/s080_shipyard/s080_shipyard.bcmdl",
	"system/minimap/maproom/s090_skybase/s090_skybase.bcmdl",
	"maps/objects/savestation001/savestation001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel14.bcmdl",
	"actors/props/samuship_int/models/samusship_int.bcmdl",
	"maps/objects/maproom001/maproom001.bcmdl",
	"maps/objects/communicationroombg/communicationroombg.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o4_mapmodel00.bcmdl",
	"actors/props/cut_57_statuebroken/models/cut_57_statuebroken.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel065.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel008.bcmdl",
	"actors/characters/chozocommander/models/chozocommander.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel028.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel10.bcmdl",
	"actors/characters/emmycave/models/emmycave.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel050.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_19.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel063.bcmdl",
	"actors/props/ev_piston_cv_001/models/ev_piston_cv_001.bcmdl",
	"maps/objects/communicationroombgcam/communicationroombgcam.bcmdl",
	"actors/props/ev_scorpiusstatue_end/models/ev_scorpiusstatue_end.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel05.bcmdl",
	"actors/props/samus_ship_b/models/samus_ship_b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_010.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel06.bcmdl",
	"actors/characters/scorpius/models/scorpius.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel10.bcmdl",
	"actors/props/scostatuefull_cut54/models/scostatuefull_cut54.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel010.bcmdl",
	"actors/props/cut_54_scorpiusstatue/models/cut_54_scorpiusstatue.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_18.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel00.bcmdl",
	"actors/props/breakablecave014/models/breakablecave014.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel022.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel07.bcmdl",
	"actors/props/elevator/models/elevator.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_007.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel053.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_09.bcmdl",
	"actors/characters/emmyproto/models/emmyproto.bcmdl",
	"actors/props/ev_chainreaction_cv_001_b/models/ev_chainreaction_cv_001_b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel04.bcmdl",
	"actors/props/ev_chainreaction_cv_011/models/ev_chainreaction_cv_011.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel01.bcmdl",
	"maps/objects/centralunitnest/centralunitnest.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel056.bcmdl",
	"actors/characters/scorpius/fx/maskregenerate.bcmdl",
	"actors/characters/scorpius/fx/scorpiusmask.bcmdl",
	"actors/items/item_cube_broken/model/itemcube_broken.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_11.bcmdl",
	"actors/props/accesspoint/models/accesspoint.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel08.bcmdl",
	"actors/props/cut_01_bridge/models/cut_01_bridge.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel08.bcmdl",
	"actors/props/planetzdr/models/planetzdr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel012.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_21.bcmdl",
	"actors/characters/samus_facial/models/cut_samusfacial.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_012.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel011.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_11.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_005.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel13.bcmdl",
	"maps/objects/chozocavespcooldownbg01_a/chozocavespcooldownbg01_a.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel025.bcmdl",
	"actors/props/scostatuertop_cut57/models/scostatuertop_cut57.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel22.bcmdl",
	"actors/props/breakablecave008/models/breakablecave008.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_19.bcmdl",
	"maps/objects/communicationroom4door/communicationroom4door.bcmdl",
	"actors/props/db_reg_cv_020/models/db_reg_cv_020.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel00.bcmdl",
	"maps/objects/communicationroom2door/communicationroom2door.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel038.bcmdl",
	"maps/objects/chozocavechaincolumn01/chozocavechaincolumn01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_05.bcmdl",
	"actors/props/db_reg_cv_021/models/db_reg_cv_021.bcmdl",
	"maps/objects/chozocorridormag02/chozocorridormag02.bcmdl",
	"maps/objects/cavartifactorstatue/cavartifactorstatue.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part007_e6_mapmodel00.bcmdl",
	"actors/props/savestation/models/savestation.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel042.bcmdl",
	"actors/props/maproom/models/maproom.bcmdl",
	"actors/props/doorchargecharge/models/doorchargecharge.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_20.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel07.bcmdl",
	"actors/props/platformcavewaterb/models/platformcavewaterb.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_medio00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_floor.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_vignette01.bcmdl",
	"actors/props/ev_chainreaction_cv_001/models/ev_chainreaction_cv_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel03.bcmdl",
	"actors/characters/centralunitcave/models/centralunitcave.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel033.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_05.bcmdl",
	"actors/props/door_frblack_protoemmy/models/door_frblack_protoemmy.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_000.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_003.bcmdl",
	"actors/props/breakablecave017/models/breakablecave017.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_04.bcmdl",
	"actors/characters/centralunitcave/models/centralunitcavebroken.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel067.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mapmodel_04.bcmdl",
	"maps/objects/chozomagbgwall01corner/chozomagbgwall01corner.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_tunel_00.bcmdl",
	"actors/props/breakablecave007/models/breakablecave007.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pipes_001.bcmdl",
	"actors/props/breakablecave003/models/breakablecave003.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel049.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel20.bcmdl",
	"actors/props/cutmodel49wall04/models/cutmodel49wall04.bcmdl",
	"cutscenes/0036enteremmyzone/fx/door_frblack_gen.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel02.bcmdl",
	"actors/props/doorclosedcharge/models/doorclosedcharge.bcmdl",
	"actors/props/doorchargeclosed/models/doorchargeclosed.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_00.bcmdl",
	"actors/props/door_frblack_gen/models/door_frblack_gen.bcmdl",
	"actors/props/gobblerweb/models/gobblerweb.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_002.bcmdl",
	"maps/objects/chozoallasset05/chozoallasset05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_15.bcmdl",
	"actors/props/grapplepulloff1x2/fx/destruction_l.bcmdl",
	"actors/props/grapplepulloff1x2/fx/destruction_r.bcmdl",
	"actors/props/totalrechargestation/models/totalrechargestation.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_004.bcmdl",
	"actors/props/ammorecharge/models/ammorecharge.bcmdl",
	"actors/props/breakablecave010/models/breakablecave010.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel064.bcmdl",
	"actors/props/ev_chainreaction_cv_001_a/models/ev_chainreaction_cv_001_a.bcmdl",
	"maps/objects/chozomagasset07/chozomagasset07.bcmdl",
	"actors/props/breakablecave002/models/breakablecave002.bcmdl",
	"actors/props/breakablecave020/models/breakablecave020.bcmdl",
	"maps/objects/cavcolumcrystal01/cavcolumcrystal01.bcmdl",
	"maps/objects/chozoadornemmylab_01/chozoadornemmylab_01.bcmdl",
	"maps/objects/rain01/rain01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel15.bcmdl",
	"actors/props/breakablecave018/models/breakablecave018.bcmdl",
	"actors/props/doorwavebeam/models/doorwavebeam.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel19.bcmdl",
	"actors/props/door_shield_plasma/models/doorshieldplasma.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel25.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_11.bcmdl",
	"actors/props/db_reg_cv_022/models/db_reg_cv_022.bcmdl",
	"actors/props/breakablecave006/models/breakablecave006.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel07.bcmdl",
	"actors/fx/accesspoint01/fx/accesspoint01.bcmdl",
	"actors/props/ev_chainreaction_cv_004_a/models/ev_chainreaction_cv_004_a.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_middle01.bcmdl",
	"maps/objects/chozocavejoint/chozocavejoint.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_chozopathemmy01v301.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_o5_mapmodel00.bcmdl",
	"actors/props/energyrecharge/models/energyrecharge.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_10.bcmdl",
	"actors/props/cut_37_wallend01/models/cut_37_wallend01.bcmdl",
	"actors/props/box_wide_cv_001/models/box_wide_cv_001.bcmdl",
	"maps/objects/chozoroomcolumn01/chozoroomcolumn01.bcmdl",
	"maps/objects/chozocavefilter01/chozocavefilter01.bcmdl",
	"actors/props/cave_elevator/models/cave_elevator.bcmdl",
	"maps/objects/cavecolumcrystal05/cavecolumcrystal05.bcmdl",
	"actors/props/ev_chainreaction_cv_010_b/models/ev_chainreaction_cv_010_b.bcmdl",
	"maps/objects/chozoallwall02x4/chozoallwall02x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_middle02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_mapmodel03.bcmdl",
	"maps/objects/chozocavspecial01/chozocavspecial01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_16.bcmdl",
	"actors/props/breakablecave016/models/breakablecave016.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_17.bcmdl",
	"maps/objects/chozocolmag01/chozocolmag01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_006.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_23.bcmdl",
	"cutscenes/0001gameintro_fight/fx/shootinggrab_zerolaser.bcmdl",
	"actors/characters/chozocommander_arm/models/chozocommander_arm_skybase.bcmdl",
	"actors/props/dooremmy/models/dooremmy.bcmdl",
	"actors/events/mapev_scorpiustail/models/mapev_scorpiustail.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel12.bcmdl",
	"maps/objects/chozoallassetbottleplat03/chozoallassetbottleplat03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilar1_rh_001_new.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_cut01.bcmdl",
	"maps/objects/chozobgairfan01_a/chozobgairfan01_a.bcmdl",
	"maps/objects/chozobgairfan01_c/chozobgairfan01_c.bcmdl",
	"maps/objects/shipyardrock02/shipyardrock02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilar1_lh_001.bcmdl",
	"cutscenes/0001gameintro_fight/fx/energy_wavety.bcmdl",
	"maps/objects/chozobgairfan01_b/chozobgairfan01_b.bcmdl",
	"maps/objects/chozobgairfan01_d/chozobgairfan01_d.bcmdl",
	"maps/objects/chozocorridormag01/chozocorridormag01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part004_o6_matte.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel27.bcmdl",
	"maps/objects/chozoadornemmy01/chozoadornemmy01.bcmdl",
	"actors/props/ev_chainreaction_cv_010/models/ev_chainreaction_cv_010.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_sg_casca004.bcmdl",
	"maps/objects/chozobgairfan01/chozobgairfan01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel060.bcmdl",
	"actors/props/doorcentralunit/models/doorcentralunit.bcmdl",
	"maps/objects/chozowaterbg02/chozowaterbg02.bcmdl",
	"maps/objects/cavrockinit01/cavrockinit01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel05.bcmdl",
	"maps/objects/cavrockwater02/cavrockwater02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel038.bcmdl",
	"maps/objects/magnetglovesp01endr/magnetglovesp01endr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel28.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel16.bcmdl",
	"maps/objects/chozoemmycolumn01x4/chozoemmycolumn01x4.bcmdl",
	"maps/objects/cavpilar01/cavpilar01.bcmdl",
	"actors/props/doorpresencepresence/models/doorpresencepresence.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel00.bcmdl",
	"actors/props/deviceheat/models/deviceheat.bcmdl",
	"maps/objects/cavrockwater01/cavrockwater01.bcmdl",
	"maps/objects/magnetglovesp01endl/magnetglovesp01endl.bcmdl",
	"maps/fx/waterstream/waterstreamforest01.bcmdl",
	"maps/objects/chozoplatformwater01x4/chozoplatformwater01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel050.bcmdl",
	"maps/objects/baselabprop01x03/baselabprop01x03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel24.bcmdl",
	"actors/props/ev_chainreaction_cv_005/models/ev_chainreaction_cv_005.bcmdl",
	"cutscenes/0001gameintro_space/fx/planet_atmos.bcmdl",
	"actors/props/doorcentralunit/fx/fracture_explosion.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel052.bcmdl",
	"cutscenes/0033sonarobtention/fx/trails_energy.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_18.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mattepaintrocks01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel009.bcmdl",
	"actors/items/itemsphere/fx/impact_itemsphere.bcmdl",
	"maps/objects/chozoemmywall01x4/chozoemmywall01x4.bcmdl",
	"maps/objects/cavcolumcrystal02/cavcolumcrystal02.bcmdl",
	"actors/props/breakablecave009/models/breakablecave009.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_s8_cooldown_02.bcmdl",
	"maps/objects/chozopipesyellowadorn01/chozopipesyellowadorn01.bcmdl",
	"system/fx/generic/varia_leftarmenergy.bcmdl",
	"maps/objects/chozoemmywall02x4/chozoemmywall02x4.bcmdl",
	"system/fx/generic/varia_leftshoulderenergy.bcmdl",
	"system/fx/generic/varia_end_shoulderenergy.bcmdl",
	"maps/objects/chozodumpcaveturbine/chozodumpcaveturbine.bcmdl",
	"actors/props/platformcavewaterb/fx/water_breakloop.bcmdl",
	"maps/fx/bigwaterstream_cave/fx/water_loop.bcmdl",
	"maps/fx/bigwaterstream_cave/fx/water_loop_02.bcmdl",
	"maps/objects/chozoroomatrezzo02/chozoroomatrezzo02.bcmdl",
	"actors/props/platformcavewaterb/fx/water_init.bcmdl",
	"maps/objects/chozoroomaltar01/chozoroomaltar01.bcmdl",
	"maps/objects/chozocavproto_02/chozocavproto_02.bcmdl",
	"actors/props/platformcavewaterb/fx/water_end.bcmdl",
	"actors/props/cut_37_wall01/models/cut_37_wall01.bcmdl",
	"actors/props/platformcavewaterb/fx/water_loop.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel10.bcmdl",
	"actors/props/platformcavewaterb/fx/water_initbreakloop.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel13.bcmdl",
	"actors/props/breakablecave003/fx/breakable_water.bcmdl",
	"actors/characters/bigfist/models/bigfist.bcmdl",
	"actors/props/watercave09/models/watercave09.bcmdl",
	"actors/props/weightactivatedplatform_teleport_frozen/models/weightactivatedplatform_teleport_frozen.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part004_o6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_walls_004.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_sg_casca006.bcmdl",
	"actors/props/cut_37_wires01/models/cut_37_wires01.bcmdl",
	"maps/objects/chozocavespecialoven01/chozocavespecialoven01.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/ashesparticles4_anim.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_decal02.bcmdl",
	"maps/objects/chozobgwallemmy02/chozobgwallemmy02.bcmdl",
	"maps/objects/chozocavspecial03/chozocavspecial03.bcmdl",
	"actors/props/ev_chainreaction_cv_009/models/ev_chainreaction_cv_009.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilarside2_001.bcmdl",
	"maps/objects/chozopathemmy01v2/chozopathemmy01v2.bcmdl",
	"actors/weapons/plasmabeam/fx/explosion.bcmdl",
	"actors/items/item_energyfragment/models/item_energyfragment.bcmdl",
	"actors/props/ev_chainreaction_cv_007/models/ev_chainreaction_cv_007.bcmdl",
	"maps/objects/chozoplatformemmy01x4/chozoplatformemmy01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel01.bcmdl",
	"actors/props/pool_lava_35x3/models/pool_lava_35x3.bcmdl",
	"actors/props/totalrechargestation/fx/charge_fx.bcmdl",
	"actors/props/energyrecharge/fx/charge_fx.bcmdl",
	"actors/props/ammorecharge/fx/charge_fx.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca133.bcmdl",
	"maps/objects/chozowatercolum01cl/chozowatercolum01cl.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_08sg_casca044.bcmdl",
	"maps/objects/chozowatercolum01cr/chozowatercolum01cr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_medio01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel012.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel066.bcmdl",
	"maps/objects/chozopathemmy01x4/chozopathemmy01x4.bcmdl",
	"maps/objects/fxwaterfallcave01/fxwaterfallcave01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel29.bcmdl",
	"maps/objects/chozocorridoremmy02/chozocorridoremmy02.bcmdl",
	"maps/objects/chozopathemmy01v3/chozopathemmy01v3.bcmdl",
	"actors/props/zipline_frozen/models/zipline_frozen.bcmdl",
	"maps/objects/chozoroomwall01x4/chozoroomwall01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilarside1_001.bcmdl",
	"maps/fx/waterstream/waterstream00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca146.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel001.bcmdl",
	"maps/objects/chozobasebg03x4/chozobasebg03x4.bcmdl",
	"maps/objects/chozomagassetlamp02/chozomagassetlamp02.bcmdl",
	"actors/props/ev_chainreaction_cv_003/models/ev_chainreaction_cv_003.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel030.bcmdl",
	"maps/objects/chozoroomwall01x6/chozoroomwall01x6.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_26.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca136.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_08.bcmdl",
	"actors/props/ev_chainreaction_cv_004/models/ev_chainreaction_cv_004.bcmdl",
	"actors/props/platformtrapgrapple5right/models/platformtrapgrapple5right.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel057.bcmdl",
	"actors/props/weightactivatedplatform_elevator_frozen/models/weightactivatedplatform_elevator_frozen.bcmdl",
	"maps/objects/chozoroomwall03x6/chozoroomwall03x6.bcmdl",
	"actors/props/doorpresenceframe/models/doorpresenceframe.bcmdl",
	"actors/props/doorgrapplegrapple/models/doorgrapplegrapple.bcmdl",
	"maps/objects/chozomagassetn03/chozomagassetn03.bcmdl",
	"maps/objects/chozomagpathwall01/chozomagpathwall01.bcmdl",
	"maps/objects/cavbackgroundrock01/cavbackgroundrock01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_05sg_casca045.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca144.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel044.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel17.bcmdl",
	"actors/props/doorframepresence/models/doorframepresence.bcmdl",
	"actors/props/doorclosedgrapple/models/doorclosedgrapple.bcmdl",
	"maps/objects/chozopipes01clamp01/chozopipes01clamp01.bcmdl",
	"actors/props/db_dif_cv_001/models/db_dif_cv_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_cut02.bcmdl",
	"maps/objects/chozowaterbg01endl/chozowaterbg01endl.bcmdl",
	"maps/objects/magnetglovesp01x3/magnetglovesp01x3.bcmdl",
	"actors/props/box_grapple_cv_001/models/box_grapple_cv_001.bcmdl",
	"maps/objects/chozoroomwall02x4/chozoroomwall02x4.bcmdl",
	"maps/objects/chozobasebgcorner01/chozobasebgcorner01.bcmdl",
	"maps/objects/chozoallwall03/chozoallwall03.bcmdl",
	"maps/objects/baselabprop01/baselabprop01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_25.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel15.bcmdl",
	"maps/objects/chozowaterbg01endr/chozowaterbg01endr.bcmdl",
	"actors/props/gatecaveprotoemmy/models/gatecaveprotoemmy.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_sg_casca007.bcmdl",
	"actors/props/doorheat/models/doorheat.bcmdl",
	"maps/objects/chozocavproto_03/chozocavproto_03.bcmdl",
	"maps/objects/chozowatercolum01al/chozowatercolum01al.bcmdl",
	"maps/objects/chozowatercolum01ar/chozowatercolum01ar.bcmdl",
	"actors/props/watercave08a/models/watercave08a.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part027_r9_00.bcmdl",
	"maps/objects/magnetziplinespendl/magnetziplinespendl.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part002_s5_vignettefull01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca135.bcmdl",
	"maps/objects/magnetziplinespendr/magnetziplinespendr.bcmdl",
	"maps/objects/chozoallassetpanel02/chozoallassetpanel02.bcmdl",
	"actors/items/item_energytank/models/item_energytank.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel04.bcmdl",
	"system/fx/generic/varia_end_leftarmenergy.bcmdl",
	"maps/objects/chozobgwater01x1/chozobgwater01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel03.bcmdl",
	"maps/objects/chozoallwall02x2/chozoallwall02x2.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel014.bcmdl",
	"maps/objects/cavrock06/cavrock06.bcmdl",
	"system/fx/generic/varia_chestenergysupport.bcmdl",
	"maps/objects/cavpathrock01v5/cavpathrock01v5.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel02.bcmdl",
	"actors/props/weightactivatedplatform_teleport/models/platform_teleporter.bcmdl",
	"maps/objects/chozopathemmy02endl/chozopathemmy02endl.bcmdl",
	"actors/props/platformcavmagnet3left/models/platformcavmagnet3left.bcmdl",
	"maps/objects/chozopathemmy02endr/chozopathemmy02endr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_06sg_casca045sg_casca047.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel05.bcmdl",
	"maps/objects/chozoemmybg01dx4/chozoemmybg01dx4.bcmdl",
	"maps/objects/chozoemmybg01cx4/chozoemmybg01cx4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_turbine_004.bcmdl",
	"actors/items/powerup_chargebeam/models/powerup_chargebeam.bcmdl",
	"actors/props/trap_thermal_horizontal/models/trap_thermal_horizontal.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca145.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_001.bcmdl",
	"actors/props/trap_rot_cv_002/models/trap_rot_cv_002.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_debris_001.bcmdl",
	"maps/objects/chozoemmypath01v2/chozoemmypath01v2.bcmdl",
	"actors/props/trap_rot_cv_001/models/trap_rot_cv_001.bcmdl",
	"actors/props/cover_magnet_cv_002/fx/covermagnet02_fracture.bcmdl",
	"maps/fx/waterstream/waterstream01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca147.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca134.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part020_e10_vignette_000.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_07sg_casca044sg_casca046.bcmdl",
	"maps/objects/cavcrystal04/cavcrystal04.bcmdl",
	"actors/events/mapev_deer01/models/deer.bcmdl",
	"actors/props/pool_water15x3_gen/models/pool_water15x3_gen.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel04.bcmdl",
	"cutscenes/0001gameintro_fight/fx/zerolaser_airstrong.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette_001.bcmdl",
	"maps/objects/chozocolmag02/chozocolmag02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel08.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_final_01.bcmdl",
	"maps/objects/chozoroompath01endright/chozoroompath01endright.bcmdl",
	"maps/objects/chozoroompath01endleft/chozoroompath01endleft.bcmdl",
	"maps/objects/chozoroomplatform01x3/chozoroomplatform01x3.bcmdl",
	"maps/objects/caverock02/caverock02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part025_jp1_planereflect_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pipe_019.bcmdl",
	"maps/objects/chozocavspecial04/chozocavspecial04.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aurascratch_noise.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_011.bcmdl",
	"actors/props/grappleswingpoint/models/grappleswingpoint.bcmdl",
	"maps/objects/chozowatercolum01dl/chozowatercolum01dl.bcmdl",
	"maps/objects/shipyardrock03/shipyardrock03.bcmdl",
	"maps/objects/cavscorpiusbones01/cavscorpiusbones01.bcmdl",
	"maps/objects/caverock01/caverock01.bcmdl",
	"maps/objects/chozoemmyplatform01x4/chozoemmyplatform01x4.bcmdl",
	"maps/objects/chozoemmypath01x4/chozoemmypath01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca137.bcmdl",
	"maps/objects/chozomagplatform200/chozomagplatform200.bcmdl",
	"actors/props/ev_chainreaction_cv_002/models/ev_chainreaction_cv_002.bcmdl",
	"maps/objects/cavegg03/cavegg03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_middle00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel032.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pipefloor_003_new.bcmdl",
	"maps/objects/chozocavproto_04b/chozocavproto_04b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_08.bcmdl",
	"maps/objects/cavpathrock01v4/cavpathrock01v4.bcmdl",
	"maps/objects/chozowatercolum01dr/chozowatercolum01dr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel11.bcmdl",
	"maps/objects/chozowaterbg01x3/chozowaterbg01x3.bcmdl",
	"maps/objects/cavplatformrock04v6/cavplatformrock04v6.bcmdl",
	"maps/objects/cavplatformrock04v5/cavplatformrock04v5.bcmdl",
	"maps/objects/cavplatformrock04v8/cavplatformrock04v8.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/absortion_cu.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_071.bcmdl",
	"cutscenes/0112endgame/fx/starfield_01.bcmdl",
	"maps/objects/chozocavspecial05/chozocavspecial05.bcmdl",
	"maps/objects/chozoemmywallcorner02/chozoemmywallcorner02.bcmdl",
	"actors/props/breakablecave008/fx/water.bcmdl",
	"maps/objects/chozoallpathceiling04x4a/chozoallpathceiling04x4a.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_043.bcmdl",
	"maps/objects/chozobasebgcornerleft01/chozobasebgcornerleft01.bcmdl",
	"cutscenes/0053genericcupowerobtention/fx/absortion_meshes.bcmdl",
	"actors/props/dooremmy_cut36/models/dooremmy_cut36.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_04sg_casca043.bcmdl",
	"maps/objects/chozobasebgcornerright01/chozobasebgcornerright01.bcmdl",
	"maps/objects/chozoemmypath01v3/chozoemmypath01v3.bcmdl",
	"maps/fx/lavasplashes/lava_explosion01_anim.bcmdl",
	"maps/objects/magnetglovesp01x2/magnetglovesp01x2.bcmdl",
	"actors/props/cut_37_wallend02/models/cut_37_wallend02.bcmdl",
	"maps/fx/lavadrops/lava_drops04_anim.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel31.bcmdl",
	"maps/fx/lavadrops/lava_drops01_anim.bcmdl",
	"maps/fx/lavadrops/lava_drops03_anim.bcmdl",
	"maps/fx/lavadrops/lava_drops00_anim.bcmdl",
	"cutscenes/0036enteremmyzone/fx/dooremmyfx.bcmdl",
	"actors/props/dooremmy/fx/dooremmyfx.bcmdl",
	"maps/objects/chozoallasset04/chozoallasset04.bcmdl",
	"maps/fx/lavasplashes/lava_explosion00_anim.bcmdl",
	"maps/objects/chozoroomwall02curve/chozoroomwall02curve.bcmdl",
	"maps/objects/chozoemmybgcorner02a/chozoemmybgcorner02a.bcmdl",
	"actors/props/weightactivatedplatform_total/models/platform_totalrecharge.bcmdl",
	"maps/objects/chozofrontpath02x4/chozofrontpath02x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_06sg_casca054.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_03sg_casca041.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part021_e4_00.bcmdl",
	"actors/props/doorwidebeam/models/doorwidebeam.bcmdl",
	"actors/props/zipline/models/zipline.bcmdl",
	"maps/objects/magpathrock01/magpathrock01.bcmdl",
	"maps/objects/chozomagassetn01/chozomagassetn01.bcmdl",
	"actors/props/grapplepulloff1x2/models/grapplepulloff1x2.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_090sg_casca090.bcmdl",
	"maps/objects/chozopipes01clamp02/chozopipes01clamp02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_064sg_casca064.bcmdl",
	"actors/props/weightactivatedplatform_elevator/models/platform_elevator.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_089sg_casca089.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_063sg_casca063.bcmdl",
	"actors/spawnpoints/spawnpointautool/models/dockautool.bcmdl",
	"maps/objects/chozomagasset01/chozomagasset01.bcmdl",
	"maps/objects/chozobasebg02x4/chozobasebg02x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_10sg_casca040.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables13sg_casca109.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables15sg_casca116.bcmdl",
	"actors/props/platformcavmagnet5down/models/platformcavmagnet5down.bcmdl",
	"maps/objects/chozoplatformpipes01x1/chozoplatformpipes01x1.bcmdl",
	"maps/objects/chozoplatformpipes01x4/chozoplatformpipes01x4.bcmdl",
	"cutscenes/0001gameintro_fight/fx/commander_zerolaser_explosion_big.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel16b.bcmdl",
	"actors/spawnpoints/spawnpointcaterzillametallic/models/spawnpointcaterzillametallicwall.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_24.bcmdl",
	"maps/objects/shipyardrock01/shipyardrock01.bcmdl",
	"maps/objects/chozoallpathceiling04x4b/chozoallpathceiling04x4b.bcmdl",
	"actors/spawnpoints/spawnpointcaterzillametallic/models/spawnpointcaterzillametallic.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables17sg_casca130.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_px_cooldown_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables16sg_casca123.bcmdl",
	"maps/objects/evrodhorde_a/evrodhorde_a.bcmdl",
	"maps/objects/evrodhorde_c/evrodhorde_c.bcmdl",
	"maps/objects/evrodhorde_d/evrodhorde_d.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part023_o9_vignette.bcmdl",
	"maps/objects/chozomagasset05/chozomagasset05.bcmdl",
	"maps/objects/chozoallassetbottleplat04/chozoallassetbottleplat04.bcmdl",
	"maps/objects/chozomagemmypath01endr/chozomagemmypath01endr.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel30.bcmdl",
	"actors/props/maproom/fx/sphere_map.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables14sg_casca101.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_09sg_casca042.bcmdl",
	"actors/props/platformcavmagnet4down/models/platformcavmagnet4down.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part009_r6_00.bcmdl",
	"actors/weapons/missile/models/cutscenemissile.bcmdl",
	"maps/objects/fxpouringwaterx4/fxpouringwaterx4.bcmdl",
	"actors/items/powerup_grapplebeam/models/powerup_grapplebeam.bcmdl",
	"maps/objects/chozoallassetbottle02/chozoallassetbottle02.bcmdl",
	"cutscenes/0001gameintro_fight/fx/plasmabeam_chargedprojectile.bcmdl",
	"actors/props/block_slide_reg_001/models/block_slide_reg_001.bcmdl",
	"actors/fx/flickeringlight01/fx/flickeringlight01.bcmdl",
	"maps/objects/coldzoneasset08/coldzoneasset08.bcmdl",
	"maps/objects/lshaftlamp01/lshaftlamp01.bcmdl",
	"maps/objects/magnetglovesp01cornerout/magnetglovesp01cornerout.bcmdl",
	"maps/objects/magnetglovesp01cornerout90b/magnetglovesp01cornerout90b.bcmdl",
	"maps/objects/chozomagemmypath01endl/chozomagemmypath01endl.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_wallbox2_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_088sg_casca088.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_088sg_casca089.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_087sg_casca087.bcmdl",
	"cutscenes/0033sonarobtention/fx/energy_center.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_sg_093sg_casca093.bcmdl",
	"maps/objects/chozopathpipes01x4/chozopathpipes01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_turbine_pipe_003.bcmdl",
	"maps/objects/chozohangcable03/chozohangcable03.bcmdl",
	"maps/objects/chozoemmytunnelbg01set/chozoemmytunnelbg01set.bcmdl",
	"maps/objects/chozoshipasset02/chozoshipasset02.bcmdl",
	"actors/props/pool_water37_7_gen/models/pool_water37_7_gen.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part012_e7_vignette.bcmdl",
	"maps/objects/chozopathmag01x4/chozopathmag01x4.bcmdl",
	"maps/objects/caverockplatform05/caverockplatform05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_001_new.bcmdl",
	"maps/objects/chozoallassetpanel01/chozoallassetpanel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pipe_026.bcmdl",
	"maps/objects/chozobasebgcorner03/chozobasebgcorner03.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/ashesparticles3_anim.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca143.bcmdl",
	"cutscenes/0001gameintro_fight/fx/zerolaser_airburst.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables12sg_casca106.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables29sg_casca113.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables33sg_casca127.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables31sg_casca120.bcmdl",
	"actors/props/cutmodel49wall02/models/cutmodel49wall02.bcmdl",
	"actors/props/weightactivatedplatform_save/models/weightactivatedplatform_save.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables28sg_casca105.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables10sg_casca104.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables30sg_casca112.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables11sg_casca098.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables32sg_casca119.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables34sg_casca126.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilarside2_002.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel32.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_ceiling1_000.bcmdl",
	"maps/objects/cavpathrock01/cavpathrock01.bcmdl",
	"actors/props/doorshutter/models/doorshutter.bcmdl",
	"maps/objects/chozoemmybg01bx4/chozoemmybg01bx4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel03.bcmdl",
	"maps/objects/chozoemmybg02x4/chozoemmybg02x4.bcmdl",
	"maps/objects/magnetglovesp01cornerin90b/magnetglovesp01cornerin90b.bcmdl",
	"maps/objects/cavcolumcrystal04/cavcolumcrystal04.bcmdl",
	"maps/objects/magnetglovesp01cornerin90/magnetglovesp01cornerin90.bcmdl",
	"actors/props/doorwidebeam/fx/shieldwidefx.bcmdl",
	"actors/props/weightactivatedplatform_valve/models/weightactivatedplatform_valve.bcmdl",
	"maps/objects/chozospecialfurnace/chozospecialfurnace.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/speedtunnel_samus.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/scorpiusscream_distortion.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/scorpiusscream.bcmdl",
	"system/fx/generic/varia_jumpsmoke.bcmdl",
	"maps/objects/magdigrocklava01/magdigrocklava01.bcmdl",
	"maps/objects/chozopipesthermal01cornerinvert/chozopipesthermal01cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal01corner/chozopipesthermal01corner.bcmdl",
	"maps/objects/chozopipesthermal01mcorner/chozopipesthermal01mcorner.bcmdl",
	"actors/props/doorframe/models/doorframe.bcmdl",
	"actors/props/burnertrapcav01/models/burnertrapcav01.bcmdl",
	"actors/props/steammag01/models/steammag01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_006.bcmdl",
	"maps/objects/frontchozowires01/frontchozowires01.bcmdl",
	"actors/spawnpoints/spawnpointcaterzilla/models/spawnpointcaterzilla.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_wallbox2_002_new.bcmdl",
	"maps/objects/chozoemmywallcorner01x1/chozoemmywallcorner01x1.bcmdl",
	"actors/props/doorcentralunit/fx/lampfresnel.bcmdl",
	"maps/objects/cavpathrock01v2/cavpathrock01v2.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_wallbox1_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_turbinefairing_003.bcmdl",
	"maps/objects/chozobgemmydoor01/chozobgemmydoor01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel021.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca160sg_casca160.bcmdl",
	"maps/objects/chozomagasset06/chozomagasset06.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_burst.bcmdl",
	"maps/objects/chozopathemmy02x4/chozopathemmy02x4.bcmdl",
	"maps/objects/chozobasepath02x1/chozobasepath02x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel020.bcmdl",
	"maps/objects/chozobgpipes02/chozobgpipes02.bcmdl",
	"actors/props/weightactivatedplatform_thermal/models/platform_heat.bcmdl",
	"maps/objects/chozofrontpath01x4/chozofrontpath01x4.bcmdl",
	"actors/props/doorcaveatrium/models/doorcaveatrium.bcmdl",
	"maps/objects/coldzoneasset03/coldzoneasset03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca161sg_casca161.bcmdl",
	"maps/objects/chozobaseassets01/chozobaseassets01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part007_e6_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pilarside1_002.bcmdl",
	"maps/objects/chozoallscaffold05/chozoallscaffold05.bcmdl",
	"maps/objects/chozoallassetbottle03/chozoallassetbottle03.bcmdl",
	"actors/props/maproom/fx/ring_sphere.bcmdl",
	"actors/items/powerup_variasuit/models/powerup_variasuit.bcmdl",
	"maps/objects/chozomagassetlamp01/chozomagassetlamp01.bcmdl",
	"maps/objects/chozoborderemmy01/chozoborderemmy01.bcmdl",
	"maps/objects/chozoemmywallcorner03/chozoemmywallcorner03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_007.bcmdl",
	"maps/objects/chozoalldecal01/chozoalldecal01.bcmdl",
	"actors/props/totalrechargestation/fx/prop_energy.bcmdl",
	"actors/props/ev_chainreaction_cv_006/models/ev_chainreaction_cv_006.bcmdl",
	"maps/objects/chozopipesthermal01mx3/chozopipesthermal01mx3.bcmdl",
	"maps/objects/chozopipesthermal01x3/chozopipesthermal01x3.bcmdl",
	"maps/objects/chozobgmagwallb08/chozobgmagwallb08.bcmdl",
	"actors/props/doorshieldsupermissile/models/doorshieldsupermissile.bcmdl",
	"maps/objects/cavrockinit02/cavrockinit02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part019_jg8_vignette.bcmdl",
	"maps/objects/chozobgair02/chozobgair02.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/energy_absortion.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel062.bcmdl",
	"actors/props/weightactivatedplatform_energy/models/platform_energy.bcmdl",
	"cutscenes/0001gameintro_fight/fx/commander_zerolaser_explosion_medium.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel006.bcmdl",
	"maps/objects/chozobasebg01x4/chozobasebg01x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_02sg_casca052.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel08.bcmdl",
	"maps/objects/magnetglovesp01x1/magnetglovesp01x1.bcmdl",
	"maps/objects/cavedigrock04/cavedigrock04.bcmdl",
	"maps/objects/chozoallassetmachine02/chozoallassetmachine02.bcmdl",
	"actors/props/doorshieldmissile/models/doorshieldmissile.bcmdl",
	"maps/objects/chozoallassetmachine01/chozoallassetmachine01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_08sg_casca055.bcmdl",
	"actors/spawnpoints/spawnpointrockdiver/models/spawnpointrockdiver.bcmdl",
	"maps/objects/chozopathmag01endright/chozopathmag01endright.bcmdl",
	"maps/objects/cavrockcrystal01/cavrockcrystal01.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_cv_003.bcmdl",
	"maps/objects/chozobgmagwallb04/chozobgmagwallb04.bcmdl",
	"actors/props/pool_lava_mg_006/models/pool_lava_mg_006.bcmdl",
	"maps/objects/chozohangcable08/chozohangcable08.bcmdl",
	"maps/objects/caverock03/caverock03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_07sg_casca048.bcmdl",
	"maps/objects/chozopathmag01endleft/chozopathmag01endleft.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca162sg_casca162.bcmdl",
	"maps/objects/chozoroomroof01curve/chozoroomroof01curve.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables25sg_casca118.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables04sg_casca114.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables02sg_casca099.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_casca_pipe1_sg_casca033.bcmdl",
	"maps/objects/chozoshipasset01/chozoshipasset01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables00sg_casca107.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_lshaft02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables26sg_casca125.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables24sg_casca103.bcmdl",
	"maps/objects/chozoallpathceiling02x2/chozoallpathceiling02x2.bcmdl",
	"maps/objects/chozoaqpipejoint01/chozoaqpipejoint01.bcmdl",
	"maps/objects/cavegg02/cavegg02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables27sg_casca132.bcmdl",
	"maps/objects/chozoemmywall02x1/chozoemmywall02x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel16a.bcmdl",
	"actors/props/cover_magnet_cv_001/models/cover_magnet_cv_001.bcmdl",
	"actors/props/pool_lava_mg_018/models/pool_lava_mg_018.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part010_jg9_mapmodel_030.bcmdl",
	"cutscenes/0033sonarobtention/fx/flames_ic.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_070.bcmdl",
	"actors/props/missile_cut/models/missile_cut.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_01sg_casca051.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca159sg_casca159.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables23sg_casca111.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables08sg_casca128.bcmdl",
	"maps/objects/magnetziplinesp01x3/magnetziplinesp01x3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables06sg_casca121.bcmdl",
	"maps/objects/chozoemmycolumn01x1/chozoemmycolumn01x1.bcmdl",
	"maps/objects/cavbackgroundrock02/cavbackgroundrock02.bcmdl",
	"maps/objects/coldzoneasset07/coldzoneasset07.bcmdl",
	"maps/objects/magrockborder01/magrockborder01.bcmdl",
	"maps/objects/caverockborder01/caverockborder01.bcmdl",
	"maps/objects/chozocavspecial02/chozocavspecial02.bcmdl",
	"maps/objects/coldzoneassetn010/coldzoneassetn010.bcmdl",
	"maps/objects/cavwaterrock02/cavwaterrock02.bcmdl",
	"maps/objects/magdigrocklava06/magdigrocklava06.bcmdl",
	"maps/objects/magrockborder03/magrockborder03.bcmdl",
	"maps/objects/caverockborder03/caverockborder03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca151sg_casca151.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_s6_mapmodel_51.bcmdl",
	"maps/objects/chozofrontpath02x1b/chozofrontpath02x1b.bcmdl",
	"actors/props/weightactivatedplatform_ammo/models/platform_ammo.bcmdl",
	"maps/objects/chozoemmypipejoint01/chozoemmypipejoint01.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_energy.bcmdl",
	"cutscenes/0001gameintro_fight/fx/kistrike_wave.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_casca_pipe1_sg_casca037.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_plug1_008.bcmdl",
	"maps/objects/cavpathrock02/cavpathrock02.bcmdl",
	"maps/objects/chozoadornpipes01/chozoadornpipes01.bcmdl",
	"actors/props/watercave07/models/watercave07.bcmdl",
	"maps/objects/chozoallwall01x3/chozoallwall01x3.bcmdl",
	"maps/objects/cavcolumnrock01/cavcolumnrock01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca165sg_casca165.bcmdl",
	"maps/objects/cavrockpillar01/cavrockpillar01.bcmdl",
	"maps/objects/chozowaterbg01x2/chozowaterbg01x2.bcmdl",
	"maps/objects/shipyardrock06/shipyardrock06.bcmdl",
	"maps/objects/chozoallbgemmy01corext/chozoallbgemmy01corext.bcmdl",
	"actors/props/weightactivatedplatform_map/models/weightactivatedplatform.bcmdl",
	"actors/props/weightactivatedplatform_valve/models/weightactivatedplatform.bcmdl",
	"maps/objects/chozoallpipesset01x3/chozoallpipesset01x3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_11sg_casca185.bcmdl",
	"actors/props/watercave01a/models/watercave01a.bcmdl",
	"maps/objects/chozowatercolum01er/chozowatercolum01er.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_startrays.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_04sg_casca053.bcmdl",
	"maps/objects/cavedigrock01/cavedigrock01.bcmdl",
	"maps/objects/cavrockdetail01/cavrockdetail01.bcmdl",
	"maps/objects/chozospenginebk06/chozospenginebk06.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_rays_radial.bcmdl",
	"maps/objects/chozobgmagwallb06/chozobgmagwallb06.bcmdl",
	"maps/objects/chozoemmybg01corext/chozoemmybg01corext.bcmdl",
	"maps/objects/chozowatercolum01el/chozowatercolum01el.bcmdl",
	"maps/objects/chozoemmywallcorner01/chozoemmywallcorner01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca152sg_casca152.bcmdl",
	"maps/objects/coldzoneasset05/coldzoneasset05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel00.bcmdl",
	"maps/objects/chozohangcable07/chozohangcable07.bcmdl",
	"maps/objects/chozoemmybgcorner02c/chozoemmybgcorner02c.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel14.bcmdl",
	"maps/objects/coldzoneasset04/coldzoneasset04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_05sg_casca049.bcmdl",
	"actors/props/watercave08b/models/watercave08b.bcmdl",
	"maps/objects/chozofrontpath04x1d/chozofrontpath04x1d.bcmdl",
	"actors/props/asteroids/models/asteroid_c.bcmdl",
	"maps/objects/cavwaterrock01/cavwaterrock01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca172sg_casca172.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part008_r6_vignette_001.bcmdl",
	"maps/objects/chozopipesyellow01x3/chozopipesyellow01x3.bcmdl",
	"maps/objects/chozoallverticalwall01/chozoallverticalwall01.bcmdl",
	"maps/objects/chozoaqjoint02/chozoaqjoint02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_matte01.bcmdl",
	"maps/objects/cavdigrockplatform01/cavdigrockplatform01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_sg_casca038.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_sg_casca039.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_pipeclamp_001.bcmdl",
	"maps/objects/cavegg01/cavegg01.bcmdl",
	"actors/props/weightactivatedplatform_access/models/weightactivatedplatform_access.bcmdl",
	"actors/props/supermissile_cut/models/supermissile_cut.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_casca_pipe1_sg_casca034.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables19sg_casca102.bcmdl",
	"actors/items/item_missiletankplus/models/item_missiletankplus.bcmdl",
	"maps/objects/chozobgmagwallb07/chozobgmagwallb07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables18sg_casca110.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables20sg_casca117.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables22sg_casca131.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables05sg_casca115.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables09sg_casca129.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_pathmachinee_pipeclamp_006.bcmdl",
	"maps/objects/chozoallscaffold03/chozoallscaffold03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables07sg_casca122.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables03sg_casca100.bcmdl",
	"maps/objects/chozoemmybgcorner02b/chozoemmybgcorner02b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables01sg_casca108.bcmdl",
	"actors/props/asteroids/models/asteroid_b.bcmdl",
	"maps/objects/chozomagasset03/chozomagasset03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_breakables21sg_casca124.bcmdl",
	"actors/props/elevator/fx/chains_glow.bcmdl",
	"actors/props/maproom/fx/sonar_sphere.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_94sg_casca094.bcmdl",
	"maps/objects/chozobasebgcorner04/chozobasebgcorner04.bcmdl",
	"maps/objects/chozomagemmypath01x4/chozomagemmypath01x4.bcmdl",
	"maps/objects/magrockborder02/magrockborder02.bcmdl",
	"maps/objects/caverockborder02/caverockborder02.bcmdl",
	"maps/objects/chozoemmywall01x1/chozoemmywall01x1.bcmdl",
	"actors/items/item_missiletank/models/item_missiletank.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_wallbox1_002_new.bcmdl",
	"maps/objects/chozoallwall01x1/chozoallwall01x1.bcmdl",
	"maps/objects/chozohangcable09/chozohangcable09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel008.bcmdl",
	"maps/objects/chozowatercolum01bl/chozowatercolum01bl.bcmdl",
	"maps/objects/chozoallbgemmy01corint/chozoallbgemmy01corint.bcmdl",
	"actors/events/mapev_reptile01/models/reptile01.bcmdl",
	"actors/props/asteroids/models/asteroid_a.bcmdl",
	"maps/objects/chozowatercolum01br/chozowatercolum01br.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca169sg_casca169.bcmdl",
	"actors/events/mapev_bigfistgrub/models/bigfistgrub.bcmdl",
	"actors/events/mapev_reptile02/models/reptile02.bcmdl",
	"maps/objects/coldzoneasset01/coldzoneasset01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel002.bcmdl",
	"actors/props/pool_water14x7_gen/models/pool_water14x7_gen.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca171sg_casca171.bcmdl",
	"actors/props/grapplenavigation/models/grapplenavigation.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel036.bcmdl",
	"maps/fx/waterstream/waterwave00.bcmdl",
	"maps/objects/chozopipes01corner02/chozopipes01corner02.bcmdl",
	"actors/spawnpoints/spawnpointrockdivermetallic/models/spawnpointrockdivermetallic.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca150sg_casca150.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca149sg_casca149.bcmdl",
	"maps/objects/chozofrontpath01x1b/chozofrontpath01x1b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part008_r6_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_pipe1_03sg_casca050.bcmdl",
	"maps/objects/magnetglovesp01xhalf1/magnetglovesp01xhalf1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part04_o6_00.bcmdl",
	"maps/objects/chozoemmytunnelbg01/chozoemmytunnelbg01.bcmdl",
	"actors/props/watercave05/models/watercave05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel048.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_004.bcmdl",
	"maps/objects/chozopathemmy01endl/chozopathemmy01endl.bcmdl",
	"actors/props/watercave01b/models/watercave01b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_sg_casca005.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_x1_sg_casca008.bcmdl",
	"maps/objects/chozoemmypath01endl/chozoemmypath01endl.bcmdl",
	"maps/objects/chozomagplatform100/chozomagplatform100.bcmdl",
	"maps/fx/waterstream/waterwave01.bcmdl",
	"maps/objects/chozoallpath01x3/chozoallpath01x3.bcmdl",
	"maps/objects/chozoallscaffold04/chozoallscaffold04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_airunit1_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_airunit1_000.bcmdl",
	"actors/events/butterfly/models/butterfly.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part014_p3_vignette.bcmdl",
	"maps/objects/chozopathemmy01x1b/chozopathemmy01x1b.bcmdl",
	"maps/objects/chozoemmybg01corint/chozoemmybg01corint.bcmdl",
	"maps/objects/cavcrystal08/cavcrystal08.bcmdl",
	"actors/props/cover_magnet_cv_002/models/cover_magnet_cv_002.bcmdl",
	"maps/objects/chozoemmypath01endr/chozoemmypath01endr.bcmdl",
	"maps/objects/chozobasebgcorner02/chozobasebgcorner02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel035.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel030.bcmdl",
	"cutscenes/0001gameintro_fight/fx/zerolaser_energybase.bcmdl",
	"maps/objects/cavedigrock03/cavedigrock03.bcmdl",
	"maps/objects/chozobgpipes01x4/chozobgpipes01x4.bcmdl",
	"maps/objects/chozomagbgwall01x3/chozomagbgwall01x3.bcmdl",
	"maps/objects/chozomagasset04/chozomagasset04.bcmdl",
	"maps/objects/chozomagbgwall01x1/chozomagbgwall01x1.bcmdl",
	"maps/objects/chozoallassetpanel03b/chozoallassetpanel03b.bcmdl",
	"maps/objects/chozoallassetpanel03/chozoallassetpanel03.bcmdl",
	"maps/objects/cavrock04/cavrock04.bcmdl",
	"maps/objects/chozostationfence01/chozostationfence01.bcmdl",
	"maps/objects/chozoallpipe03/chozoallpipe03.bcmdl",
	"maps/objects/cavpathrock02v2/cavpathrock02v2.bcmdl",
	"maps/objects/chozopipes01x3/chozopipes01x3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca141.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_o2_lightshaft02.bcmdl",
	"maps/objects/magrockborder04/magrockborder04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_013.bcmdl",
	"maps/objects/caverockborder04/caverockborder04.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_pipebreakable_002_sg_casca060.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca168sg_casca168.bcmdl",
	"actors/items/powerup_screwattack/models/powerup_screwattack.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part003_p4_vignette00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca142.bcmdl",
	"actors/items/item_powerbombtank/models/item_powerbombtank.bcmdl",
	"maps/objects/chozoallscaffold06/chozoallscaffold06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca139.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca140.bcmdl",
	"maps/objects/cavplatformrock04v4/cavplatformrock04v4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_sg_casca138.bcmdl",
	"maps/objects/chozoallwall02cornerleft/chozoallwall02cornerleft.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel05.bcmdl",
	"maps/objects/cavpathrock01v3/cavpathrock01v3.bcmdl",
	"actors/props/doorshieldsupermissile/fx/shieldmissilefx.bcmdl",
	"actors/props/doorshieldmissile/fx/shieldmissilefx.bcmdl",
	"actors/props/box_weight_cv_001/models/box_weight_cv_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca167sg_casca167.bcmdl",
	"maps/objects/chozoallassetbox01/chozoallassetbox01.bcmdl",
	"maps/objects/chozoallwall02corner/chozoallwall02corner.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part017_e5_vignette00.bcmdl",
	"maps/objects/chozoroompath01x4/chozoroompath01x4.bcmdl",
	"maps/objects/chozofrontpath01x1a/chozofrontpath01x1a.bcmdl",
	"maps/objects/chozohangcable01/chozohangcable01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_vignette_001.bcmdl",
	"maps/objects/coldzoneasset09/coldzoneasset09.bcmdl",
	"maps/objects/chozopathmagjoint01/chozopathmagjoint01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca148sg_casca148.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e4_decal01.bcmdl",
	"maps/objects/caverockborder05/caverockborder05.bcmdl",
	"maps/objects/chozocorridoremmy01/chozocorridoremmy01.bcmdl",
	"maps/objects/chozowatercolum01f/chozowatercolum01f.bcmdl",
	"actors/props/planetzdr_background/models/planetzdr_background.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_rays.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_rays_end.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_09.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca156sg_casca156.bcmdl",
	"maps/objects/chozofrontpath01x1c/chozofrontpath01x1c.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca170sg_casca170.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_003.bcmdl",
	"maps/objects/cavcrystal01/cavcrystal01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel14.bcmdl",
	"maps/objects/cavcrystal07/cavcrystal07.bcmdl",
	"maps/objects/chozoallpathceilingcorner/chozoallpathceilingcorner.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca155sg_casca155.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca166sg_casca166.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel09.bcmdl",
	"maps/objects/cavcrystal06/cavcrystal06.bcmdl",
	"maps/objects/chozoallassettube01/chozoallassettube01.bcmdl",
	"maps/objects/cavcrystal05/cavcrystal05.bcmdl",
	"actors/weapons/plasmabeam/fx/muzzle_3d.bcmdl",
	"maps/objects/chozoallverticalwall02/chozoallverticalwall02.bcmdl",
	"maps/objects/chozoallpath01x1/chozoallpath01x1.bcmdl",
	"cutscenes/0033sonarobtention/fx/absortion_energy_hand.bcmdl",
	"maps/objects/chozoallassetbottleplat01/chozoallassetbottleplat01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_o2_lightshaft03.bcmdl",
	"maps/objects/chozoemmyborderwalljoint01/chozoemmyborderwalljoint01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel16.bcmdl",
	"maps/objects/chozopathemmy02x1/chozopathemmy02x1.bcmdl",
	"system/fx/generic/varia_cannon_smallcover.bcmdl",
	"system/fx/generic/varia_cannon_smallcover_end.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_13sg_casca096.bcmdl",
	"maps/objects/chozofrontpath01x1d/chozofrontpath01x1d.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_14sg_casca095.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_casca_pipe1_sg_casca036.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/rayscannon.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_casca_pipe1_sg_casca035.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_pb7_mapmodel07.bcmdl",
	"maps/objects/chozoemmywallcorner02x1/chozoemmywallcorner02x1.bcmdl",
	"maps/objects/chozobgair01/chozobgair01.bcmdl",
	"maps/objects/chozogrid02/chozogrid02.bcmdl",
	"maps/objects/chozoallcorner01b/chozoallcorner01b.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/ocsphere.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca153sg_casca153.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel07.bcmdl",
	"maps/objects/magnetziplinesp01x1/magnetziplinesp01x1.bcmdl",
	"maps/objects/cavpathrockmod01v2/cavpathrockmod01v2.bcmdl",
	"maps/objects/chozopipesthermal01mx1/chozopipesthermal01mx1.bcmdl",
	"maps/objects/chozopipesthermal01x1/chozopipesthermal01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_12sg_casca64000.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part013_pb7_vignette.bcmdl",
	"maps/objects/chozoborderemmyjoint01/chozoborderemmyjoint01.bcmdl",
	"maps/objects/chozobgmagwall10/chozobgmagwall10.bcmdl",
	"maps/objects/chozoborderemmy02x4/chozoborderemmy02x4.bcmdl",
	"maps/objects/chozohangcable04/chozohangcable04.bcmdl",
	"maps/objects/cavpathrockmod02v2/cavpathrockmod02v2.bcmdl",
	"maps/objects/chozoemmypath01x1/chozoemmypath01x1.bcmdl",
	"maps/objects/chozopathemmy01x1/chozopathemmy01x1.bcmdl",
	"maps/objects/chozoalltunnelbg01x3/chozoalltunnelbg01x3.bcmdl",
	"maps/objects/chozomagplatformend/chozomagplatformend.bcmdl",
	"maps/objects/cavrock05/cavrock05.bcmdl",
	"maps/objects/cavbugrockcolum04/cavbugrockcolum04.bcmdl",
	"maps/objects/cavbugrockcolum02/cavbugrockcolum02.bcmdl",
	"maps/objects/cavedigrock02/cavedigrock02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca154sg_casca154.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca157sg_casca157.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel12.bcmdl",
	"actors/props/cut_37_wdrain01/models/cut_37_wdrain01.bcmdl",
	"maps/objects/chozoallpathceiling01x1/chozoallpathceiling01x1.bcmdl",
	"maps/objects/cavbugrockcolum03/cavbugrockcolum03.bcmdl",
	"maps/objects/cavcrystal09/cavcrystal09.bcmdl",
	"maps/objects/chozohandrail04_2/chozohandrail04_2.bcmdl",
	"maps/objects/magmeltrockpath01x4/magmeltrockpath01x4.bcmdl",
	"maps/objects/chozoemmyplatform01x1/chozoemmyplatform01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca163sg_casca163.bcmdl",
	"maps/objects/chozohandrail04break01/chozohandrail04break01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel15.bcmdl",
	"maps/objects/magdigrock02/magdigrock02.bcmdl",
	"maps/objects/cavwaterrockpath01x4/cavwaterrockpath01x4.bcmdl",
	"maps/objects/cavwaterrockpath02x4/cavwaterrockpath02x4.bcmdl",
	"maps/objects/chozobgmagwallb03/chozobgmagwallb03.bcmdl",
	"maps/objects/chozobgair01x1/chozobgair01x1.bcmdl",
	"maps/objects/chozoroomwall02/chozoroomwall02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part005_e5_00.bcmdl",
	"actors/items/itemsphere/models/itemsphere.bcmdl",
	"maps/objects/chozobasebg01x1/chozobasebg01x1.bcmdl",
	"maps/objects/chozobgpipescorner_01/chozobgpipescorner_01.bcmdl",
	"maps/objects/chozopathemmy02bgcorl/chozopathemmy02bgcorl.bcmdl",
	"maps/objects/cavbugrockcolum01/cavbugrockcolum01.bcmdl",
	"maps/objects/chozoallcorner01a/chozoallcorner01a.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_airunit2_001.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/trail_cannon.bcmdl",
	"maps/objects/chozopathemmy02bgcorr/chozopathemmy02bgcorr.bcmdl",
	"maps/objects/chozobgmagwalljointb/chozobgmagwalljointb.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel048.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_casca_pipe1_sg_casca189.bcmdl",
	"actors/props/ev_entercu_cv_001/models/ev_entercu_cv_001.bcmdl",
	"maps/objects/magmeltrockwall01x4/magmeltrockwall01x4.bcmdl",
	"maps/objects/chozoemmybg02x1/chozoemmybg02x1.bcmdl",
	"maps/objects/cavpathrock01v6/cavpathrock01v6.bcmdl",
	"maps/objects/chozopipes01x1/chozopipes01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_turbinefairing_001.bcmdl",
	"maps/objects/chozobgwall01coltop/chozobgwall01coltop.bcmdl",
	"maps/fx/aquabubbles/aquabubbles01.bcmdl",
	"maps/fx/aquabubbles/aquabubbles02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel034.bcmdl",
	"maps/objects/cavpathrock03v3/cavpathrock03v3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_08.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_04.bcmdl",
	"maps/objects/chozohangcable02/chozohangcable02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_02.bcmdl",
	"actors/props/watercave10/models/watercave10.bcmdl",
	"maps/objects/magrock01/magrock01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_10.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca164sg_casca164.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_03.bcmdl",
	"actors/props/weightactivatedplatform_ammo/fx/shaft_ammo.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/verticaldust_scorpius.bcmdl",
	"maps/objects/chozohandrail02end/chozohandrail02end.bcmdl",
	"maps/objects/chozoallanimcable01_a/chozoallanimcable01_a.bcmdl",
	"maps/objects/chozohandrail04_1/chozohandrail04_1.bcmdl",
	"maps/objects/chozoroompath01x1/chozoroompath01x1.bcmdl",
	"maps/objects/cavpathrock03/cavpathrock03.bcmdl",
	"maps/objects/cavcrystal03/cavcrystal03.bcmdl",
	"maps/objects/chozopathpipescorner01/chozopathpipescorner01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_01sg_casca056.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_casca_02sg_casca057.bcmdl",
	"actors/props/pool_water15x4_gen/models/pool_water15x4_gen.bcmdl",
	"maps/objects/chozobgpipesend/chozobgpipesend.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_o1_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel02.bcmdl",
	"maps/objects/chozobgmagwalljoint/chozobgmagwalljoint.bcmdl",
	"actors/characters/scorpius/fx/trail_whiplash.bcmdl",
	"actors/props/cutmodel49wall03/models/cutmodel49wall03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_r6_mapmodel08.bcmdl",
	"maps/objects/cavpathrock03v2/cavpathrock03v2.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_o2_lightshaft04.bcmdl",
	"cutscenes/0001gameintro_fight/fx/animfresnel_aurascratch_border.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/absortionbody_fresnel.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/handmetroidnization_fresnel.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/scorpiusdissolveouter_ball.bcmdl",
	"cutscenes/0001gameintro_fight/fx/animfresnel_aurascratch.bcmdl",
	"cutscenes/0001gameintro_fight/fx/metroidnization_fresnel.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/handfresnel_scorpius.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/scorpiusdissolve_ball.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/scorpiusdissolveouter.bcmdl",
	"actors/characters/scorpius/fx/opticalcamo.bcmdl",
	"cutscenes/0001gameintro_fight/fx/animfresnel.bcmdl",
	"cutscenes/0001gameintro_fight/fx/animfresnel2.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/fresnel_ilum_tail.bcmdl",
	"cutscenes/0057scorpiusdeath/fx/scorpiusdissolve.bcmdl",
	"actors/characters/samus/fx/animfresnel.bcmdl",
	"actors/characters/scorpius/fx/damage.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_lshaft01.bcmdl",
	"maps/objects/chozostationfence02left/chozostationfence02left.bcmdl",
	"maps/objects/chozobgmagwallb01/chozobgmagwallb01.bcmdl",
	"maps/objects/chozostationfence02right/chozostationfence02right.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_px_cooldownzip.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_11.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_o1_lightshaft02.bcmdl",
	"maps/objects/chozoallassetbottle01/chozoallassetbottle01.bcmdl",
	"cutscenes/0001gameintro_space/fx/ship_propulsor.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/init_auras.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/rayscannon_048.bcmdl",
	"maps/objects/chozocavproto_07/chozocavproto_07.bcmdl",
	"cutscenes/0033sonarobtention/fx/rays_cube.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel057.bcmdl",
	"actors/props/rinkaunit/models/rinkaunit.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel044.bcmdl",
	"maps/fx/splashes/splashes_waterfall_1x3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_px_cooldownzip.bcmdl",
	"maps/objects/chozowallemmy01x4/chozowallemmy01x4.bcmdl",
	"maps/objects/coldzoneasset06/coldzoneasset06.bcmdl",
	"maps/objects/chozobgmagwallb02/chozobgmagwallb02.bcmdl",
	"maps/objects/chozoallassetbottle06/chozoallassetbottle06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_m4_mapmodel018.bcmdl",
	"maps/objects/chozobgpipes01x1/chozobgpipes01x1.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_04.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_05.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_06.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel06.bcmdl",
	"actors/props/footstepplatform/models/footstepplatform.bcmdl",
	"maps/objects/chozopipes01corner05/chozopipes01corner05.bcmdl",
	"maps/objects/chozomagemmypath01x1/chozomagemmypath01x1.bcmdl",
	"actors/props/weightactivatedplatform_map/models/weightactivatedplatform_map.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel00.bcmdl",
	"maps/fx/cooldownevent/snowparticles01.bcmdl",
	"maps/objects/chozobgmagwallb05/chozobgmagwallb05.bcmdl",
	"system/fx/generic/varia_feetrays_right.bcmdl",
	"maps/objects/chozowatercolum01g/chozowatercolum01g.bcmdl",
	"maps/objects/chozobgemmy01/chozobgemmy01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_breakable_casca158sg_casca158.bcmdl",
	"cutscenes/0001gameintro_fight/fx/hyperdash_trail.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_px_cooldownhot.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_lshaft05.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel04.bcmdl",
	"maps/objects/chozoallscaffold02/chozoallscaffold02.bcmdl",
	"maps/objects/chozobgpipescorner_03/chozobgpipescorner_03.bcmdl",
	"maps/objects/chozopathmag01x1/chozopathmag01x1.bcmdl",
	"maps/objects/chozoallanimcable02_a/chozoallanimcable02_a.bcmdl",
	"maps/objects/caverockborder07/caverockborder07.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031vfz_a4_vignette.bcmdl",
	"maps/objects/chozobgpath01x3/chozobgpath01x3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_22.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel01.bcmdl",
	"maps/objects/chozobgpath01x1/chozobgpath01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_o2_lightshaft05.bcmdl",
	"actors/characters/scorpius/fx/trail_grab.bcmdl",
	"maps/objects/chozopipes01corner01/chozopipes01corner01.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_final_04.bcmdl",
	"actors/props/stopstation_autool/models/stopstation_autool.bcmdl",
	"system/fx/generic/varia_trailsjump01.bcmdl",
	"actors/props/accesspoint/fx/hologram_base.bcmdl",
	"cutscenes/0055scorpiusphase2/fx/fromocitemtoinvi.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_073.bcmdl",
	"maps/objects/chozoallbgemmy01ax4/chozoallbgemmy01ax4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_039.bcmdl",
	"maps/objects/chozoemmybg01ax4/chozoemmybg01ax4.bcmdl",
	"maps/objects/chozoroomroof01/chozoroomroof01.bcmdl",
	"system/fx/generic/varia_shoulderrays.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_turbine_005_.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel055.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel058.bcmdl",
	"maps/objects/chozoallscaffold07/chozoallscaffold07.bcmdl",
	"actors/characters/chozocommander/fx/chargeenergy_commander.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_rays_wide.bcmdl",
	"maps/objects/frontchozowires03/frontchozowires03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel13.bcmdl",
	"actors/characters/scorpius/fx/trail_tailsmash.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_wallbox2clamp_015.bcmdl",
	"maps/objects/frontchozowires02/frontchozowires02.bcmdl",
	"maps/objects/chozowaterbg02corner/chozowaterbg02corner.bcmdl",
	"maps/objects/chozopipes01corner04/chozopipes01corner04.bcmdl",
	"maps/fx/aquabubbles/aquabubbles03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part007_o1_lightshaft02.bcmdl",
	"actors/characters/chozocommander/fx/kistrike_speedenergy.bcmdl",
	"actors/props/box_grapple_cv_001/fx/boxgrapplemesh.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_008.bcmdl",
	"maps/fx/splashes/splashes_waterfall_1x_cube.bcmdl",
	"system/fx/generic/varia_shoulderrays_var.bcmdl",
	"maps/fx/emmymist02/fx/emmymist02.bcmdl",
	"maps/fx/splashes/splashes_waterfall.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_planos.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part011_m1_mapmodel040.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_jg9_matte02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part028_s5_mapmodel_06.bcmdl",
	"maps/objects/chozobgcorner01/chozobgcorner01.bcmdl",
	"maps/objects/chozoallassetbottle04/chozoallassetbottle04.bcmdl",
	"system/fx/generic/varia_displacementaura.bcmdl",
	"maps/objects/chozoallassetbottle05/chozoallassetbottle05.bcmdl",
	"actors/props/fx_heat_door/fx/distortionplane.bcmdl",
	"maps/objects/chozopipes01corner03/chozopipes01corner03.bcmdl",
	"maps/objects/chozowaterbg01x1/chozowaterbg01x1.bcmdl",
	"maps/fx/magmaheat/magmaheatplane01.bcmdl",
	"maps/objects/chozoalltunnelbg01x1/chozoalltunnelbg01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part007_o1_lightshaft01.bcmdl",
	"actors/props/accesspoint/fx/hologram_letters.bcmdl",
	"maps/objects/chozosanccolumn02x3left/chozosanccolumn02x3left.bcmdl",
	"maps/objects/chozosanccolumn02x3right/chozosanccolumn02x3right.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel14.bcmdl",
	"maps/objects/cavscorpiusbones02/cavscorpiusbones02.bcmdl",
	"actors/props/fx_heat_tunnel/fx/distortion.bcmdl",
	"actors/props/fx_heat_tunnel/fx/heatplane.bcmdl",
	"actors/props/fx_heat_door/fx/heatplane.bcmdl",
	"maps/objects/chozoallscaffold01/chozoallscaffold01.bcmdl",
	"maps/objects/cavewater00/cavewater00.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/frontdustfinal.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e5_casca66000.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part017_e5_mapmodel04.bcmdl",
	"maps/objects/chozocolmag03/chozocolmag03.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/bodydustfinal.bcmdl",
	"actors/props/weightactivatedplatform_train/fx/shaft_train_vertical.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_009.bcmdl",
	"actors/props/weightactivatedplatform_teleport/fx/platform_glow.bcmdl",
	"actors/characters/hecathon/fx/disruptedtile.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_m5_mapmodel_042.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_cv_002.bcmdl",
	"maps/objects/cavcolumncrystal03/cavcolumncrystal03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_o2_lightshaft01.bcmdl",
	"maps/objects/chozobgwallemmycorner01/chozobgwallemmycorner01.bcmdl",
	"cutscenes/0053genericcupowerobtention/fx/rays_cannon.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_cv_004.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part027_r9_009.bcmdl",
	"maps/objects/cavscorpiusbones03/cavscorpiusbones03.bcmdl",
	"maps/objects/coldzoneasset02/coldzoneasset02.bcmdl",
	"maps/fx/splashes/splashes_waterfall_1x.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part010_s6_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part004_o6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part011_m1_vignette.bcmdl",
	"actors/props/weightactivatedplatform_teleport/fx/shaft_teleport.bcmdl",
	"maps/objects/chozopathpipescorner03/chozopathpipescorner03.bcmdl",
	"cutscenes/0001gameintro_fight/fx/commander_misil_trailsmoke.bcmdl",
	"maps/objects/chozoallbgemmy01x1/chozoallbgemmy01x1.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aurascratch_back.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aurascratch_fast.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aurascratch_wall.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aurascratch_waves.bcmdl",
	"maps/objects/chozoemmybg01x1/chozoemmybg01x1.bcmdl",
	"maps/objects/chozobgwall01col/chozobgwall01col.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_vignette007.bcmdl",
	"maps/objects/chozopathpipes02/chozopathpipes02.bcmdl",
	"maps/objects/chozopathpipes01x1/chozopathpipes01x1.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_final_02.bcmdl",
	"maps/objects/chozoallbgemmy01corniceext/chozoallbgemmy01corniceext.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_01.bcmdl",
	"maps/objects/chozoemmybg01corniceext/chozoemmybg01corniceext.bcmdl",
	"maps/objects/chozoborderemmyjoint04/chozoborderemmyjoint04.bcmdl",
	"system/fx/generic/varia_feetrays.bcmdl",
	"cutscenes/0001gameintro_space/fx/nebula_final_03.bcmdl",
	"maps/fx/aquasparks/aquasparks01.bcmdl",
	"maps/fx/aquasparks/aquasparks03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette002.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_o1_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o1_lightshaft02.bcmdl",
	"system/fx/generic/varia_bodyrays.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_o1_lightshaft01.bcmdl",
	"maps/objects/fxfiretornado01/fxfiretornado01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o1_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_s8_cooldown_01.bcmdl",
	"cutscenes/0001gameintro_fight/fx/aura_startrays_cannon.bcmdl",
	"maps/objects/chozoemmyborderwall02/chozoemmyborderwall02.bcmdl",
	"maps/objects/chozoalltunnelbg01corner/chozoalltunnelbg01corner.bcmdl",
	"maps/objects/chozoborderemmy02/chozoborderemmy02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part002_s5_mapmodel11.bcmdl",
	"maps/objects/magmaparticles01/magmaparticles01.bcmdl",
	"maps/objects/magmaparticles02/magmaparticles02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part012_e7_vignette004.bcmdl",
	"actors/props/elevator/fx/elevator_glow.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part021_e4_06.bcmdl",
	"maps/objects/chozoallbgemmy01cornice2x4/chozoallbgemmy01cornice2x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette_006.bcmdl",
	"maps/objects/chozoallassetbottleplat02/chozoallassetbottleplat02.bcmdl",
	"maps/objects/chozopathemmy02bgx1/chozopathemmy02bgx1.bcmdl",
	"actors/characters/scorpius/fx/trail_ballprick.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_04.bcmdl",
	"actors/props/weightactivatedplatform_teleport/fx/trails_inactive.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part004_o6_sg_vignette_10.bcmdl",
	"maps/objects/chozoallscaffold08/chozoallscaffold08.bcmdl",
	"maps/objects/snowparticles01/snowparticles01.bcmdl",
	"actors/props/doorlock/models/doorlock.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part005_e5_casca66000vig.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_floor_005.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_cunit_pe_turbine_glows_004.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part019_jg8_vignetteb.bcmdl",
	"maps/objects/lshaftgen01/lshaftgen01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette_007.bcmdl",
	"maps/objects/cavlittlerock01/cavlittlerock01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_e7_mattepaintbackground01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette_008.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part019_jg8_sg0001.bcmdl",
	"maps/fx/pipeleaks00/fx/pipeleaks00_fastdrops.bcmdl",
	"maps/fx/pipeleaks00/fx/pipeleaks00_largedrops.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part020_e10_vignette_001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part015_e6_vignette_005.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part001_s6_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_12.bcmdl",
	"maps/objects/chozobgwall01botx1/chozobgwall01botx1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part027_r9_mapmodel03.bcmdl",
	"maps/objects/chozoalltunnelbg01_in/chozoalltunnelbg01_in.bcmdl",
	"maps/objects/chozobgwall01topx1/chozobgwall01topx1.bcmdl",
	"maps/objects/lshaftcave01/lshaftcave01.bcmdl",
	"maps/objects/lshaftscorpius/lshaftscorpius.bcmdl",
	"maps/fx/effectcold01/fx/effectcold01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_mapmodel_07.bcmdl",
	"actors/props/cutmodel49wall01/models/cutmodel49wall01.bcmdl",
	"actors/props/doorcentralunit/fx/doorpannerplane.bcmdl",
	"maps/objects/chozoborderemmyjoint02/chozoborderemmyjoint02.bcmdl",
	"maps/objects/lshaftcave03/lshaftcave03.bcmdl",
	"maps/objects/lshaftcave04/lshaftcave04.bcmdl",
	"actors/characters/chozozombiex/fx/gridmudside.bcmdl",
	"maps/objects/lshaftcave02/lshaftcave02.bcmdl",
	"maps/objects/chozoallbgemmy01corniceint/chozoallbgemmy01corniceint.bcmdl",
	"maps/objects/cavewater01/cavewater01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part009_p_lightcut.bcmdl",
	"maps/objects/lshaftlamp02/lshaftlamp02.bcmdl",
	"actors/props/teleporter/fx/trail_inactive_top.bcmdl",
	"maps/fx/lightningstroke/lightningstroke7.bcmdl",
	"maps/fx/effectcold02/fx/effectcold02.bcmdl",
	"maps/fx/lightningstroke/lightningstroke5.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_mapmodel1434.bcmdl",
	"maps/objects/chozostationfence02/chozostationfence02.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part012_s8_cooldown_00.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part013_px_ice.bcmdl",
	"maps/fx/emmymist01/fx/emmymist01_left.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_14.bcmdl",
	"actors/characters/chozozombiex/fx/gridmudcenter.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_19.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_20.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_16.bcmdl",
	"maps/fx/lightningstroke/lightningstroke6.bcmdl",
	"maps/fx/lightningstroke/lightningstroke9.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_18.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_17.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_15.bcmdl",
	"maps/fx/lightningstroke/lightningstroke8.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel10.bcmdl",
	"maps/fx/lightningstroke/lightningstroke4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part020_e10_breakables00sg_casca_13.bcmdl",
	"cutscenes/0001gameintro_fight/fx/samus_metroidnization.bcmdl",
	"maps/objects/chozoalltunnelbg01x3b/chozoalltunnelbg01x3b.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/camerafog_scorpiuspresentation.bcmdl",
	"actors/props/watercave02/models/watercave02.bcmdl",
	"actors/items/drop_life_cut/models/drop_life_cut.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part031_a3_floorreflect.bcmdl",
	"cutscenes/0040sancemmypresentation_part2b/fx/fakelightshot.bcmdl",
	"cutscenes/0054scorpiuspresentation/fx/cameradust_samus.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/vignette_part023_o9_vignette2.bcmdl",
	"actors/props/ev_shi_ray01/models/ev_shi_ray01.bcmdl",
	"maps/objects/chozoallbgemmy01cornicex1/chozoallbgemmy01cornicex1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part021_e4_mapmodel06.bcmdl",
	"maps/objects/chozoemmybg01cornicex1/chozoemmybg01cornicex1.bcmdl",
	"maps/objects/chozoallbgemmy01cornice1x4/chozoallbgemmy01cornice1x4.bcmdl",
	"maps/objects/chozoemmybg01cornice1x4/chozoemmybg01cornice1x4.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part004_o6_water01.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_n6_plane.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part003_p0_reflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part014_p3_reflection.bcmdl",
	"maps/fx/lightningstroke/lightningstroke.bcmdl",
	"maps/fx/lightningstroke/lightningstroke2.bcmdl",
	"maps/fx/lightningstroke/lightningstroke3.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part015_e6_mapmodel09.bcmdl",
	"maps/fx/emmymist00/fx/emmymist00_right.bcmdl",
	"maps/fx/emmymist00/fx/emmymist00_left.bcmdl",
	"maps/objects/chozobgwall01x1/chozobgwall01x1.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_jg8_mapmodel_007b.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part023_o9_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_n6_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_n6_planereflection003.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part029_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part030_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part006_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part024_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_n6_planereflection001.bcmdl",
	"maps/levels/c10_samus/s010_cave/models/part019_n6_planereflection002.bcmdl",
	"maps/fx/cloudlightning/cloudquad00.bcmdl",
	"maps/fx/dustcorner00/fx/dustcorner00_center.bcmdl",
	"maps/fx/dustcorner00/fx/dustcorner00_center02.bcmdl",
	"maps/fx/dustcorner00/fx/dustcorner00_center03.bcmdl",
	"maps/fx/dustcorner00/fx/dustcorner00_left.bcmdl",
	"maps/fx/dustcorner00/fx/dustcorner00_right.bcmdl",
	"maps/fx/emmyzoneletters00/fx/emmyzoneletters00.bcmdl",
	"maps/fx/dustdebris/fx/dustdebris01.bcmdl",
	"maps/fx/dustdebris/fx/dustdebris02.bcmdl",
	"maps/fx/emmyventilationgridgas00/fx/emmyventilationgridgas01.bcmdl",
	"actors/characters/chozowarriorxnormal/models/chozowarriorxnormal.bcmdl",
	"actors/characters/chozowarriornormal/models/chozowarriornormal.bcmdl",
	"actors/characters/chozowarrior/fx/shieldbreak.bcmdl",
	"actors/characters/chozowarriorx/fx/mudwave01fx.bcmdl",
	"actors/characters/chozowarriorx/fx/mudwave02fx.bcmdl",
	"actors/characters/chozowarriorx/fx/backtrail_prep01.bcmdl",
	"actors/characters/chozowarriorx/fx/fronttrail_prep01.bcmdl",
	"actors/characters/chozowarrior/fx/lightningshield.bcmdl",
	"actors/characters/chozowarrior/fx/lightningchozo.bcmdl",
	"actors/characters/chozowarriorx/fx/mudbeam02fx.bcmdl",
	"actors/characters/takumaku/fx/chargemesh.bcmdl",
	"actors/characters/chozocommanderx/fx/materia_x.bcmdl",
	"actors/characters/chozowarrior/fx/damageshield.bcmdl",
	"actors/characters/chozowarrior/fx/trail_start_new_front_right.bcmdl",
	"actors/characters/chozowarrior/fx/trail_start_new_front.bcmdl",
	"actors/characters/chozowarriorx/fx/2impact_trail.bcmdl",
	"actors/characters/chozowarriorx/fx/preptrail02_grab.bcmdl",
	"actors/characters/chozowarrior/fx/trail_end_new_front.bcmdl",
	"actors/characters/chozowarrior/fx/trail_end_new_back.bcmdl",
	"actors/characters/chozowarriorx/fx/preptrail02_grab_back.bcmdl",
	"actors/characters/chozowarrior/fx/trail_start_new_back_right.bcmdl",
	"actors/characters/chozowarrior/fx/trail_start_new_back.bcmdl",
	"actors/characters/chozowarriorx/fx/mudbeamsplash01fx.bcmdl",
	"actors/characters/chozowarriorx/fx/mudtrail.bcmdl",
	"actors/characters/chozowarrior/fx/trail_attack_end_01.bcmdl",
	"actors/characters/chozowarrior/fx/vertical_trail.bcmdl",
	"actors/characters/chozowarrior/fx/trail_end_new_front_right.bcmdl",
	"actors/characters/chozowarriorx/fx/trailflip_back_right.bcmdl",
	"actors/characters/chozowarrior/fx/trail_attack_end_02.bcmdl",
	"actors/characters/chozowarriorx/fx/trailflip_back.bcmdl",
	"actors/characters/chozowarriorx/fx/trailflip_front.bcmdl",
	"actors/characters/chozowarriorx/fx/trailflip_front_right.bcmdl",
	"actors/characters/chozowarrior/fx/trail_end_new_back_right.bcmdl",
	"actors/characters/chozowarriorx/fx/spike_start_mesh.bcmdl",
	"actors/characters/chozowarrior/fx/chozotrail.bcmdl",
	"actors/characters/chozowarrior/fx/trail_attack_02.bcmdl",
	"actors/characters/chozowarrior/fx/trail_attack_right.bcmdl",
	"actors/characters/chozowarriorx/fx/trailspike_left.bcmdl",
	"actors/characters/chozowarrior/fx/trail_verticalattack_01.bcmdl",
	"actors/characters/gobbler/models/gobbler_test.bcmdl",
	"actors/characters/goliath/models/goliath.bcmdl",
	"actors/characters/warlotus/models/warlotus.bcmdl",
	"actors/characters/iceflea/fx/ice_break.bcmdl",
	"actors/characters/hecathon/models/hecathon.bcmdl",
	"actors/characters/bigkranx/models/bigkranx.bcmdl",
	"actors/characters/obsydomithon/models/obsydomithon.bcmdl",
	"actors/characters/chozozombiex/models/chozozombiex.bcmdl",
	"actors/characters/autclast/models/autclast.bcmdl",
	"actors/characters/takumaku/models/takumaku.bcmdl",
	"actors/characters/klaida/models/klaida.bcmdl",
	"actors/characters/sunnap/models/sunnap.bcmdl",
	"actors/characters/nailugger/models/nailugger.bcmdl",
	"actors/characters/iceflea/models/iceflea.bcmdl",
	"actors/characters/rockdiver/models/rockdiver.bcmdl",
	"actors/characters/infester/models/infester.bcmdl",
	"actors/characters/poisonfly/models/poisonfly.bcmdl",
	"actors/characters/rodomithonx/models/rodomithonx.bcmdl",
	"actors/characters/caterzilla/models/caterzilla.bcmdl",
	"actors/characters/chozozombiex/fx/walkmud01.bcmdl",
	"actors/characters/autool/models/autool.bcmdl",
	"actors/characters/chozozombiex/fx/runattackmud01.bcmdl",
	"actors/characters/chozozombiex/fx/attackmud01.bcmdl",
	"actors/characters/chozozombiex/fx/turnmud01.bcmdl",
	"actors/characters/dropter/models/dropter.bcmdl",
	"actors/characters/autclast/fx/death.bcmdl",
	"actors/characters/sabotoru/fx/bubbles.bcmdl",
	"actors/characters/kreep/models/kreep.bcmdl",
	"actors/characters/spitclawk/models/spitclawk.bcmdl",
	"actors/characters/autclast/fx/rays.bcmdl",
	"actors/characters/autool/fx/autooldamagefx.bcmdl",
	"actors/props/ice_cube/models/ice_cube.bcmdl",
	"actors/characters/slugger/fx/sluggerball.bcmdl",
	"actors/characters/goliath/fx/displacement_nonmelee.bcmdl",
	"actors/characters/rinka/fx/rinkasphere.bcmdl",
	"actors/characters/goliath/fx/nonmeleerays.bcmdl",
	"actors/characters/superquetzoa/fx/rayshield_glow.bcmdl",
	"actors/characters/autclast/fx/autclastdamage.bcmdl",
	"actors/characters/goliath/fx/surfaceanimfresnel.bcmdl",
	"actors/characters/iceflea/fx/explosion_fresnel.bcmdl",
	"actors/weapons/vulkranmagmaball/fx/magmaball.bcmdl",
	"actors/props/ice_casquery/models/ice_casquery.bcmdl",
	"actors/characters/obsydomithon/fx/rocksgravitational.bcmdl",
	"actors/weapons/infesterball/models/infesterball.bcmdl",
	"actors/characters/bigfist/fx/trail4m.bcmdl",
	"actors/characters/bigfist/fx/trail6m.bcmdl",
	"actors/characters/bigfist/fx/trail5m.bcmdl",
	"actors/characters/poisonfly/fx/poisonflyconemesh.bcmdl",
	"actors/characters/nailugger/fx/trails_smoke.bcmdl",
	"actors/characters/goliath/fx/trail.bcmdl",
	"actors/characters/rinka/models/rinka.bcmdl",
	"actors/characters/obsydomithon/fx/dustgravitational.bcmdl",
	"actors/characters/obsydomithon/fx/gasleak.bcmdl",
	"actors/characters/spittail/fx/shockwave_particles.bcmdl",
	"actors/characters/rinka/fx/rinkatrail.bcmdl",
	"actors/weapons/nailongthorn/models/nailongthorn_onlaunch.bcmdl",
	"actors/characters/chozozombiex/fx/gridmud01.bcmdl",
	"actors/characters/rodomithonx/fx/fireoverwall.bcmdl",
	"actors/characters/obsydomithon/fx/fireoverwall.bcmdl",
	"actors/characters/emmy/fx/emmyglass.bcmdl",
	"actors/weapons/emmywave/fx/waveswall.bcmdl",
	"actors/weapons/emmywave/fx/waves.bcmdl",
	"actors/characters/emmy/fx/speedbooster_cover.bcmdl",
	"actors/characters/emmy/fx/protectorfresnel.bcmdl",
	"actors/characters/emmy/fx/dissolve_cubes_emmy.bcmdl",
	"actors/characters/emmyforest/fx/energy_absortion_forest.bcmdl",
	"actors/characters/emmymagma/fx/energy_absortion_magma.bcmdl",
	"actors/characters/emmycave/fx/energy_absortion.bcmdl",
	"actors/characters/emmylab/fx/energy_absortion_lab.bcmdl",
	"actors/characters/emmysanc/fx/energy_absortion_sanc.bcmdl",
	"actors/characters/emmy/fx/dissolvedeath_internal_emmy.bcmdl",
	"actors/characters/emmy/fx/dissolvedeath_emmy.bcmdl",
	"actors/characters/emmycave/fx/animfresnel_armor.bcmdl",
	"actors/characters/emmy/fx/eyefresnel.bcmdl",
	"actors/characters/emmy/models/pulse.bcmdl",
	"actors/characters/emmy/models/pulse_bg.bcmdl",
	"system/engine/models/dummy.bcmdl",
	"actors/characters/cucannon/models/cucannon.bcmdl",
	"actors/weapons/cucannonbeam/fx/cucannonbeam_projectile.bcmdl",
	"actors/characters/cucannon/fx/charge_energy.bcmdl",
	"actors/characters/scorpius/fx/wallhit_impactshaft.bcmdl",
	"actors/characters/scorpius/fx/wallhit_fastflash.bcmdl",
	"actors/characters/scorpius/fx/wallhit_mesh.bcmdl",
	"actors/characters/scorpius/fx/gas_mouth.bcmdl",
	"actors/characters/scorpius/fx/wall_energy.bcmdl",
	"actors/weapons/scorpiuspoisonousspit/models/scorpiuspoisonousspit.bcmdl",
	"actors/weapons/scorpiuspoisonousspit/fx/tailballspit.bcmdl",
	"actors/characters/scorpius/fx/wallhit_decal.bcmdl",
	"actors/props/ev_lavapump_mg_001/models/ev_lavapump_mg_001.bcmdl",
	"actors/props/cut_cooldownboss_machine/models/cut_cooldownboss_machine.bcmdl",
	"maps/objects/savestationr/savestationr.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel14.bcmdl",
	"maps/objects/maproom001l/maproom001l.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel04.bcmdl",
	"actors/characters/cooldownxboss/models/cooldownxboss.bcmdl",
	"actors/props/ev_kraid_structure/models/ev_kraid_structure.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel03.bcmdl",
	"actors/characters/emmymagma/models/emmymagma.bcmdl",
	"actors/props/wagontrain/models/wagontrain.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel07.bcmdl",
	"actors/characters/kraid/models/kraid.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel02.bcmdl",
	"actors/props/ev_kraid_symmetrywall/models/ev_kraid_symmetrywall.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_027.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel03.bcmdl",
	"maps/objects/chozomagmapistonbg/chozomagmapistonbg.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel02.bcmdl",
	"actors/props/ev_kraid_symmetrywalldome/models/ev_kraid_symmetrywalldome.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_25.bcmdl",
	"actors/props/ev_kraid_platform/models/ev_kraid_platform.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_14.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel18.bcmdl",
	"actors/props/ev_kraid_platform_post/models/ev_kraid_platform_post.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_p2_columnsbreakpost.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_p2_columnsbreak.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel33.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_20.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part024_e2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part024_e2_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel34.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_decal00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_station.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel12.bcmdl",
	"actors/props/breakablemag005/models/breakablemag005.bcmdl",
	"actors/props/ev_kraid_structure_ingame/models/ev_kraid_structure_ingame.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel01.bcmdl",
	"actors/props/ev_dspiston_mg_001/models/ev_dspiston_mg_001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel05.bcmdl",
	"maps/objects/chozomagassetduct01/chozomagassetduct01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel01.bcmdl",
	"actors/props/db_hdoor_mg_001/models/db_hdoor_mg_001.bcmdl",
	"actors/props/breakablemag012/models/breakablemag012.bcmdl",
	"actors/props/ev_kraid_rails/models/ev_kraid_rails.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel32.bcmdl",
	"actors/props/ev_tpiston_mg_001/models/ev_tpiston_mg_001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel03.bcmdl",
	"actors/props/cut_81_lava/models/cut_81_lava.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel43.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_p_lava.bcmdl",
	"actors/props/cut_78_roof/models/cut_78_roof.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel03.bcmdl",
	"actors/props/db_hdoor_mg_002/models/db_hdoor_mg_002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel21.bcmdl",
	"maps/objects/chozostationwagonbgmagma/chozostationwagonbgmagma.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel14.bcmdl",
	"actors/props/db_dif_mg_001/models/db_dif_mg_001.bcmdl",
	"actors/weapons/cooldownxbosslavacarpet/fx/lavafloor.bcmdl",
	"actors/props/ev_kraid_entrance/models/ev_kraid_entrance.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel53.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel35.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel02.bcmdl",
	"actors/props/db_reg_mg_018/models/db_reg_mg_018.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_18.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel41.bcmdl",
	"actors/props/db_reg_mg_020/models/db_reg_mg_020.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_decals04.bcmdl",
	"actors/characters/core_x/models/core_x.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel01.bcmdl",
	"actors/props/breakablemag001/models/breakablemag001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel11.bcmdl",
	"actors/props/db_reg_mg_016/models/db_reg_mg_016.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel16.bcmdl",
	"actors/props/breakablemag004/models/breakablemag004.bcmdl",
	"actors/props/fusiblebox/models/fusiblebox.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_pipes01.bcmdl",
	"actors/props/db_hdoor_mg_002b/models/db_hdoor_mg_002b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_22.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel04.bcmdl",
	"actors/props/pool_lava_mg_014/models/pool_lava_mg_014.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel00.bcmdl",
	"actors/props/breakablemag010/models/breakablemag010.bcmdl",
	"actors/props/db_reg_mg_019/models/db_reg_mg_019.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel45.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel25.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_03.bcmdl",
	"actors/props/db_dside_mg_002b/models/db_dside_mg_002b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca12.bcmdl",
	"maps/objects/chozomagnetglove01end02/chozomagnetglove01end02.bcmdl",
	"actors/props/pool_lava_mg_003/models/pool_lava_mg_003.bcmdl",
	"maps/objects/chozomagblueemitter01/chozomagblueemitter01.bcmdl",
	"actors/props/breakablemag009/models/breakablemag009.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel40.bcmdl",
	"actors/props/breakablemag003/models/breakablemag003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables02sg_casca005sg_casca006.bcmdl",
	"actors/props/fusiblebox_broken/models/fusiblebox_broken.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel01.bcmdl",
	"actors/props/db_dif_mg_002/models/db_dif_mg_002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel27.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel27.bcmdl",
	"actors/props/breakablemag014/models/breakablemag014.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel50.bcmdl",
	"actors/props/fan_cooldown/models/fan_cooldown_mud.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel05.bcmdl",
	"actors/props/breakablemag007/models/breakablemag007.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel04.bcmdl",
	"actors/props/breakablemag008/models/breakablemag008.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_decal00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_24.bcmdl",
	"actors/props/db_dside_mg_003b/models/db_dside_mg_003b.bcmdl",
	"actors/props/db_dside_mg_001b/models/db_dside_mg_001b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_19.bcmdl",
	"actors/props/fan_cooldown/models/fan_cooldown_mud_02.bcmdl",
	"actors/props/fan_cooldown/models/fan_cooldown.bcmdl",
	"maps/objects/chozoallmechhol01/chozoallmechhol01.bcmdl",
	"actors/props/db_dside_mg_003/models/db_dside_mg_003.bcmdl",
	"actors/props/db_dside_mg_002/models/db_dside_mg_002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel14.bcmdl",
	"actors/props/db_dside_mg_001/models/db_dside_mg_001.bcmdl",
	"actors/props/cut_81_wall01/models/cut_81_wall01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_decal01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part024_e2_decal00.bcmdl",
	"actors/props/breakablemag013/models/breakablemag013.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel20.bcmdl",
	"maps/objects/gravitysuit_chozo/gravitysuit_chozo.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel10.bcmdl",
	"actors/props/wagontrain/fx/trainlightning.bcmdl",
	"maps/objects/chozostationwagon01low/chozostationwagon01low.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel12.bcmdl",
	"actors/props/cut_81_ball_slime/models/cut_81_ball_slime.bcmdl",
	"actors/props/emmyvalve_reg_gen_001/models/emmyvalve_reg_gen_001.bcmdl",
	"actors/props/pool_lava_mg_017/models/pool_lava_mg_017.bcmdl",
	"maps/objects/chozopathmag03x3/chozopathmag03x3.bcmdl",
	"actors/props/pool_lava_mg_007/models/pool_lava_mg_007.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables01sg_casca003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel08.bcmdl",
	"actors/props/kraidshackles/models/kraidshackles.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel07.bcmdl",
	"maps/objects/chozoallasset02/chozoallasset02.bcmdl",
	"actors/props/breakablemag002/models/breakablemag002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel01.bcmdl",
	"maps/objects/chozoallmechcolum01/chozoallmechcolum01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_26.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables04sg_casca001sg_casca002sg_casca003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel31.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel29.bcmdl",
	"maps/objects/chozomagassetn04/chozomagassetn04.bcmdl",
	"actors/weapons/cooldownxbosswindtunneldamagetrigger/fx/wall_bubbles.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_x1_mapmodel_1902.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables03sg_casca004.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables06sg_casca005.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable09sg_casca046.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable10sg_casca041.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part029_o8_01.bcmdl",
	"actors/props/pistonmag01/models/pistonmag01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel37.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel36.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_028.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca49.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel44.bcmdl",
	"maps/objects/chozoallwagonrail01x16/chozoallwagonrail01x16.bcmdl",
	"maps/objects/chozomagmechanicarm01/chozomagmechanicarm01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca48.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable11sg_casca045.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable12sg_casca042.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable06sg_casca145.bcmdl",
	"maps/objects/chozobgwalljoint/chozobgwalljoint.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mattepaintrocks02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable01sg_casca146.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable02sg_casca147.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable03sg_casca148.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable18sg_casca18008.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable19sg_casca18009.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable20sg_casca18010.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable04sg_casca149.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable05sg_casca150.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable17sg_casca18007.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable16sg_casca18006.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part018_jp1_planereflect_01.bcmdl",
	"actors/props/pool_lava_68x6/models/pool_lava_68x6.bcmdl",
	"maps/objects/chozoaqatrezzorot01_a/chozoaqatrezzorot01_a.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables09sg_casca173.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mattepaintrocks01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca45.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca42.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca34.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel06.bcmdl",
	"maps/objects/chozoallmecharm01_a/chozoallmecharm01_a.bcmdl",
	"maps/objects/chozoallmecharm01_b/chozoallmecharm01_b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables01sg_casca175.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_x1_mapmodel_1900.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca46.bcmdl",
	"maps/objects/chozoaqbggate01/chozoaqbggate01.bcmdl",
	"maps/objects/chozoemmytunnelbg01t/chozoemmytunnelbg01t.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca43.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables07sg_casca174.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca32.bcmdl",
	"maps/objects/chozoallbgemmy01dx4/chozoallbgemmy01dx4.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables11sg_casca176.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel18.bcmdl",
	"maps/objects/chozopathmag03x1/chozopathmag03x1.bcmdl",
	"maps/objects/magkraidheadcorridor01/magkraidheadcorridor01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca47.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca44.bcmdl",
	"cutscenes/0081cooldowndeath/fx/magmabasecylinder.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel25.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part010_r7_vignette01.bcmdl",
	"actors/items/powerup_diffusionbeam/models/powerup_diffusionbeam.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca33.bcmdl",
	"maps/objects/chozoemmytunnelbg01corner/chozoemmytunnelbg01corner.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_decal00.bcmdl",
	"actors/props/weightactivatedplatform_train/models/platform_wagontrailplatfom.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_breakables05sg_casca001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca31.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s2_mattepaint_skybox.bcmdl",
	"actors/props/box_magnet_mg_01/models/box_magnet_mg_01.bcmdl",
	"actors/events/mapev_insects/models/mapev_insects.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel24.bcmdl",
	"maps/objects/chozomagasset02/chozomagasset02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part021_r7_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel28.bcmdl",
	"maps/objects/chozobgmagwall11x06/chozobgmagwall11x06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part020_r6_mapmodel00.bcmdl",
	"actors/props/ev_hpiston_mg_001_disabled/models/ev_hpiston_mg_001_disabled.bcmdl",
	"actors/props/ev_hpiston_mg_001/models/ev_hpiston_mg_001.bcmdl",
	"maps/objects/chozobgmagwall11x09/chozobgmagwall11x09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel51.bcmdl",
	"actors/props/box_magnet_mg_003/models/box_magnet_mg_003.bcmdl",
	"cutscenes/0078cooldownpresentation/fx/samus_splashenter.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part015_e7_mapmodel00.bcmdl",
	"cutscenes/0061kraiddeath/fx/lava_explosion01_anim.bcmdl",
	"maps/fx/lavadrops/lava_drops05_anim.bcmdl",
	"maps/fx/lavadrops/lava_drops07_anim.bcmdl",
	"maps/fx/lavadrops/lava_drops06_anim.bcmdl",
	"maps/objects/chozostationwheel/chozostationwheel.bcmdl",
	"cutscenes/0061kraiddeath/fx/lava_explosion00_anim.bcmdl",
	"actors/props/pool_lava_19x2/models/pool_lava_19x2.bcmdl",
	"maps/objects/chozomagassetrobot01a/chozomagassetrobot01a.bcmdl",
	"maps/objects/chozomagassetrobot02a/chozomagassetrobot02a.bcmdl",
	"maps/objects/chozobgmagwall11bx06/chozobgmagwall11bx06.bcmdl",
	"maps/objects/chozomagassetrobotr01a/chozomagassetrobotr01a.bcmdl",
	"maps/objects/chozomagplatform150/chozomagplatform150.bcmdl",
	"maps/objects/chozomagcolumn01/chozomagcolumn01.bcmdl",
	"cutscenes/0061kraiddeath/fx/lava_explosion02_anim.bcmdl",
	"maps/fx/lavasplashes/lava_explosion02_anim.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel05.bcmdl",
	"maps/objects/chozomagassetrobotr02a/chozomagassetrobotr02a.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca38.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca27.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable08sg_casca040.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable07sg_casca047.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables03sg_casca130.bcmdl",
	"maps/objects/chozobgmagwallendright/chozobgmagwallendright.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s2_mattepaint_rocks.bcmdl",
	"actors/props/mblauncher_launcher_gen_001/models/mblauncher_launcher_gen_001.bcmdl",
	"maps/objects/chozopathmag03endr/chozopathmag03endr.bcmdl",
	"actors/props/pool_lava_45x2_kraid_death/models/pool_lava_45x2_kraid_death.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables04sg_casca129sg_casca126.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca37.bcmdl",
	"maps/objects/chozobgmagwallendleft/chozobgmagwallendleft.bcmdl",
	"maps/objects/chozopathmag03endl/chozopathmag03endl.bcmdl",
	"cutscenes/0081cooldowndeath/fx/plasmabeam_chargedfull.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables00sg_casca131.bcmdl",
	"maps/objects/magnetglovesp01cornerout90/magnetglovesp01cornerout90.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca06.bcmdl",
	"maps/objects/chozobgmagwall06joint/chozobgmagwall06joint.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables06sg_casca128sg_casca127.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables21sg_casca130.bcmdl",
	"maps/objects/chozomagassetn_02/chozomagassetn_02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables02sg_casca130sg_casca124.bcmdl",
	"maps/objects/magdigrock05/magdigrock05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables20sg_casca126.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables23sg_casca131.bcmdl",
	"actors/events/mapev_magma_crab/models/mapev_magma_crab.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables18sg_casca127.bcmdl",
	"actors/props/mblauncher_exit_gen_001/models/mblauncher_exit_gen_001.bcmdl",
	"maps/objects/magnetglovesp01cornerin/magnetglovesp01cornerin.bcmdl",
	"maps/objects/chozomagassetn_05/chozomagassetn_05.bcmdl",
	"maps/objects/chozopipesthermal02cornerinvert/chozopipesthermal02cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal03cornerinvert/chozopipesthermal03cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal04cornerinvert/chozopipesthermal04cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal06cornerinvert/chozopipesthermal06cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal07cornerinvert/chozopipesthermal07cornerinvert.bcmdl",
	"maps/objects/chozopipesthermal02corner/chozopipesthermal02corner.bcmdl",
	"maps/objects/chozopipesthermal03corner/chozopipesthermal03corner.bcmdl",
	"maps/objects/chozopipesthermal04corner/chozopipesthermal04corner.bcmdl",
	"maps/objects/chozopipesthermal05corner/chozopipesthermal05corner.bcmdl",
	"maps/objects/chozopipesthermal07corner/chozopipesthermal07corner.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables22sg_casca124.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_decal01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables13sg_casca109.bcmdl",
	"maps/objects/chozomagassetduct02/chozomagassetduct02.bcmdl",
	"cutscenes/0081cooldowndeath/fx/firefusible.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part003_x1_vignette_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables12sg_casca105.bcmdl",
	"actors/spawnpoints/spawnpointcaterzilla/models/spawnpointcaterzillawall.bcmdl",
	"maps/objects/chozoalltunnel01curve/chozoalltunnel01curve.bcmdl",
	"actors/props/piston_right_kraid/models/piston_right_kraid.bcmdl",
	"maps/objects/chozobgmagwall04/chozobgmagwall04.bcmdl",
	"maps/objects/magdigrock06/magdigrock06.bcmdl",
	"maps/objects/chozoemmytunnelbg01x1l/chozoemmytunnelbg01x1l.bcmdl",
	"maps/objects/chozoemmytunnelbg01x1r/chozoemmytunnelbg01x1r.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel46.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel14.bcmdl",
	"actors/props/pool_lava_mg_001/models/pool_lava_mg_001.bcmdl",
	"maps/objects/chozostationpath01x4/chozostationpath01x4.bcmdl",
	"maps/objects/chozopathmag02x4/chozopathmag02x4.bcmdl",
	"actors/props/pool_lava_mg_005/models/pool_lava_mg_005.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable15sg_casca039.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel38.bcmdl",
	"maps/objects/chozopipesthermal02x3/chozopipesthermal02x3.bcmdl",
	"maps/objects/chozopipesthermal04x3/chozopipesthermal04x3.bcmdl",
	"maps/objects/chozopipesthermal05x3/chozopipesthermal05x3.bcmdl",
	"maps/objects/chozopipesthermal06x3/chozopipesthermal06x3.bcmdl",
	"maps/objects/chozopipesthermal07x3/chozopipesthermal07x3.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables14sg_casca106.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables16sg_casca009.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel47.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables14sg_casca011.bcmdl",
	"maps/objects/magdigrocklava02/magdigrocklava02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part025_r5_vignette00.bcmdl",
	"cutscenes/0081cooldowndeath/fx/magmalaser_base.bcmdl",
	"maps/objects/magdigrock04/magdigrock04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables10sg_casca104.bcmdl",
	"actors/props/mblauncher_exit_kraid/models/mblauncher_exit_kraid.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel48.bcmdl",
	"actors/props/wagontrain/fx/forcefield.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_a8_mattepaintbackgorund01.bcmdl",
	"maps/objects/chozoemmybg01tur2/chozoemmybg01tur2.bcmdl",
	"maps/objects/magkraidheadcorridor02/magkraidheadcorridor02.bcmdl",
	"actors/props/pool_lava_mg_019/models/pool_lava_mg_019.bcmdl",
	"actors/events/mapev_lightinsects/models/mapev_lightinsects.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables05sg_casca129.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_x1_mapmodel_1901.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca40.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca29.bcmdl",
	"actors/props/pool_lava_mg_002/models/pool_lava_mg_002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca41.bcmdl",
	"actors/props/pool_lava_mg_011/models/pool_lava_mg_011.bcmdl",
	"maps/objects/chozopathmag03x1b/chozopathmag03x1b.bcmdl",
	"maps/objects/magrockborderlava01/magrockborderlava01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca00.bcmdl",
	"maps/objects/magrockborderlava03/magrockborderlava03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables19sg_casca129.bcmdl",
	"maps/objects/chozoaqpipejoint02/chozoaqpipejoint02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_mapmodel54.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca19.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca20.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca21.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca22.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca11.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca12.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca13.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca14.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca16.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca18.bcmdl",
	"actors/props/pool_lava_mg_008/models/pool_lava_mg_008.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca36.bcmdl",
	"actors/props/shootactivatormag01/models/shootactivatormag01.bcmdl",
	"actors/props/shootactivatoroff/models/shootactivatoroff.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables08sg_casca128.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca03.bcmdl",
	"maps/objects/chozoalltunnel01x3/chozoalltunnel01x3.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part001_r12_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca39.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_x1_mapmodel_1904.bcmdl",
	"maps/objects/chozomagassetrobot01b/chozomagassetrobot01b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables31sg_casca023.bcmdl",
	"maps/objects/chozomagassetrobot02b/chozomagassetrobot02b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables18sg_casca008.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables17sg_casca128.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_decals01.bcmdl",
	"maps/objects/magdigrock01/magdigrock01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables12sg_casca014.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca30.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca13.bcmdl",
	"maps/objects/chozopathmag02_endr/chozopathmag02_endr.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca14.bcmdl",
	"maps/objects/magdigrockbglava01/magdigrockbglava01.bcmdl",
	"maps/objects/magmeltrock02/magmeltrock02.bcmdl",
	"maps/objects/magrockborderlava02/magrockborderlava02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca28.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables10sg_casca131sg_casca125.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel00.bcmdl",
	"maps/objects/magdigrockbg01/magdigrockbg01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables11sg_casca110.bcmdl",
	"maps/objects/chozopathmag02_endl/chozopathmag02_endl.bcmdl",
	"actors/props/pool_lava_7x2/models/pool_lava_7x2.bcmdl",
	"maps/objects/magdigrocklava03/magdigrocklava03.bcmdl",
	"maps/objects/magdigrockplatformlava01/magdigrockplatformlava01.bcmdl",
	"maps/objects/chozoaqexteriorwall02/chozoaqexteriorwall02.bcmdl",
	"maps/objects/magnetziplinesp01x2/magnetziplinesp01x2.bcmdl",
	"maps/objects/magdigrockplatform01/magdigrockplatform01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables13sg_casca012.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca015sg_casca68003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel05pipes.bcmdl",
	"maps/objects/magnetglovesp01xhalf2/magnetglovesp01xhalf2.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables16sg_casca125.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca02.bcmdl",
	"maps/objects/magmeltrockplatform01/magmeltrockplatform01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca00.bcmdl",
	"maps/objects/magmeltrock01/magmeltrock01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca014sg_casca68002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca016sg_casca68000.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables09sg_casca111.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part032_n2_mapmodel01_vignette.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel39.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca017sg_casca68001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_21.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_x1_lava_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part002_n2_mapmodel01_vignette.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel25.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_mg_001.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_mg_003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part001_r12_mapmodel15.bcmdl",
	"actors/props/weightactivatedplatform_train/fx/shaft_train.bcmdl",
	"maps/objects/magdigrockwalllava02/magdigrockwalllava02.bcmdl",
	"maps/objects/magvulkraneggs/magvulkraneggs.bcmdl",
	"maps/objects/magdigrockwall02/magdigrockwall02.bcmdl",
	"maps/objects/magrockborderlava04/magrockborderlava04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca172.bcmdl",
	"maps/objects/chozohandrail04_stairs2/chozohandrail04_stairs2.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_17.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel03pipes.bcmdl",
	"maps/objects/chozohandrail04_stairs/chozohandrail04_stairs.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables15sg_casca010.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables32sg_casca024.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_vignette02.bcmdl",
	"maps/objects/magdigrockwalllava03/magdigrockwalllava03.bcmdl",
	"maps/objects/magdigrock03/magdigrock03.bcmdl",
	"maps/objects/magdigrockwall03/magdigrockwall03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_breakables17sg_casca013.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_x1_mapmodel00.bcmdl",
	"maps/objects/magdigrocklava05/magdigrocklava05.bcmdl",
	"maps/objects/chozoallpathgenjoint03/chozoallpathgenjoint03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables35sg_casca022.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_lava01.bcmdl",
	"maps/objects/magdigrockwalllava01/magdigrockwalllava01.bcmdl",
	"maps/objects/magdigrockwall01/magdigrockwall01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables34sg_casca021.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables27sg_casca168.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables24sg_casca171.bcmdl",
	"actors/props/kraidspike_cntk/models/kraidspike_cntk.bcmdl",
	"actors/props/ev_kraid_spike/models/ev_kraid_spike.bcmdl",
	"maps/objects/chozoalltunnelborder01x4a/chozoalltunnelborder01x4a.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables28sg_casca165.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel30.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca011sg_casca69005.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables29sg_casca170.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables33sg_casca020.bcmdl",
	"maps/objects/chozoallbggen02x4/chozoallbggen02x4.bcmdl",
	"maps/objects/chozopathmag02x1a/chozopathmag02x1a.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca008sg_casca69002.bcmdl",
	"maps/objects/chozopathmag02x1b/chozopathmag02x1b.bcmdl",
	"actors/props/pool_lava_4x2/models/pool_lava_4x2.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_lava02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca009sg_casca69001.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca010sg_casca69000.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_x1_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca012sg_casca69003.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca013sg_casca69004.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel01b.bcmdl",
	"maps/objects/chozostationpath01end/chozostationpath01end.bcmdl",
	"maps/objects/chozopipesthermal02x1/chozopipesthermal02x1.bcmdl",
	"maps/objects/chozopipesthermal03x1/chozopipesthermal03x1.bcmdl",
	"maps/objects/chozopipesthermal04x1/chozopipesthermal04x1.bcmdl",
	"maps/objects/chozopipesthermal07x1/chozopipesthermal07x1.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_e3_breakables01sg_casca007.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable13sg_casca044.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable14sg_casca043.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable00sg_casca139.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables25sg_casca164.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel06pipe.bcmdl",
	"maps/objects/chozoallwall02x3/chozoallwall02x3.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables30sg_casca166.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_breakables26sg_casca169.bcmdl",
	"maps/objects/chozoalltunnel01x1/chozoalltunnel01x1.bcmdl",
	"maps/objects/chozoallbggen02x1/chozoallbggen02x1.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_decals02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mattepaintbackgorund02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel12.bcmdl",
	"maps/objects/magfrontpatch01/magfrontpatch01.bcmdl",
	"maps/objects/magfrontpatch02/magfrontpatch02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_x1_mapmodel00.bcmdl",
	"maps/objects/chozostationpath01x1/chozostationpath01x1.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_x1_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_mapmodel018_breakable.bcmdl",
	"maps/objects/magdigrocklava04/magdigrocklava04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part027_n2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_tapa.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_mapmodel07.bcmdl",
	"maps/objects/chozobgmagwall03x1/chozobgmagwall03x1.bcmdl",
	"cutscenes/0081cooldowndeath/fx/magma_center.bcmdl",
	"maps/objects/chozobgmagmawall08/chozobgmagmawall08.bcmdl",
	"maps/objects/chozobgwall08/chozobgwall08.bcmdl",
	"cutscenes/0081cooldowndeath/fx/magma_wave.bcmdl",
	"maps/objects/magfrontpatch03/magfrontpatch03.bcmdl",
	"maps/objects/magfrontpatch04/magfrontpatch04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_sg_casca153.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_sg_casca154.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca25.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca23.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mattepaintclouds01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel03.bcmdl",
	"maps/objects/chozobgmagwall11x01/chozobgmagwall11x01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_lava01.bcmdl",
	"maps/objects/magvulkraneggs01/magvulkraneggs01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca26.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca35.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca24.bcmdl",
	"maps/objects/chozobgmagmawall07/chozobgmagmawall07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mattepaintbackgorund01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part010_r7_sg_casca152.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca50.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_breakables00sg_casca51.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_breakables00sg_casca15.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part25_x2_mapmodel01.bcmdl",
	"cutscenes/0061kraiddeath/fx/kraid_decal.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_px_cooldown_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72001.bcmdl",
	"maps/fx/chozonumbers/fx/hologramletters_yellow_five.bcmdl",
	"maps/fx/chozonumbers/fx/hologramletters_yellow_seven.bcmdl",
	"maps/fx/chozonumbers/fx/hologramletters_red_five.bcmdl",
	"maps/fx/chozonumbers/fx/hologramletters_red_seven.bcmdl",
	"actors/props/pool_lava_45x2_kraid/models/pool_lava_45x2_kraid.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part029_o8_04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_a8_mattepaintclouds02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_23.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part024_e2_vignette01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72000.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72002.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part024_e2_mapmodel00.bcmdl",
	"cutscenes/0061kraiddeath/fx/magmaheatplane02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part029_o8_02.bcmdl",
	"cutscenes/0081cooldowndeath/fx/backfliptrail_right.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part010_r7_vignette02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_04.bcmdl",
	"cutscenes/0081cooldowndeath/fx/backfliptrail_left.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_vignette01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel42.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_07.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_06.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_02.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_x1_visualbreak_05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel49.bcmdl",
	"maps/objects/chozoemmybg01cornice2x4/chozoemmybg01cornice2x4.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_04.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_x1_breakable_09.bcmdl",
	"maps/objects/chozoalltunnelbg01_ta/chozoalltunnelbg01_ta.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mattepaintclouds01b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part029_o8_03.bcmdl",
	"maps/fx/magmaheat/magmaheatplane03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_o7_mapmodel22.bcmdl",
	"maps/objects/chozoalltunnelbg01_tb/chozoalltunnelbg01_tb.bcmdl",
	"maps/fx/ashparticles/ashparticles00.bcmdl",
	"maps/fx/ashparticles/ashparticles01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part001_r12_01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part020_r6_breakable009.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72002v.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72000v.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable21.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_breakablessg_casca72001v.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part003_x1_vignette_01.bcmdl",
	"actors/props/ev_dspiston_heat/models/ev_dspiston_heat.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_09.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part004_x1_vignettebreakable_00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_010.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_012.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_011.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_05.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_08.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_glass00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part020_r6_breakable22.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_02.bcmdl",
	"maps/objects/chozoalltunnelborder01x4b/chozoalltunnelborder01x4b.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/vignette_part004_03.bcmdl",
	"maps/objects/chozoalltunnelborder01x1/chozoalltunnelborder01x1.bcmdl",
	"maps/objects/chozobgmagwall05endl/chozobgmagwall05endl.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_lshaft01.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_mapmodel_029.bcmdl",
	"actors/props/fan_reg/fx/wind_cutscene.bcmdl",
	"maps/objects/chozoemmybg01corniceint/chozoemmybg01corniceint.bcmdl",
	"actors/props/fan_reg/fx/hurricane.bcmdl",
	"actors/props/fan_reg/fx/wind.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part003_s3_shadow.bcmdl",
	"maps/fx/steamdevices/steamdevices_column02_red.bcmdl",
	"maps/fx/holograms/models/holo_16_9_vfx1.bcmdl",
	"maps/fx/holograms/models/holo_16_9_vfx2.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part015_e7_mattepaintlightshaft02.bcmdl",
	"cutscenes/0081cooldowndeath/fx/magmalaserfakeglow.bcmdl",
	"actors/props/ev_tpiston_heat/models/ev_tpiston_heat.bcmdl",
	"cutscenes/0038magmaemmypresentation/fx/emmycone.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part029_o8_mapmodel52.bcmdl",
	"cutscenes/0061kraiddeath/fx/impact_decal.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part002_jp1_reflection.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part021_r7_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part027_n2_decals03.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part032_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part011_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_planereflection00.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part035_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s020_magma/models/part025_r5_planereflection01.bcmdl",
	"maps/fx/dustdebris/fx/dustdebris00.bcmdl",
	"maps/fx/dustdebris/fx/dustdebris00_fast.bcmdl",
	"maps/fx/lavaplanes/lavaplanes00.bcmdl",
	"cutscenes/0059kraidpresentation/fx/kraid_intro_fog.bcmdl",
	"cutscenes/0078cooldownpresentation/fx/cooldown_intro_fog.bcmdl",
	"cutscenes/0059kraidpresentation/fx/kraid_camera_color.bcmdl",
	"actors/weapons/kraidspike/fx/spikes_fast.bcmdl",
	"actors/weapons/kraidspike/fx/spikes.bcmdl",
	"actors/characters/kraid/fx/splash_kraid.bcmdl",
	"actors/weapons/kraidshockersplashprojectile/fx/mudwave01fx.bcmdl",
	"actors/weapons/kraidnail/fx/nailsfracture01.bcmdl",
	"actors/weapons/kraidspike/fx/slime.bcmdl",
	"actors/weapons/kraidrottenmeat/fx/meat_slime.bcmdl",
	"actors/weapons/kraidbouncingcreaturesunb/models/kraidbouncingcreaturesunb.bcmdl",
	"actors/weapons/kraidbouncingcreatures/models/kraidbouncingcreatures.bcmdl",
	"actors/weapons/kraidspike/models/kraidspike.bcmdl",
	"actors/weapons/kraidacidblobs/fx/blob_projectile.bcmdl",
	"actors/characters/kraid/fx/kraid_fresnel.bcmdl",
	"actors/weapons/kraidnail/models/kraidnail01.bcmdl",
	"actors/weapons/kraidrottenmeat/models/kraidrottenmeat.bcmdl",
	"actors/weapons/kraidnail/fx/nailstrail.bcmdl",
	"actors/characters/cooldownxboss/fx/lifeabsorption_body.bcmdl",
	"actors/weapons/cooldownxbosslavacarpet/fx/lavabubbles.bcmdl",
	"actors/characters/cooldownxboss/fx/bubbles_splash.bcmdl",
	"actors/characters/cooldownxboss/fx/lifeabsorption_tail.bcmdl",
	"actors/characters/cooldownxboss/fx/cooldownfresnel.bcmdl",
	"actors/characters/cooldownxboss/fx/ray_lateral.bcmdl",
	"actors/characters/cooldownxboss/fx/lifeabsorption.bcmdl",
	"actors/characters/cooldownxboss/fx/reaperdoubletrail.bcmdl",
	"actors/characters/cooldownxboss/fx/reapertrail.bcmdl",
	"actors/weapons/cooldownxbosslavacolumn/fx/columndismiss.bcmdl",
	"actors/weapons/cooldownxbosslavacolumn/fx/lavacolumn.bcmdl",
	"actors/characters/cooldownxboss/fx/background_wind.bcmdl",
	"actors/weapons/cooldownxbosslavacarpet/fx/lavaground.bcmdl",
	"actors/characters/cooldownxboss/fx/cooldown_grab_fog.bcmdl",
	"actors/characters/shakernaut/models/shakernaut.bcmdl",
	"actors/characters/shelmit/fx/shellmit_shellbreak.bcmdl",
	"actors/characters/shelmit/models/shelmit.bcmdl",
	"actors/characters/sclawk/models/sclawk.bcmdl",
	"actors/characters/fulmite/models/fulmite.bcmdl",
	"actors/weapons/fulmitebellymine/fx/explosion.bcmdl",
	"actors/characters/vulkran/models/vulkran.bcmdl",
	"actors/characters/shakernaut/fx/warm_right.bcmdl",
	"actors/characters/shakernaut/fx/warm_left.bcmdl",
	"actors/characters/vulkran/fx/magma_muzzle.bcmdl",
	"actors/weapons/fulmitebellymine/models/fulmitebellymine.bcmdl",
	"actors/characters/emmy/fx/protectorfresnel_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel06.bcmdl",
	"actors/characters/emmylab/models/emmylab.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel07.bcmdl",
	"actors/props/powergeneratorengine/models/powergeneratorengine_movable.bcmdl",
	"actors/events/mapev_disectedcreature/models/mapev_disectedcreature.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel04r.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_mapmodel_02.bcmdl",
	"actors/props/portal_trainwagon/models/portal_trainwagon_left.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_station00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part018_e2_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel10.bcmdl",
	"maps/objects/chozobasebgdeposit01_a/chozobasebgdeposit01_a.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_11.bcmdl",
	"maps/objects/chozobasebgdeposit01/chozobasebgdeposit01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part018_e2_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part007_m1_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel14.bcmdl",
	"actors/props/db_reg_b1_004/models/db_reg_b1_004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels04.bcmdl",
	"maps/objects/chozolabcryotube02/chozolabcryotube02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel03.bcmdl",
	"actors/props/db_hdoor_b1_001/models/db_hdoor_b1_001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel017.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel00.bcmdl",
	"maps/objects/communicationroomwalldoor/communicationroomwalldoor.bcmdl",
	"maps/objects/chozolabcryotube02b/chozolabcryotube02b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel00r.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part022_jg7_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_07.bcmdl",
	"actors/props/db_dif_b1_002/models/db_dif_b1_002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_10.bcmdl",
	"actors/props/db_reg_b1_002/models/db_reg_b1_002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel06r.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel10.bcmdl",
	"maps/objects/chozobasesetadn01_a/chozobasesetadn01_a.bcmdl",
	"maps/objects/chozobasesetadn01_b/chozobasesetadn01_b.bcmdl",
	"maps/objects/chozobasesetadn01_c/chozobasesetadn01_c.bcmdl",
	"maps/objects/chozobasesetadn01_d/chozobasesetadn01_d.bcmdl",
	"actors/props/db_reg_b1_001/models/db_reg_b1_001.bcmdl",
	"actors/props/ev_dna_centrifuge/models/ev_dna_centrifuge.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel018.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel_04.bcmdl",
	"maps/objects/chozolabcryotube01/chozolabcryotube01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel07.bcmdl",
	"maps/objects/chozobasecolumn01x3/chozobasecolumn01x3.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels05.bcmdl",
	"maps/objects/chozolabcryotube01b/chozolabcryotube01b.bcmdl",
	"maps/objects/chozobaseproplaser01/chozobaseproplaser01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_14.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel01.bcmdl",
	"actors/props/db_dif_b1_001/models/db_dif_b1_001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_station01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel08_hideable.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel04.bcmdl",
	"actors/props/db_reg_b1_003/models/db_reg_b1_003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel012.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part022_jg7_mapmodel001.bcmdl",
	"maps/objects/chozobaselavawheel01_a/chozobaselavawheel01_a.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel011.bcmdl",
	"actors/props/powergenerator/models/powergenerator.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel019.bcmdl",
	"maps/objects/chozobaseatrezzodeposit01a/chozobaseatrezzodeposit01a.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel020.bcmdl",
	"actors/props/pool_lava58x4_gen/models/pool_lava58x4_gen.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels02.bcmdl",
	"maps/objects/chozobaseatrezzodeposit01b/chozobaseatrezzodeposit01b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part018_e2_decal001.bcmdl",
	"actors/events/mapev_celldoors/models/mapev_celldoors.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part022_jg7_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel015.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel02b.bcmdl",
	"maps/objects/aquarocksalt03/aquarocksalt03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel004.bcmdl",
	"maps/objects/chozolabcryotubedoor/chozolabcryotubedoor.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26009.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca257.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel006.bcmdl",
	"maps/objects/chozobaseassets02/chozobaseassets02.bcmdl",
	"maps/objects/chozobasebgcorridor01x3b/chozobasebgcorridor01x3b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_03.bcmdl",
	"maps/objects/chozobasebgcorridor02x3/chozobasebgcorridor02x3.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel013.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part022_jg7_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca256.bcmdl",
	"maps/objects/aquarocksaltcorner/aquarocksaltcorner.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca259.bcmdl",
	"maps/objects/aquanature04/aquanature04.bcmdl",
	"maps/objects/aquarocksaltcornersimple/aquarocksaltcornersimple.bcmdl",
	"maps/objects/chozobasesetadn02_a/chozobasesetadn02_a.bcmdl",
	"maps/objects/chozobasesetadn02_b/chozobasesetadn02_b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca240.bcmdl",
	"maps/objects/chozoaquafloodgate/chozoaquafloodgate.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca254.bcmdl",
	"maps/objects/chozobaseasset04/chozobaseasset04.bcmdl",
	"maps/objects/aquarock01x3simple/aquarock01x3simple.bcmdl",
	"maps/objects/chozobasebgcorridor01x3/chozobasebgcorridor01x3.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca258.bcmdl",
	"maps/objects/chozoaqatrezzorot01/chozoaqatrezzorot01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel07.bcmdl",
	"actors/spawnpoints/spawnpointautsharp/models/spawnpointautsharp.bcmdl",
	"maps/objects/chozobaseasset05/chozobaseasset05.bcmdl",
	"maps/objects/aquarocksalt03simple/aquarocksalt03simple.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part014_jp1_planereflect_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable07sg_casca195.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca251.bcmdl",
	"maps/objects/aquanature03/aquanature03.bcmdl",
	"maps/objects/chozobasebgwall06endr/chozobasebgwall06endr.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca113.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca262.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca114.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca263.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca241.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca148.bcmdl",
	"maps/objects/chozoaqexteriorrooft01end/chozoaqexteriorrooft01end.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca141.bcmdl",
	"maps/objects/chozobasebgwall01tubes/chozobasebgwall01tubes.bcmdl",
	"maps/objects/aquanature05a/aquanature05a.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel014.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca115.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca261.bcmdl",
	"maps/objects/chozoaqexteriorrooft01x4/chozoaqexteriorrooft01x4.bcmdl",
	"maps/objects/chozobasepath02endl/chozobasepath02endl.bcmdl",
	"maps/objects/chozobasebgasset01/chozobasebgasset01.bcmdl",
	"maps/objects/chozoallmecharm01/chozoallmecharm01.bcmdl",
	"maps/objects/chozobasebgcorridor02x3b/chozobasebgcorridor02x3b.bcmdl",
	"maps/objects/chozobasepath02x4/chozobasepath02x4.bcmdl",
	"actors/items/powerup_widebeam/models/powerup_widebeam.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_lightshaft.bcmdl",
	"maps/objects/chozobasebgcorridor01x1/chozobasebgcorridor01x1.bcmdl",
	"actors/props/mlm_point/models/mlm_point.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca147.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca143.bcmdl",
	"maps/objects/chozobasebgwall06mid/chozobasebgwall06mid.bcmdl",
	"maps/objects/chozobasepath02x4b/chozobasepath02x4b.bcmdl",
	"maps/objects/chozobasepath02endr/chozobasepath02endr.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca116.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_sg_casca260.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca142.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26008.bcmdl",
	"maps/objects/plantforestminis01/plantforestminis01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca145.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel08.bcmdl",
	"actors/props/pool_water50x15_gen/models/pool_water50x15_gen.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26002.bcmdl",
	"maps/objects/chozoaqexteriorrooft01x1/chozoaqexteriorrooft01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part019_s010_00.bcmdl",
	"maps/objects/chozobasebgwall01right/chozobasebgwall01right.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_r3_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca146.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_tapa.bcmdl",
	"actors/props/cut_all_pathemmy01/models/cut_all_pathemmy01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca252.bcmdl",
	"maps/objects/chozoaqadorn01x7/chozoaqadorn01x7.bcmdl",
	"maps/objects/chozobasebgwall01left/chozobasebgwall01left.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca253.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_e5_mapmodel04.bcmdl",
	"maps/objects/chozobasewallset01/chozobasewallset01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26000.bcmdl",
	"actors/props/pool_water38x5_gen/models/pool_water38x5_gen.bcmdl",
	"actors/props/pool_lava_19x5_gen/models/pool_lava_19x5_gen.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca201.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_sg_casca144.bcmdl",
	"maps/objects/chozoroomwall04x6/chozoroomwall04x6.bcmdl",
	"maps/objects/aquarock01x3/aquarock01x3.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_jg3_mapmodel000.bcmdl",
	"maps/objects/aquarock02x3/aquarock02x3.bcmdl",
	"actors/events/mapev_shrimps/models/mapev_shrimps.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca200.bcmdl",
	"maps/objects/chozobasewallset02/chozobasewallset02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_cavelightshaft.bcmdl",
	"maps/objects/aquarock03x4simple/aquarock03x4simple.bcmdl",
	"maps/objects/aquarocksalt02/aquarocksalt02.bcmdl",
	"maps/objects/aquarockwall02x3/aquarockwall02x3.bcmdl",
	"maps/objects/chozoaqpipejoint03/chozoaqpipejoint03.bcmdl",
	"maps/objects/aquarockwall01x3/aquarockwall01x3.bcmdl",
	"actors/events/mapev_gooplot/models/mapev_gooplot.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca199.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable002.bcmdl",
	"maps/objects/plantforestminis02/plantforestminis02.bcmdl",
	"maps/objects/aquanature05b/aquanature05b.bcmdl",
	"maps/objects/chozobasebgwall06endl/chozobasebgwall06endl.bcmdl",
	"actors/fx/flickeringlight01static/fx/flickeringlight01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_lightshaft_lightcave2.bcmdl",
	"maps/objects/chozobasebgcorridor02cornerr/chozobasebgcorridor02cornerr.bcmdl",
	"maps/objects/chozohangcable10/chozohangcable10.bcmdl",
	"maps/objects/chozobasebgcorridor02cornerl/chozobasebgcorridor02cornerl.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca202.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part017_jp6_01.bcmdl",
	"maps/objects/aquarocksalt02simple/aquarocksalt02simple.bcmdl",
	"maps/objects/aquarocksalt01/aquarocksalt01.bcmdl",
	"maps/objects/aquarockwall07x3/aquarockwall07x3.bcmdl",
	"maps/objects/chozoallpathgen01endr/chozoallpathgen01endr.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part022_jg7_mapmodel003.bcmdl",
	"maps/objects/chozobasebgwindow01cornerl/chozobasebgwindow01cornerl.bcmdl",
	"maps/objects/chozobasebgcorridor01x3cornerr/chozobasebgcorridor01x3cornerr.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_07.bcmdl",
	"actors/props/pool_water9x4_gen/models/pool_water9x4_gen.bcmdl",
	"maps/objects/chozobasebgcorridor01x3cornerl/chozobasebgcorridor01x3cornerl.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca188.bcmdl",
	"maps/objects/aquadigrock05/aquadigrock05.bcmdl",
	"maps/objects/aquanature04a/aquanature04a.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_00.bcmdl",
	"maps/objects/aquarock02x4/aquarock02x4.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca190.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26006.bcmdl",
	"maps/objects/aquarocksalt01simple/aquarocksalt01simple.bcmdl",
	"maps/objects/aquarockwall06x3/aquarockwall06x3.bcmdl",
	"actors/props/mlm_block/models/mlm_block.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel13.bcmdl",
	"maps/objects/chozoaqwallsetcorner02right/chozoaqwallsetcorner02right.bcmdl",
	"actors/spawnpoints/spawnpointslidle/models/spawnpointslidle.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_mapmodel_04.bcmdl",
	"maps/objects/aquarockwall05x3/aquarockwall05x3.bcmdl",
	"maps/objects/aquarock02x4simple/aquarock02x4simple.bcmdl",
	"maps/objects/aquanature05c/aquanature05c.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part011_e7_vignettel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca192.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca189.bcmdl",
	"maps/objects/aquarockwall03x3/aquarockwall03x3.bcmdl",
	"maps/objects/chozobasewallsetcorner02right/chozobasewallsetcorner02right.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable20sg_casca239.bcmdl",
	"maps/objects/aquanature01a/aquanature01a.bcmdl",
	"maps/objects/chozobasewallsetcorner02left/chozobasewallsetcorner02left.bcmdl",
	"maps/objects/chozobasetank01/chozobasetank01.bcmdl",
	"maps/objects/chozoallpathgen03x4/chozoallpathgen03x4.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca191.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_s7_sg_casca187.bcmdl",
	"actors/props/pool_lava_11x3_gen/models/pool_lava_11x3_gen.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_sg_casca26004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable001.bcmdl",
	"maps/objects/chozobasebgwall01x2/chozobasebgwall01x2.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable005.bcmdl",
	"maps/objects/chozobasejaildoor02/chozobasejaildoor02.bcmdl",
	"maps/objects/chozobasetanklbroken01/chozobasetanklbroken01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel_breakables_sg_casca73sg_casca073.bcmdl",
	"maps/objects/aquanature06a_01/aquanature06a_01.bcmdl",
	"maps/objects/chozobasebgwindow02x2/chozobasebgwindow02x2.bcmdl",
	"maps/objects/chozobasejaildoor02open/chozobasejaildoor02open.bcmdl",
	"maps/objects/chozoallpath02x3/chozoallpath02x3.bcmdl",
	"maps/objects/aquadigrock04/aquadigrock04.bcmdl",
	"maps/objects/aquanature03b/aquanature03b.bcmdl",
	"maps/objects/chozobasetankempty01/chozobasetankempty01.bcmdl",
	"maps/objects/chozobasejaildoor01opena/chozobasejaildoor01opena.bcmdl",
	"maps/objects/chozobasewallsetcorner01left/chozobasewallsetcorner01left.bcmdl",
	"maps/objects/chozobasewallset03/chozobasewallset03.bcmdl",
	"actors/props/pool_water16x7_gen/models/pool_water16x7_gen.bcmdl",
	"maps/objects/chozobasebgwall01endl/chozobasebgwall01endl.bcmdl",
	"maps/objects/chozobasejaildoor01/chozobasejaildoor01.bcmdl",
	"maps/objects/aquanature06a_02/aquanature06a_02.bcmdl",
	"maps/objects/aquanature06b_02/aquanature06b_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel_breakables_sg_casca169.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel_breakables_sg_casca168.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel_breakables_sg_casca170.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part002_9_00.bcmdl",
	"actors/props/pool_water6x3_gen/models/pool_water6x3_gen.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part020_jg3_vignette00.bcmdl",
	"maps/objects/chozoemmytunnelbg01corner2/chozoemmytunnelbg01corner2.bcmdl",
	"actors/props/pool_water10x3_gen/models/pool_water10x3_gen.bcmdl",
	"maps/objects/chozobasewallsetcorner01right/chozobasewallsetcorner01right.bcmdl",
	"maps/objects/chozoaqpipejoint04/chozoaqpipejoint04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable004.bcmdl",
	"maps/objects/chozobasewallset04/chozobasewallset04.bcmdl",
	"maps/objects/chozotunnel01x1/chozotunnel01x1.bcmdl",
	"actors/items/powerup_bomb/models/powerup_bomb.bcmdl",
	"maps/objects/chozoaqexteriorwall01x4/chozoaqexteriorwall01x4.bcmdl",
	"maps/objects/chozobasepath01x4/chozobasepath01x4.bcmdl",
	"maps/objects/chozobasepath02x01/chozobasepath02x01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part003_e9_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part026_jg4_mapmodel002.bcmdl",
	"actors/props/emergency_light/models/emergency_light.bcmdl",
	"actors/props/weightactivatedplatform_generator/models/weightactivatedplatform.bcmdl",
	"maps/objects/chozoallpipesset01xcorner2/chozoallpipesset01xcorner2.bcmdl",
	"maps/objects/aquarockplatform01x3/aquarockplatform01x3.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable000.bcmdl",
	"maps/objects/chozobaseassets03/chozobaseassets03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break04.bcmdl",
	"actors/props/weightactivatedplatform_generator/models/weightactivatedplatform_generator.bcmdl",
	"maps/objects/aquarockwall04x3/aquarockwall04x3.bcmdl",
	"maps/objects/chozobasepath02x1b/chozobasepath02x1b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel09.bcmdl",
	"maps/objects/chozobasebgwall01/chozobasebgwall01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part025_s7_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel021.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part001_e5_vignette001.bcmdl",
	"maps/objects/chozobasejaildoor01openb/chozobasejaildoor01openb.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part016_jg5_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part006_jg9_vignette.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable02sg_casca197.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part024_o2_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break06.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part005_r3_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_lightshaft.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable08sg_casca196.bcmdl",
	"maps/objects/aquanature01b/aquanature01b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable00sg_casca194.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable01sg_casca193.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part007_m1_vignette_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break02.bcmdl",
	"maps/objects/chozoemmybg01tur1/chozoemmybg01tur1.bcmdl",
	"maps/objects/aquadigrock03/aquadigrock03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part009_f8.bcmdl",
	"maps/objects/chozobasehandrail01_stairsl/chozobasehandrail01_stairsl.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part022_jg7.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part016_jg5_vignette02.bcmdl",
	"maps/objects/chozobasehandrail01_stairsr/chozobasehandrail01_stairsr.bcmdl",
	"maps/objects/chozobasebgwindow02cornerr/chozobasebgwindow02cornerr.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_lightshaft_lightcave.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part012_jg4_vignette000.bcmdl",
	"maps/objects/aquanature06a_03/aquanature06a_03.bcmdl",
	"maps/objects/aquanature06b_03/aquanature06b_03.bcmdl",
	"maps/objects/chozobasebg01x4b/chozobasebg01x4b.bcmdl",
	"maps/objects/chozoallpathgen02x1/chozoallpathgen02x1.bcmdl",
	"maps/objects/aquarock04x4simple/aquarock04x4simple.bcmdl",
	"maps/objects/chozobasecolumn01a/chozobasecolumn01a.bcmdl",
	"maps/objects/chozobasefence03/chozobasefence03.bcmdl",
	"maps/objects/chozobasewallset05/chozobasewallset05.bcmdl",
	"maps/objects/chozoallpathgen01x4/chozoallpathgen01x4.bcmdl",
	"maps/objects/chozoaquagrid01/chozoaquagrid01.bcmdl",
	"actors/props/powergeneratorengine/fx/generatorlightning.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca184.bcmdl",
	"maps/objects/chozoallpathgen01x1/chozoallpathgen01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca181.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable18sg_casca237.bcmdl",
	"maps/objects/chozobasebgwall01x1/chozobasebgwall01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca186.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca185.bcmdl",
	"maps/objects/chozobasehandrail01_02/chozobasehandrail01_02.bcmdl",
	"maps/objects/chozobasehandrail01_01/chozobasehandrail01_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break10.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable11sg_casca234.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_lightshaft.bcmdl",
	"maps/objects/chozobasefence01/chozobasefence01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part008_lightshaft.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part003.bcmdl",
	"maps/objects/chozoallpathgen03endleft/chozoallpathgen03endleft.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part015_jg5_00.bcmdl",
	"maps/objects/chozoaqstairs01x1/chozoaqstairs01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca182.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part017_jp6_sg_casca183.bcmdl",
	"actors/spawnpoints/spawnpointslidle/models/spawnpointslidleoutwall.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_mapmodel_05.bcmdl",
	"maps/objects/chozoallpathgen03endright/chozoallpathgen03endright.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable19sg_casca238.bcmdl",
	"maps/objects/aquarock04x4/aquarock04x4.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable06sg_casca198.bcmdl",
	"maps/objects/chozowiderail01x3/chozowiderail01x3.bcmdl",
	"actors/props/pool_water3x2_gen/models/pool_water3x2_gen.bcmdl",
	"maps/objects/chozoallpipesset01x1/chozoallpipesset01x1.bcmdl",
	"maps/objects/chozoaqjoint01/chozoaqjoint01.bcmdl",
	"maps/objects/aquadigrock02/aquadigrock02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable10sg_casca236.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable15sg_casca232.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_00.bcmdl",
	"maps/objects/chozoallpathgen03x1/chozoallpathgen03x1.bcmdl",
	"maps/objects/fxwatersplashx1/fxwatersplashx1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable12sg_casca229.bcmdl",
	"maps/objects/aberration01_a/aberration01_a.bcmdl",
	"maps/objects/aberration01_b/aberration01_b.bcmdl",
	"actors/spawnpoints/spawnpointslidle/models/spawnpointslidleout.bcmdl",
	"maps/objects/chozobasebgwall02x4/chozobasebgwall02x4.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable04sg_casca227.bcmdl",
	"maps/objects/chozoaqtuberia/chozoaqtuberia.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_break_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_break_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel023.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_s2_vignette_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break11.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/centrallight_lightshaft.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part026_jg4_vignette.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable03sg_casca226.bcmdl",
	"maps/objects/chozostationcolumn07x2/chozostationcolumn07x2.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable09sg_casca66000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca172.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_lightshaft.bcmdl",
	"actors/props/powergeneratorengine/fx/generatorlightning02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part001_lightshaft_station.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part008_jg3_vignette.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca076.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca085.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca171.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break09.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable05sg_casca228.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part011_e7_mapmodels07.bcmdl",
	"maps/objects/chozostructure02/chozostructure02.bcmdl",
	"maps/objects/chozoaqhandrail01_2/chozoaqhandrail01_2.bcmdl",
	"maps/objects/chozobasebgwall02x4b/chozobasebgwall02x4b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part025_s7_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca087.bcmdl",
	"maps/objects/chozostationengine08/chozostationengine08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca078.bcmdl",
	"maps/objects/chozobasepath01x1/chozobasepath01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca173.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca176.bcmdl",
	"maps/objects/chozobasecolumn01b/chozobasecolumn01b.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_09.bcmdl",
	"maps/objects/aquanature06a_05/aquanature06a_05.bcmdl",
	"maps/objects/chozobasebgwindow01x1/chozobasebgwindow01x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part023_f4_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca077.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca086.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable17sg_casca235.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable13sg_casca233.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part020_jg3_breakables_08.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca174.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca178.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca177.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca175.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel_breakables_sg_casca70sg_casca070.bcmdl",
	"maps/objects/chozohangcable05/chozohangcable05.bcmdl",
	"maps/objects/chozostationcolumn04a/chozostationcolumn04a.bcmdl",
	"maps/objects/aquanature06a_04/aquanature06a_04.bcmdl",
	"actors/props/powergeneratorengine/fx/generatorlightning03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable009.bcmdl",
	"maps/objects/aquanature01c/aquanature01c.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part012_jg4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_04.bcmdl",
	"maps/objects/chozobasebgwall06x1/chozobasebgwall06x1.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable006.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part010_s2_vignette_00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable011.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable008.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable010.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part005_lightshaft2.bcmdl",
	"maps/objects/aquanature05e/aquanature05e.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part006_jg9_break01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_02.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part009_f8_mapmodel016.bcmdl",
	"maps/objects/aquanature05f/aquanature05f.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part018_e2_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part002_r9_ocultavignette015.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part006_jg9_vignette001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part018_e2_vignette002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part016_r4_ocultavignette014.bcmdl",
	"maps/objects/decalcharco01/decalcharco01.bcmdl",
	"maps/objects/chozobasebgwall06x2/chozobasebgwall06x2.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part023_f4_breakable007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable16sg_casca231.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part002_r9_breakable14sg_casca230.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part024_o2_mapmodel06.bcmdl",
	"maps/objects/aquanature01d/aquanature01d.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_sg_vignette008.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca204.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca075.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_05.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part006_jg9_vignette003.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca70001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break20.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca77000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part026_jg4_sg_vignette004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca206.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca218.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca215.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca221.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part013_o4_03.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break15.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break22.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40004.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40007.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca70000.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca77001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part006_jg9_vignette002.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part016_jg5_ocultavignette013.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break17.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break21.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca205.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca220.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca225.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca203.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break12.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break13.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break18.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break19.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca214.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca216.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40005.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca40006.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part013_o4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break14.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break23.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part020_jg3_breakvignette00.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part020_jg3_breakvignette01.bcmdl",
	"maps/objects/chozobgemmybot01/chozobgemmybot01.bcmdl",
	"maps/fx/labsteam/fx/labmist01_center.bcmdl",
	"maps/fx/labsteam/fx/labmist01_left.bcmdl",
	"maps/fx/labsteam/fx/labmist01_right.bcmdl",
	"maps/objects/chozobgwall01top/chozobgwall01top.bcmdl",
	"actors/events/mapev_disectedcreature02/fx/creaturelightning.bcmdl",
	"maps/objects/chozostationcolumn04b/chozostationcolumn04b.bcmdl",
	"maps/fx/labsteam/fx/labdryicegreen_down00.bcmdl",
	"maps/fx/labdryice/fx/labdryice_down00.bcmdl",
	"maps/fx/labsteam/fx/labmist02_center.bcmdl",
	"maps/fx/stargate/stargateportal.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part021_m1_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part014_m1_mapmodel001.bcmdl",
	"maps/fx/holograms/models/holo_16_9_vfx1_blackout.bcmdl",
	"maps/fx/holograms/models/holo_16_9_vfx2_blackout.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part005_r3_01.bcmdl",
	"maps/fx/labsteam/fx/labdryicegreen_vertical01medium.bcmdl",
	"maps/fx/labsteam/fx/labdryicegreen_vertical00small.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/vignette_part025_s7_02.bcmdl",
	"cutscenes/0039labemmypresentation/fx/emmycone.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part027_jp1_planereflect01.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_sg_casca219.bcmdl",
	"maps/fx/labsteam/fx/labmist00_left.bcmdl",
	"maps/fx/labsteam/fx/labmist02_down.bcmdl",
	"maps/fx/labsteam/fx/labmist00_right.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part015_jg5_break16.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part004_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part021_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s030_baselab/models/part019_s010_mapmodel16.bcmdl",
	"maps/fx/emmyventilationgridgas00/fx/emmyventilationgridgas02.bcmdl",
	"actors/characters/autsniper/models/autsniper.bcmdl",
	"actors/characters/gooshocker/models/gooshockerx.bcmdl",
	"actors/characters/gooplot/models/gooplot.bcmdl",
	"actors/characters/nailong/models/nailong.bcmdl",
	"actors/characters/armadigger/models/armadigger.bcmdl",
	"actors/characters/sharpaw/models/sharpaw.bcmdl",
	"actors/characters/dredhed/models/dredhed.bcmdl",
	"actors/characters/autsharp/models/autsharp.bcmdl",
	"actors/characters/rodotuk/models/rodotuk.bcmdl",
	"actors/characters/gooplot/fx/gooplotsplash.bcmdl",
	"actors/characters/rodotuk/fx/souls_vortex.bcmdl",
	"actors/characters/slidle/models/slidle.bcmdl",
	"actors/characters/autector/models/autector.bcmdl",
	"actors/characters/autsniper/fx/models/autlightningfx.bcmdl",
	"actors/characters/autsniper/fx/models/autlaser_burstshoot.bcmdl",
	"actors/characters/sakai/fx/displacement_rays.bcmdl",
	"actors/characters/sakai/fx/sakaiplasma.bcmdl",
	"actors/characters/gooshocker/fx/goolightning.bcmdl",
	"actors/characters/autsniper/fx/models/autlaser_charge.bcmdl",
	"actors/characters/autsniper/fx/models/autlaser_burst.bcmdl",
	"actors/weapons/nailongthorn/fx/destruction.bcmdl",
	"actors/characters/gooshocker/fx/floor_rays.bcmdl",
	"actors/characters/autector/fx/fakelight.bcmdl",
	"actors/weapons/nailongthorn/models/nailongthorn.bcmdl",
	"actors/characters/gooplot/fx/gooplottail.bcmdl",
	"actors/characters/gooshocker/fx/gooplottail.bcmdl",
	"actors/characters/autsharp/fx/spikesaurastatic.bcmdl",
	"actors/characters/autsharp/fx/spikesaura.bcmdl",
	"maps/objects/savestationl/savestationl.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_02_edificio.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel07.bcmdl",
	"actors/props/ev_demolition_tunnel/models/ev_demolition_tunnel.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel05.bcmdl",
	"actors/props/ev_doorprof/models/ev_doorprof.bcmdl",
	"actors/props/ev_doorprof_open/models/ev_doorprof_open.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part003_e3_mapmodel03.bcmdl",
	"actors/props/portal_trainwagon/models/portal_trainwagon_right.bcmdl",
	"actors/characters/hydrogiga/models/hydro_trans.bcmdl",
	"actors/characters/hydrogiga/models/hydrogiga.bcmdl",
	"actors/props/ev_demolition_debris/models/ev_demolition_debris.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel00p2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part014_e2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part010_e3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificioa002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part014_e2_cristalera00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificio.bcmdl",
	"actors/props/db_reg_aq_007/models/db_reg_aq_007.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel00.bcmdl",
	"actors/props/db_reg_aq_002/models/db_reg_aq_002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel04b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part023_e3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificioa003.bcmdl",
	"actors/props/hydrogigacorpse/models/hydrogigacorpse.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part017_e2_mapmodel00.bcmdl",
	"maps/objects/chozoaqatrezzodoorbg01/chozoaqatrezzodoorbg01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel03.bcmdl",
	"actors/props/db_reg_aq_001/models/db_reg_aq_001.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part022_e4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_03_rocas1.bcmdl",
	"actors/props/aeiongd_statue/models/aeiongd_statue.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel10.bcmdl",
	"actors/props/ev_demolition_block/models/ev_demolition_block.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_bmapmodelb00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part014_e2_pipes00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel00p5.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_03_rocas003.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part003_e3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel09.bcmdl",
	"maps/objects/chozobgwater01x4/chozobgwater01x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_pipes.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part006_jp10_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part010_e3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_05_tubes.bcmdl",
	"actors/props/db_reg_aq_008/models/db_reg_aq_008.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part023_e3_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part010_e3_mapmodel00.bcmdl",
	"actors/props/ev_tentacle_004/models/tentaculos_muertos_posicion4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel02.bcmdl",
	"actors/props/db_reg_aq_005/models/db_reg_aq_005.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel01.bcmdl",
	"actors/props/ev_tentacle_004/models/tentaculos_muertos_posicion4_dead.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_bpipes00.bcmdl",
	"maps/objects/testrain01/testrain01.bcmdl",
	"actors/props/db_reg_aq_003/models/db_reg_aq_003.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_03_rocas.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel10c.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables17sg_casca083.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_04_cristal.bcmdl",
	"actors/props/ev_demolition_db_001/models/ev_demolition_db_001.bcmdl",
	"actors/props/ev_demolition_grapple/models/ev_demolition_grapple.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificioa1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel005.bcmdl",
	"actors/props/ev_demolition_grapple/fx/destruction.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel05.bcmdl",
	"maps/objects/chozoaqcolumn04/chozoaqcolumn04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_01_ilum1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes005.bcmdl",
	"actors/props/zipline_rail_hydrogiga/models/zipline_rail_hydrogiga.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel08.bcmdl",
	"actors/props/db_reg_aq_011/models/db_reg_aq_011.bcmdl",
	"actors/props/db_reg_aq_009/models/db_reg_aq_009.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel03.bcmdl",
	"actors/props/ev_tbdrainboss/models/ev_tbdrainboss.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel12.bcmdl",
	"actors/props/db_reg_aq_010/models/db_reg_aq_010.bcmdl",
	"actors/props/ev_tentacle_002/models/tentaculos_muertos_posicion2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel01.bcmdl",
	"actors/props/ev_tentacle_002/models/tentaculos_muertos_posicion2_dead.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel00p1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel03.bcmdl",
	"actors/props/ev_demolition_db_002/models/ev_demolition_db_002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificioh3.bcmdl",
	"maps/fx/splash00/fx/splashout_00_6m.bcmdl",
	"actors/props/ev_demolition_db_003/models/ev_demolition_db_003.bcmdl",
	"maps/objects/chozoaqpath04x4/chozoaqpath04x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes3.bcmdl",
	"actors/props/pool_water37x13_gen/models/pool_water37x13_gen.bcmdl",
	"actors/characters/omnithon/models/omnithon.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables03sg_casca082.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel00.bcmdl",
	"maps/objects/chozoaqcolumn03/chozoaqcolumn03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificio2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables02sg_casca081.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_fondo.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables15sg_casca008.bcmdl",
	"maps/objects/chozoaqdoor01a/chozoaqdoor01a.bcmdl",
	"actors/props/ev_tentacle_003/models/tentaculos_muertos_posicion3.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm05.bcmdl",
	"actors/props/ev_tentacle_003/models/tentaculos_muertos_posicion3_dead.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel02.bcmdl",
	"maps/objects/chozoallasset03/chozoallasset03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_sand00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel008.bcmdl",
	"actors/props/db_reg_aq_004/models/db_reg_aq_004.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lshaft.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificioh1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part010_e3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_decal00.bcmdl",
	"actors/props/pool_water35x22_gen/models/pool_water35x22_gen.bcmdl",
	"actors/props/ev_watervalve_hydrogiga/fx/water_init.bcmdl",
	"actors/props/ev_watervalve_hydrogiga/fx/water_end.bcmdl",
	"actors/props/ev_watervalve_hydrogiga/fx/water_loop.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_001sg_casca021.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_002sg_casca024.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel04.bcmdl",
	"actors/props/ev_aquadrain_right/models/ev_aquadrain_right.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part010_e3_mapmodel04.bcmdl",
	"actors/props/pool_aquaboss_aq/models/pool_aquaboss_aq.bcmdl",
	"actors/props/ev_aquadrain_left/models/ev_aquadrain_left.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel10c.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_01_ilum2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part014_e2_decals00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca43002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_01_ilum.bcmdl",
	"actors/characters/sakai/models/sakai.bcmdl",
	"maps/objects/chozoaqpath04x1/chozoaqpath04x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca050.bcmdl",
	"actors/props/pool_water27x4_gen/models/pool_water27x4_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel002.bcmdl",
	"maps/fx/waterfallaqua/waterfallaqua02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_12_arena.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes6.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part015_r4_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_matte_01.bcmdl",
	"maps/objects/chozoaqwallset01/chozoaqwallset01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables16sg_casca080.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca066.bcmdl",
	"maps/objects/chozoaqatrezzoroofbg01/chozoaqatrezzoroofbg01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_mar01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca074.bcmdl",
	"maps/objects/chozoassetconsole01/chozoassetconsole01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part013_jg9_vignette01.bcmdl",
	"maps/objects/chozoaqadorn01x4/chozoaqadorn01x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables00sg_casca078.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_000sg_casca023.bcmdl",
	"actors/events/mapev_coral01/models/mapev_coral01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_003sg_casca022.bcmdl",
	"maps/objects/chozoaqplatform01/chozoaqplatform01.bcmdl",
	"actors/props/ev_tentacle_001/models/tentaculos_muertos_posicion1_dead.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_decal01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part003_e3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part012_jp1_planereflect_01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel00p3.bcmdl",
	"maps/objects/chozoaqbgcorridor02/chozoaqbgcorridor02.bcmdl",
	"maps/objects/chozoaqpath05x4/chozoaqpath05x4.bcmdl",
	"maps/objects/aquarockwall05x3simple/aquarockwall05x3simple.bcmdl",
	"maps/objects/chozoaqwallset02/chozoaqwallset02.bcmdl",
	"maps/fx/waterfallaqua/waterfallaqua03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca057.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel10d.bcmdl",
	"actors/props/ev_tentacle_001/models/tentaculos_muertos_posicion1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca063.bcmdl",
	"actors/events/mapev_lapa_01/models/mapev_lapa_01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel010.bcmdl",
	"actors/props/pool_trench/models/pool_trench.bcmdl",
	"maps/objects/chozoaqcorridorbg02/chozoaqcorridorbg02.bcmdl",
	"actors/props/fan_reg/models/fan_reg.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel02.bcmdl",
	"actors/props/pool_water21x3_gen/models/pool_water21x3_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables07sg_casca013.bcmdl",
	"actors/props/box_magnet_aq_001/models/box_magnet_aq_001.bcmdl",
	"maps/objects/chozoaqcorridorroof02x4/chozoaqcorridorroof02x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables01sg_casca079.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part018_jp10_00.bcmdl",
	"actors/props/zipline_bottom_hydrogiga/models/zipline_bottom_hydrogiga.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables04sg_casca015.bcmdl",
	"actors/spawnpoints/spawnpointslidlemetallic/models/spawnpointslidlemetallicwall.bcmdl",
	"maps/objects/chozohangcable10_a/chozohangcable10_a.bcmdl",
	"actors/props/pool_water17x10_gen/models/pool_water17x10_gen.bcmdl",
	"actors/spawnpoints/spawnpointslidlemetallic/models/spawnpointslidlemetallic.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables05sg_casca011.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lightshaft_01.bcmdl",
	"maps/objects/chozoaqcolumn02/chozoaqcolumn02.bcmdl",
	"maps/objects/chozoaqatrezzofloorbg01/chozoaqatrezzofloorbg01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel007.bcmdl",
	"maps/objects/chozobgstructure01x4a/chozobgstructure01x4a.bcmdl",
	"maps/objects/chozoaqplatform01b/chozoaqplatform01b.bcmdl",
	"maps/fx/splash00/fx/splashout_00_6x1m.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables08sg_casca010.bcmdl",
	"maps/objects/aquarockwall02x3simple/aquarockwall02x3simple.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_04_cristal2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_mapmodel03.bcmdl",
	"maps/objects/chozoaqwallsetcorner02left/chozoaqwallsetcorner02left.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part015_r4_00.bcmdl",
	"maps/objects/chozoaqcolumn01/chozoaqcolumn01.bcmdl",
	"maps/objects/aquanature02a/aquanature02a.bcmdl",
	"actors/props/pool_water51x47_gen/models/pool_water51x47_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm06.bcmdl",
	"actors/props/pool_water51x26_gen/models/pool_water51x26_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca153.bcmdl",
	"maps/objects/chozoaqbg01x6/chozoaqbg01x6.bcmdl",
	"maps/objects/chozoaqsubmarine01_a/chozoaqsubmarine01_a.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables06sg_casca012.bcmdl",
	"maps/objects/aquarockwall06x3simple/aquarockwall06x3simple.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part009_jp11_00.bcmdl",
	"maps/objects/chozoallbgemmy01bx4/chozoallbgemmy01bx4.bcmdl",
	"maps/objects/chozoaqcorridorbg02x4/chozoaqcorridorbg02x4.bcmdl",
	"maps/objects/chozoaqcorridorbg01x4/chozoaqcorridorbg01x4.bcmdl",
	"maps/objects/chozoaqsubmarine01/chozoaqsubmarine01.bcmdl",
	"maps/objects/chozoaqcorridorroof02x1/chozoaqcorridorroof02x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables14sg_casca018.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca157.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel06.bcmdl",
	"actors/props/pool_water29x19_gen/models/pool_water29x19_gen.bcmdl",
	"actors/props/pool_water9x15_gen/models/pool_water9x15_gen.bcmdl",
	"maps/objects/chozoaqbg01x4/chozoaqbg01x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca43001.bcmdl",
	"actors/props/pool_water13x2_gen/models/pool_water13x2_gen.bcmdl",
	"maps/objects/aquarockwall03x3simple/aquarockwall03x3simple.bcmdl",
	"actors/items/powerup_gravitysuit/models/powerup_gravitysuit.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca070.bcmdl",
	"actors/props/pool_water51x17_gen/models/pool_water51x17_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca060.bcmdl",
	"actors/spawnpoints/spawnpointslidle/models/spawnpointslidlewall.bcmdl",
	"actors/props/spacejump_marker/models/spacejump_marker.bcmdl",
	"maps/objects/chozoalltripletube02x1/chozoalltripletube02x1.bcmdl",
	"maps/objects/chozoaqwallset03/chozoaqwallset03.bcmdl",
	"maps/objects/chozoroomwall01curve/chozoroomwall01curve.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca116.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca034.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca162.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca031.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca118.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables09sg_casca009.bcmdl",
	"maps/objects/chozohangcable08_a/chozohangcable08_a.bcmdl",
	"maps/objects/chozoaqcorridorbg01x1/chozoaqcorridorbg01x1.bcmdl",
	"maps/objects/chozoaqbgcorridor01x3/chozoaqbgcorridor01x3.bcmdl",
	"maps/objects/chozobgstructure01corner2/chozobgstructure01corner2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_004sg_casca039.bcmdl",
	"maps/objects/chozoaqwallsetcorner01left/chozoaqwallsetcorner01left.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_11_decal.bcmdl",
	"maps/objects/chozoallbgemmy01tur2/chozoallbgemmy01tur2.bcmdl",
	"maps/objects/chozoaqpath05x2/chozoaqpath05x2.bcmdl",
	"maps/objects/aquanature06b_01/aquanature06b_01.bcmdl",
	"maps/objects/chozoaqplatform01low/chozoaqplatform01low.bcmdl",
	"maps/objects/fish01_a/fish01_a.bcmdl",
	"maps/objects/fish01_c/fish01_c.bcmdl",
	"maps/objects/fish01_b/fish01_b.bcmdl",
	"maps/objects/fish01_e/fish01_e.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_casca43000.bcmdl",
	"maps/objects/fish01_f/fish01_f.bcmdl",
	"maps/objects/fish01_d/fish01_d.bcmdl",
	"maps/objects/chozoaqwallsetcorner01right/chozoaqwallsetcorner01right.bcmdl",
	"maps/objects/fish01_o/fish01_o.bcmdl",
	"maps/objects/fish01_n/fish01_n.bcmdl",
	"maps/objects/fish01_m/fish01_m.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca052.bcmdl",
	"maps/objects/chozoaqdoor01/chozoaqdoor01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca163.bcmdl",
	"maps/objects/siluro01_e/siluro01_e.bcmdl",
	"maps/objects/siluro01_a/siluro01_a.bcmdl",
	"maps/objects/siluro01_d/siluro01_d.bcmdl",
	"actors/props/pool_water11x3_gen/models/pool_water11x3_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca062.bcmdl",
	"actors/props/pool_water10x5_gen/models/pool_water10x5_gen.bcmdl",
	"maps/objects/chozoroomatrezzo01/chozoroomatrezzo01.bcmdl",
	"actors/props/pool_water9x2_gen/models/pool_water9x2_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_lshaft02.bcmdl",
	"actors/props/pool_water10x2_gen/models/pool_water10x2_gen.bcmdl",
	"actors/props/shootactivatorhidrogiga/models/shootactivatorhidrogiga.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_breakables10sg_casca014.bcmdl",
	"maps/objects/chozohangcable07_a/chozohangcable07_a.bcmdl",
	"actors/props/pool_water9x14_gen/models/pool_water9x14_gen.bcmdl",
	"maps/objects/chozoaqwallset04/chozoaqwallset04.bcmdl",
	"maps/objects/chozoaqdrain01/chozoaqdrain01.bcmdl",
	"maps/objects/chozoaqstairs01x3/chozoaqstairs01x3.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca151.bcmdl",
	"maps/objects/aquadigrock01/aquadigrock01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel31.bcmdl",
	"maps/objects/aquarockwall04x3simple/aquarockwall04x3simple.bcmdl",
	"actors/events/mapev_lum_ell/models/mapev_lum_ell.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part020_jp6_01.bcmdl",
	"maps/objects/chozobgstructure01x4b/chozobgstructure01x4b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_004sg_casca025.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part023_e3_00.bcmdl",
	"maps/objects/chozospenginebk03/chozospenginebk03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca155.bcmdl",
	"maps/objects/chozoaqwallset006/chozoaqwallset006.bcmdl",
	"actors/props/pool_water22x11_gen/models/pool_water22x11_gen.bcmdl",
	"maps/objects/chozoallpipe02/chozoallpipe02.bcmdl",
	"maps/fx/splash00/fx/splashout_00.bcmdl",
	"maps/objects/chozoaqpath02x4/chozoaqpath02x4.bcmdl",
	"maps/objects/chozoaqbgcorridor01corner/chozoaqbgcorridor01corner.bcmdl",
	"maps/objects/chozoaqpath05x1/chozoaqpath05x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca068.bcmdl",
	"actors/props/ev_demolition_block/fx/waterwave.bcmdl",
	"actors/props/pool_water21x4_gen/models/pool_water21x4_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca072.bcmdl",
	"actors/events/mapev_lapa_02/models/mapev_lapa_02.bcmdl",
	"maps/objects/chozoaqplatform01blow/chozoaqplatform01blow.bcmdl",
	"actors/props/pool_water14x6_gen/models/pool_water14x6_gen.bcmdl",
	"maps/objects/chozoaqbg01endr/chozoaqbg01endr.bcmdl",
	"maps/objects/chozoaqwallset05/chozoaqwallset05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca058.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca150.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lshaft_focos.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_aq_001.bcmdl",
	"maps/objects/aquanature02b/aquanature02b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca154.bcmdl",
	"maps/objects/chozoaqbg01endl/chozoaqbg01endl.bcmdl",
	"actors/characters/hydrogiga/fx/lightning.bcmdl",
	"maps/objects/seaslug01_a/seaslug01_a.bcmdl",
	"maps/objects/seaslug01_b/seaslug01_b.bcmdl",
	"maps/objects/seaslug01_c/seaslug01_c.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca069.bcmdl",
	"cutscenes/0063_hydrogiga-presentation/fx/distortioncone.bcmdl",
	"cutscenes/0063_hydrogiga-presentation/fx/waterstream.bcmdl",
	"maps/objects/chozopathemmy01end/chozopathemmy01end.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca073.bcmdl",
	"maps/objects/chozoaqfence03/chozoaqfence03.bcmdl",
	"maps/objects/chozohangcable01_a/chozohangcable01_a.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca152.bcmdl",
	"maps/objects/chozobasebgfloor01/chozobasebgfloor01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca059.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca156.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part021_e11.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part007_e6_bdecal_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca071.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca067.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part0019_jp9_lshaft01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca032.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca119.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca120.bcmdl",
	"maps/objects/chozoallpathgen02x4/chozoallpathgen02x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_sg_casca033.bcmdl",
	"actors/props/pool_water20x34_gen/models/pool_water20x34_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca051.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part002_jp2_vignette_00.bcmdl",
	"maps/objects/chozoaqpath01x1/chozoaqpath01x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel000.bcmdl",
	"actors/props/pool_water17x20_gen/models/pool_water17x20_gen.bcmdl",
	"maps/objects/chozoallpipesset01xcorner/chozoallpipesset01xcorner.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part011_jp2_vignette_00.bcmdl",
	"maps/objects/chozoaqfence01/chozoaqfence01.bcmdl",
	"maps/objects/lightenedkrill01_a/lightenedkrill01_a.bcmdl",
	"maps/objects/lightenedkrill01_b/lightenedkrill01_b.bcmdl",
	"maps/objects/chozohangcable04_a/chozohangcable04_a.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_sg_casca061.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part014_e2_00.bcmdl",
	"actors/props/pool_water15x8_gen/models/pool_water15x8_gen.bcmdl",
	"maps/objects/chozoaqcorridorpath01x4/chozoaqcorridorpath01x4.bcmdl",
	"maps/objects/chozoaqcorridorpath01x1/chozoaqcorridorpath01x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part019_jp9_00.bcmdl",
	"actors/items/powerup_ghostaura/models/powerup_ghostaura.bcmdl",
	"maps/objects/lightenedkrill02_a/lightenedkrill02_a.bcmdl",
	"actors/props/pool_water15x11_gen/models/pool_water15x11_gen.bcmdl",
	"maps/objects/chozoaqpathcorner01/chozoaqpathcorner01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel00b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lshaftfoco.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel02.bcmdl",
	"maps/objects/chozoaqhandrail01_stairsright/chozoaqhandrail01_stairsright.bcmdl",
	"maps/fx/underwaterfall/underwaterfall.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part022_e4_vignette.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca158.bcmdl",
	"maps/objects/cloud00/cloud00.bcmdl",
	"maps/objects/chozohangcable02_a/chozohangcable02_a.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_lightshaft02.bcmdl",
	"actors/events/mapev_fishes01/models/mapev_fishes.bcmdl",
	"maps/fx/spraypipe/fx/spraypipe.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part020_jp6_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part10_e3_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_mapmodel004.bcmdl",
	"maps/objects/chozoaqpathcorner04/chozoaqpathcorner04.bcmdl",
	"maps/objects/chozoaqhandrail01_stairsleft/chozoaqhandrail01_stairsleft.bcmdl",
	"maps/objects/aquanature04c/aquanature04c.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca161.bcmdl",
	"maps/objects/chozoallbggenwall03x1/chozoallbggenwall03x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_00_tubes1.bcmdl",
	"cutscenes/0031gravitysuiteobtention/fx/animfresnelnoise.bcmdl",
	"cutscenes/0033sonarobtention/fx/handfresnel_sonar.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lightshaft_03.bcmdl",
	"maps/objects/chozoaqhandrail01_1/chozoaqhandrail01_1.bcmdl",
	"actors/props/pool_water5x4_gen/models/pool_water5x4_gen.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part007_e6_00.bcmdl",
	"maps/objects/chozoaqpath03x4/chozoaqpath03x4.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca159.bcmdl",
	"maps/objects/chozoaqbg01x1/chozoaqbg01x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part023_e3_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part016_jp7_vignette01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mm03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_06_edificio3.bcmdl",
	"maps/objects/chozoaqbgcorridor01x1/chozoaqbgcorridor01x1.bcmdl",
	"cutscenes/0031gravitysuiteobtention/fx/gravity_groundrays.bcmdl",
	"cutscenes/0031gravitysuiteobtention/fx/gravity_trailsjump.bcmdl",
	"maps/objects/aquanature06b_05/aquanature06b_05.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part020_jp6_mapmodel06.bcmdl",
	"maps/objects/aquanature04d/aquanature04d.bcmdl",
	"maps/objects/chozobgstructure01x1/chozobgstructure01x1.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_lightshaft_02.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part018_jp10_lightshaft02.bcmdl",
	"maps/objects/aquanature04e/aquanature04e.bcmdl",
	"cutscenes/0031gravitysuiteobtention/fx/gravity_jumpingaura.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part018_jp10_02.bcmdl",
	"maps/objects/aquanature06b_04/aquanature06b_04.bcmdl",
	"cutscenes/0031gravitysuiteobtention/fx/gravity_groundenergy.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca110.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca112.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part006_jp10_sg_casca114.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part009_jp11_mapmodel03b.bcmdl",
	"maps/objects/chozoaqpath03x1/chozoaqpath03x1.bcmdl",
	"maps/objects/aquanature04b/aquanature04b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part020_jp6_02.bcmdl",
	"maps/objects/aquanature05d/aquanature05d.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part013_jg9_vignette009.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part001_e6_vignette01.bcmdl",
	"maps/objects/chozoalltripletube01x3/chozoalltripletube01x3.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part017_e2_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part14_e2_sg_vignette003.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part14_e2_sg_vignette004.bcmdl",
	"maps/fx/waterstream/waterstream02.bcmdl",
	"maps/fx/waterstream/waterstream03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part009_jp11_01.bcmdl",
	"maps/fx/aquasparksunderwater/aquasparksunderwater01.bcmdl",
	"maps/fx/aquasparksunderwater/aquasparksunderwater03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part004_m5_00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part003_e3_vignette00.bcmdl",
	"maps/fx/holograms/models/holocyl_16_9_vfx1.bcmdl",
	"maps/fx/holograms/models/holocyl_16_9_vfx2.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part007_e6_sg_vignette007.bcmdl",
	"maps/fx/amoebaparticles00/amoebaparticles00_underwater.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part018_jp10_01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_mapmodel10b.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part013_jg9_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/vignette_part013_jg9_vignetteoculta01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part004_m6_lshaft00.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part001_e6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_mapmodel08.bcmdl",
	"actors/props/ev_watervalve_hydrogiga/models/fx_dc.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part019_jp9_water.bcmdl",
	"actors/props/pool_aquadrain_aq_002/models/pool_aquadrain_aq_002.bcmdl",
	"actors/props/pool_aquadrain_aq_001/models/pool_aquadrain_aq_001.bcmdl",
	"maps/objects/chozobgwallemmy01/chozobgwallemmy01.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part002_jp2_planereflect03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part011_jp2_planereflect03.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part008_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part024_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part025_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s040_aqua/models/part021_e11_matte_00.bcmdl",
	"maps/fx/waterdripping/waterdripping.bcmdl",
	"maps/fx/waterdripping/waterdripping3x_left.bcmdl",
	"actors/characters/hydrogiga/fx/braid.bcmdl",
	"actors/characters/hydrogiga/fx/polyp.bcmdl",
	"actors/characters/hydrogiga/fx/swirl.bcmdl",
	"actors/characters/depthorn/models/depthorn.bcmdl",
	"actors/characters/slugger/models/slugger.bcmdl",
	"actors/characters/daivo/models/daivo.bcmdl",
	"actors/characters/batalloon/models/batalloon.bcmdl",
	"actors/characters/spittail/models/spittail.bcmdl",
	"actors/characters/sakai/fx/lightningsakai.bcmdl",
	"actors/weapons/spittailmagmaball/fx/magmaball.bcmdl",
	"actors/characters/chozorobotsoldier/fx/explosion5meters.bcmdl",
	"actors/characters/chozorobotsoldier/models/chozorobotsoldier.bcmdl",
	"actors/weapons/chozorobotsoldierbeam/fx/projectile_charged.bcmdl",
	"actors/characters/chozorobotsoldier/fx/uppercut_trail.bcmdl",
	"actors/characters/chozorobotsoldier/fx/ignition.bcmdl",
	"actors/weapons/chozorobotsoldierbeam/fx/projectile.bcmdl",
	"actors/characters/chozorobotsoldier/fx/dashend_trail.bcmdl",
	"actors/characters/chozorobotsoldier/fx/chozo_autoilum.bcmdl",
	"actors/characters/chozorobotsoldier/fx/surfaceanimfresnel.bcmdl",
	"actors/characters/chozorobotsoldier/fx/uppercut_cone.bcmdl",
	"maps/objects/maproom001r/maproom001r.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel07.bcmdl",
	"actors/characters/emmyforest/models/emmyforest.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_04.bcmdl",
	"actors/characters/chozoprofessor_cut/models/chozoprofessor_cut.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_p_lshaft001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel08.bcmdl",
	"actors/props/emmy_frozen/models/emmy_frozen.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel10.bcmdl",
	"actors/events/mapev_plant002/models/mapev_plant002_x6.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part011_e2_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part011_e2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel00.bcmdl",
	"actors/props/aeionstatue/models/aeionstatue.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part003_e4_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel01.bcmdl",
	"actors/events/mapev_plant002/models/mapev_plant002_x4.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part007_f5_vignette_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part016_f8_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_x1_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_12.bcmdl",
	"actors/events/mapev_planteater/models/mapev_planteater.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel04.bcmdl",
	"maps/objects/plantforestbranchbig01/plantforestbranchbig01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/plant01_001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_f4_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass03.bcmdl",
	"actors/events/mapev_plant001/models/mapev_plant001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_ivy01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel002.bcmdl",
	"maps/objects/plantforestbigleaves02_a/plantforestbigleaves02_a.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel_cinematic.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_06.bcmdl",
	"actors/events/mapev_plant002/models/mapev_plant002_x2.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/plant01_003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel13.bcmdl",
	"maps/objects/plantforestbigleaves04_a/plantforestbigleaves04_a.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel004.bcmdl",
	"maps/objects/plantforestbigleaves03_a/plantforestbigleaves03_a.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel18.bcmdl",
	"maps/objects/plantforestbigleaves02/plantforestbigleaves02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel05.bcmdl",
	"actors/props/pf_mushr_fr_ice_cube/fx/ice_explosion.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel004.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel04.bcmdl",
	"cutscenes/0033sonarobtention/fx/sphere_statue.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel05.bcmdl",
	"actors/events/mapev_plant003_small/models/mapev_plant003_small.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel011.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel012.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel17.bcmdl",
	"maps/objects/plantforestbigleaves03/plantforestbigleaves03.bcmdl",
	"maps/objects/plantforestbigleaves04/plantforestbigleaves04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/plant01_002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel11.bcmdl",
	"maps/objects/forestchozostatue01l/forestchozostatue01l.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_00.bcmdl",
	"maps/objects/forestchozostatue01r/forestchozostatue01r.bcmdl",
	"maps/objects/chozobgairfan02_a/chozobgairfan02_a.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel05.bcmdl",
	"maps/objects/chozosancplatform01x4/chozosancplatform01x4.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel010.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel_grass_04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part019_x1_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel008.bcmdl",
	"maps/objects/plantforestblue01/plantforestblue01.bcmdl",
	"maps/objects/plantforestblue01_a/plantforestblue01_a.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part011_e2_decal00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel03.bcmdl",
	"maps/objects/chozosanccolumn01x10left/chozosanccolumn01x10left.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part014_f8.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel12.bcmdl",
	"maps/objects/forestwallarenaboss04/forestwallarenaboss04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel03.bcmdl",
	"maps/objects/forestwallarenaboss02/forestwallarenaboss02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_f4_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_r9_sg_casca2133.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mattepaint02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel04.bcmdl",
	"maps/objects/plantforestblue02/plantforestblue02.bcmdl",
	"maps/objects/forestwallarenaboss01/forestwallarenaboss01.bcmdl",
	"maps/objects/chozosancplatform01endr/chozosancplatform01endr.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_f4_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_r9_sg_casca2135.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel010.bcmdl",
	"maps/objects/forestwallarenaboss03/forestwallarenaboss03.bcmdl",
	"maps/objects/forestwallarenaboss05/forestwallarenaboss05.bcmdl",
	"maps/objects/chozosancplatform01x1/chozosancplatform01x1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel011.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca76003.bcmdl",
	"actors/props/doorgrappleclosed/models/doorgrappleclosed.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel04.bcmdl",
	"actors/props/pool_water32x5_gen/models/pool_water32x5_gen.bcmdl",
	"actors/props/pool_water32x5_green/models/pool_water32x5_green.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part001_s2_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_r9_sg_casca2134.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part013_jp1_planereflect_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel16.bcmdl",
	"maps/objects/chozosancbgpath03x3/chozosancbgpath03x3.bcmdl",
	"maps/fx/waterfallforest/waterfallforest02.bcmdl",
	"actors/characters/autool_cut/models/autool_cut.bcmdl",
	"maps/objects/plantforesthongo01/plantforesthongo01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel15.bcmdl",
	"actors/props/pf_mushr_fr/models/pf_mushr_fr.bcmdl",
	"maps/objects/chozosancplatform01endl/chozosancplatform01endl.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74013.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel04.bcmdl",
	"actors/props/box_magnet_fr_001/models/box_magnet_fr_001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel005.bcmdl",
	"maps/objects/chozosancfrieze02l/chozosancfrieze02l.bcmdl",
	"actors/events/mapev_butterflygroup/models/mapev_butterflygroup.bcmdl",
	"maps/objects/chozosancfrieze02r/chozosancfrieze02r.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel01.bcmdl",
	"maps/fx/waterfallforest/waterfallforest03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74010.bcmdl",
	"maps/objects/chozobgstructure01x4c/chozobgstructure01x4c.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_plant01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_matte03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74017.bcmdl",
	"actors/props/pool_water20x11_gen/models/pool_water20x11_gen.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca76002.bcmdl",
	"maps/objects/chozosancbgpath01cornerl/chozosancbgpath01cornerl.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel_grass_03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74005.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel01.bcmdl",
	"maps/objects/chozoallwagonrail01end/chozoallwagonrail01end.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74014.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_matte04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel_grass_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel009.bcmdl",
	"maps/objects/forestflower/forestflower.bcmdl",
	"actors/characters/xparasite_cut/models/xparasite_cut.bcmdl",
	"maps/objects/chozosancbgpath01cornerr/chozosancbgpath01cornerr.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part018_pb7_00.bcmdl",
	"maps/objects/plantforestorganictree02/plantforestorganictree02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel000.bcmdl",
	"maps/objects/chozopathnormalzone01x4/chozopathnormalzone01x4.bcmdl",
	"maps/objects/chozoforestbg01/chozoforestbg01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel08.bcmdl",
	"maps/objects/chozobgmagmadoor01/chozobgmagmadoor01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel_grass_01.bcmdl",
	"maps/objects/chozosancwall01x1cornerin/chozosancwall01x1cornerin.bcmdl",
	"actors/props/pool_water17x10_green/models/pool_water17x10_green.bcmdl",
	"maps/objects/chozopathgeneric01x4/chozopathgeneric01x4.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel001.bcmdl",
	"actors/items/powerup_doublejump/models/powerup_doublejump.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel19.bcmdl",
	"maps/objects/chozosancbgpath01x1/chozosancbgpath01x1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mattepaint00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74015.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca76001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_breakables00sg_casca054.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca76000.bcmdl",
	"maps/objects/plantforestroot05/plantforestroot05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74012.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part005_f2.bcmdl",
	"actors/items/powerup_supermissile/models/powerup_supermissile.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74008.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel005.bcmdl",
	"maps/objects/chozomagnetglove01/chozomagnetglove01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel004.bcmdl",
	"maps/objects/chozoforestpathwood01x4v1/chozoforestpathwood01x4v1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part006_f6.bcmdl",
	"maps/objects/plantforestorganictree03/plantforestorganictree03.bcmdl",
	"maps/objects/chozoemmycolumn02x1/chozoemmycolumn02x1.bcmdl",
	"maps/objects/plantforestorganictree04/plantforestorganictree04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74007.bcmdl",
	"maps/objects/rockforestplatform01x4v2/rockforestplatform01x4v2.bcmdl",
	"maps/objects/rockforestplatform01x4v1/rockforestplatform01x4v1.bcmdl",
	"maps/objects/rockforestplatform01x4v3/rockforestplatform01x4v3.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74011.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74016.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel02.bcmdl",
	"maps/objects/chozoforestpathwood01x2v2/chozoforestpathwood01x2v2.bcmdl",
	"actors/events/mapev_bird/models/mapev_bird.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca116.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mapmodel03.bcmdl",
	"maps/objects/plantforestblue03_a/plantforestblue03_a.bcmdl",
	"maps/objects/plantforestbigleaves01/plantforestbigleaves01.bcmdl",
	"maps/objects/chozosancwall01x1cornerout/chozosancwall01x1cornerout.bcmdl",
	"maps/objects/plantforestblue03/plantforestblue03.bcmdl",
	"actors/props/pf_mushr_fr_ice_cube/models/pf_mushr_fr_ice_cube.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel_grass_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74004.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca74003.bcmdl",
	"maps/objects/rockforest02/rockforest02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables02sg_casca41009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables01sg_casca083.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables03sg_casca62000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mattepaint02.bcmdl",
	"maps/objects/chozomagpathchain02end/chozomagpathchain02end.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel16.bcmdl",
	"maps/objects/forestrock03/forestrock03.bcmdl",
	"maps/objects/forestmushtree03/forestmushtree03.bcmdl",
	"maps/objects/forestrock01/forestrock01.bcmdl",
	"maps/objects/forestrock04/forestrock04.bcmdl",
	"actors/props/pool_water14x7_green/models/pool_water14x7_green.bcmdl",
	"maps/objects/magnetziplinesp01cornerout/magnetziplinesp01cornerout.bcmdl",
	"maps/fx/resin/resin_horizontal_vignette.bcmdl",
	"maps/fx/resin/resin_horizontal.bcmdl",
	"maps/objects/forestrock02/forestrock02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables04sg_casca122.bcmdl",
	"actors/props/pool_water10x2_green/models/pool_water10x2_green.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel_grass_001.bcmdl",
	"maps/objects/magnetziplinesp01cornerin/magnetziplinesp01cornerin.bcmdl",
	"maps/objects/chozomagpathchain01end/chozomagpathchain01end.bcmdl",
	"actors/props/pool_water19x5_gen/models/pool_water19x5_gen.bcmdl",
	"maps/objects/rockforestplatform01x1v2/rockforestplatform01x1v2.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_matte_01.bcmdl",
	"maps/objects/rockforestplatform01x1v1/rockforestplatform01x1v1.bcmdl",
	"maps/objects/rockforestplatform01x1v3/rockforestplatform01x1v3.bcmdl",
	"maps/objects/forestmushtree01/forestmushtree01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part017_jp6_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel23.bcmdl",
	"maps/objects/plantforestroot02/plantforestroot02.bcmdl",
	"maps/objects/forestmushtree02/forestmushtree02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables00sg_casca039.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca67001.bcmdl",
	"maps/objects/forestdigrock01/forestdigrock01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables00sg_casca80000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel011.bcmdl",
	"maps/objects/chozopathgeneric01endr/chozopathgeneric01endr.bcmdl",
	"maps/objects/chozopathgeneric01endl/chozopathgeneric01endl.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel08.bcmdl",
	"actors/props/cut_professorpanel/models/cut_professorpanel.bcmdl",
	"maps/objects/chozosancwall01x4/chozosancwall01x4.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_sg_casca107.bcmdl",
	"maps/objects/chozopathnormalzone01x1cornera/chozopathnormalzone01x1cornera.bcmdl",
	"maps/objects/rockforest01/rockforest01.bcmdl",
	"maps/objects/chozopathnormalzone01x1cornerb/chozopathnormalzone01x1cornerb.bcmdl",
	"actors/props/rail_magnet/models/rail_magnet_fr_001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca69000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part008_r4_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca38006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca67000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel07.bcmdl",
	"maps/objects/plantforestroot09/plantforestroot09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca031.bcmdl",
	"maps/objects/forestdigrock03/forestdigrock03.bcmdl",
	"maps/objects/plantforestroot04/plantforestroot04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_sg_casca106.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part019_jp8_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca128.bcmdl",
	"maps/objects/plantforestorganictree01/plantforestorganictree01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables00sg_casca57000.bcmdl",
	"maps/objects/chozosancwall01x1b/chozosancwall01x1b.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part021_n2_mapmodel01_vignette.bcmdl",
	"maps/objects/chozosanclamp02/chozosanclamp02.bcmdl",
	"maps/objects/plantforestroot06/plantforestroot06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_casca75000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca112.bcmdl",
	"maps/objects/chozosanclamp01/chozosanclamp01.bcmdl",
	"maps/objects/plantforestroot03/plantforestroot03.bcmdl",
	"actors/props/pool_water5x3_gen/models/pool_water5x3_gen.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca024.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca68000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables08sg_casca60000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables07sg_casca60002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel12b.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables05sg_casca60003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables06sg_casca60001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca69001.bcmdl",
	"maps/objects/chozosancbg04/chozosancbg04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vigmette_1qpart012_f2_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca023.bcmdl",
	"maps/objects/chozobgstructure01corner3/chozobgstructure01corner3.bcmdl",
	"maps/fx/resin/resin.bcmdl",
	"maps/objects/plantforestroot10/plantforestroot10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca119.bcmdl",
	"maps/objects/chozopathgeneric01x1/chozopathgeneric01x1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca55000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_f4_grass06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_casca75001.bcmdl",
	"maps/objects/forestdigrock02/forestdigrock02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca82000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca113.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca64001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_lightshaft01.bcmdl",
	"maps/objects/plantforestorganictree05/plantforestorganictree05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part020_f3.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_casca75002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca058.bcmdl",
	"maps/objects/forestwallpath01v3/forestwallpath01v3.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca35002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca026.bcmdl",
	"maps/objects/plantforestroot11/plantforestroot11.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca54000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca025.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca030.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca77000.bcmdl",
	"maps/objects/forestwallpath01/forestwallpath01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca56000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables10sg_casca78000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca35003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca110.bcmdl",
	"maps/objects/plantforestroot08/plantforestroot08.bcmdl",
	"maps/objects/forestwallpath01v2/forestwallpath01v2.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca117.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca81003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca022.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca81000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca109.bcmdl",
	"maps/objects/plantforestroot07/plantforestroot07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca115.bcmdl",
	"maps/objects/plantforestroot01/plantforestroot01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca32006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca32007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_lightshaft001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f0_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_breakables09sg_casca64000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mattepaint03.bcmdl",
	"maps/objects/chozomagpathchain01x1/chozomagpathchain01x1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca32009.bcmdl",
	"maps/objects/chozopathnormalzone01x1/chozopathnormalzone01x1.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_f4_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel_grass_02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_lightshaft03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part021_jp1_reflection.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_breakable_f8_casca00sg.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca81002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca38005.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca32010.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_sg_casca81001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_sg_casca32008.bcmdl",
	"maps/objects/plantforestminis05/plantforestminis05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_tapa.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part007_f5_vignette_02.bcmdl",
	"maps/objects/plantforestminis06/plantforestminis06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_mapmodel_16.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_mapmodel09.bcmdl",
	"maps/objects/plantforestminis04/plantforestminis04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel005.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_casca052.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_lightshaft001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_matte05.bcmdl",
	"maps/objects/plantforestminis03/plantforestminis03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part011_e2_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part002_f2_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part001_s2_vignette.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part016_f8_03.bcmdl",
	"maps/objects/plantforestminis07/plantforestminis07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part011_e2_vignette01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_f2_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_x1_breakable02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_12.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_08.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_07.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part012_x1_breakable_09.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca005.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca008.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca007.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_jp8_lightshaft01.bcmdl",
	"maps/fx/firefliesparticles/firefliesparticles00.bcmdl",
	"maps/fx/fliesparticles/fliesparticles00.bcmdl",
	"maps/fx/sporesparticles00/sporesparticles00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca006.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part016_f8_04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_x1_breakable03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca004.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/vignette_part016_f8_02x.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca002.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part019_x1_sg_casca003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_vignette_camera18.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_mattepaint00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mapmodel009.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part005_f2_mattepaint00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part007_f5_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_matte01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mapmodel000.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part014_f8_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_matte_cinematic.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008part009_pb5_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_f4_matte003.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part008_r4_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part020_f3_mattepaint00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mattepaint02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_lightshaft02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part006_f6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part017_jp6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft05.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part003_e4_lightshaft03.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part016_f8_lightshaft04.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part018_pb7_mattepaint001.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part009_x2_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part010_f3_mattepaint00.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part015_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part025_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s050_forest/models/part013_x1_tapa_00.bcmdl",
	"actors/characters/scourge/models/scourge.bcmdl",
	"actors/characters/yampa/models/yampa.bcmdl",
	"actors/characters/chozowarriorx/models/chozowarriorx.bcmdl",
	"actors/characters/chozowarrior/models/chozowarrior.bcmdl",
	"actors/characters/quetzoa/models/quetzoa.bcmdl",
	"actors/characters/specimen_x4a/models/specimen_x4a.bcmdl",
	"actors/characters/quetzoa/fx/charge_rays.bcmdl",
	"actors/characters/superquetzoa/fx/rays_body.bcmdl",
	"actors/characters/superquetzoa/fx/rays_wing_r.bcmdl",
	"actors/characters/superquetzoa/fx/rays_wing_l.bcmdl",
	"actors/characters/superquetzoa/fx/rays_tail.bcmdl",
	"actors/characters/superquetzoa/fx/rays_wings.bcmdl",
	"actors/weapons/quetzoaenergywave/fx/floor_rays.bcmdl",
	"actors/characters/supergoliath/models/supergoliath.bcmdl",
	"actors/characters/core_x/models/destroyer.bcmdl",
	"actors/characters/core_x/fx/death_glow.bcmdl",
	"actors/characters/supergoliath/fx/rays.bcmdl",
	"actors/characters/supergoliath/fx/trail.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel025b.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel30.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel04.bcmdl",
	"actors/props/ev_gatesealed/models/ev_gatesealed.bcmdl",
	"actors/props/db_reg_qt_001/models/db_reg_qt_001.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel25.bcmdl",
	"actors/props/ev_gatesealed_closed/models/ev_gatesealed_closed.bcmdl",
	"actors/props/ev_gatesealed_openned/models/ev_gatesealed_openned.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel05.bcmdl",
	"actors/props/chozoastro/models/chozoastro.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel30.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel28.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel12c.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel00.bcmdl",
	"maps/objects/statuegatesanctuary/statuegatesanctuary.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel10.bcmdl",
	"maps/objects/chozosancpillar01break/chozosancpillar01break.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel23.bcmdl",
	"actors/props/camerasanc/models/camerasanc.bcmdl",
	"actors/props/ev_gatesealed_aut_001/models/ev_gatesealed_aut_001.bcmdl",
	"maps/objects/chozosancstatue02/chozosancstatue02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel16.bcmdl",
	"actors/events/mapev_bigdebrisqua01/models/mapev_bigdebrisqua01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel27.bcmdl",
	"maps/objects/chozosancfullflag01/chozosancfullflag01.bcmdl",
	"maps/objects/chozosancfullflag02/chozosancfullflag02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel09.bcmdl",
	"maps/objects/chozosancstatue01/chozosancstatue01.bcmdl",
	"actors/characters/chozozombiex_cut/models/chozozombiex_cut.bcmdl",
	"maps/fx/fullflag01fx/fx/fullflag01fx_int01.bcmdl",
	"maps/fx/fullflag01fx/fx/fullflag01fx_int02.bcmdl",
	"maps/fx/fullflag03fx/fx/fullflag03_int01.bcmdl",
	"maps/fx/fullflag03fx/fx/fullflag03_int02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel28.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel20.bcmdl",
	"actors/events/mapev_armor/models/mapev_armor.bcmdl",
	"actors/props/quarantine_bridge/models/quarantine_bridge.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_02sg_casca24001.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_14sg_casca23003.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_02sg_casca24002.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23005.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23006.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23002.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23004.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23001.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel12b.bcmdl",
	"maps/objects/chozosanccolumn01x10right/chozosanccolumn01x10right.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_14sg_casca23002.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23000.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23003.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_14sg_casca23004.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23009.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23007.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23008.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_15sg_casca23010.bcmdl",
	"maps/objects/chozosanccolumn01x5right/chozosanccolumn01x5right.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel26.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_08sg_casca16001.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_09sg_casca16000.bcmdl",
	"maps/objects/chozobase2statue01/chozobase2statue01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel29.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_13sg_casca23003.bcmdl",
	"maps/fx/fullflag02fx/fx/fullflag02_int02.bcmdl",
	"maps/fx/fullflag02fx/fx/fullflag02_int01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_a3_matepaint.bcmdl",
	"maps/objects/chozosanwall01x4/chozosanwall01x4.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel21.bcmdl",
	"actors/items/powerup_plasmabeam/models/powerup_plasmabeam.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part03_s4_breakablemodel_13sg_casca23001.bcmdl",
	"cutscenes/0013firstencounterchozozombie/fx/mudtrail.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel02.bcmdl",
	"actors/events/mapev_bigdebrisqua02/models/mapev_bigdebrisqua02.bcmdl",
	"maps/objects/chozosanccolumn08/chozosanccolumn08.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel01.bcmdl",
	"maps/objects/chozosancpilar/chozosancpilar.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_mapmodel11.bcmdl",
	"maps/objects/chozosanwall01x1/chozosanwall01x1.bcmdl",
	"actors/props/ev_quarantine_roomlights/models/ev_quarantine_roomlights.bcmdl",
	"maps/objects/chozosancwall01x1cornerinb/chozosancwall01x1cornerinb.bcmdl",
	"maps/objects/chozosancbasestatue01/chozosancbasestatue01.bcmdl",
	"actors/props/ev_soldierpresentation/models/ev_soldierpresentation.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel21.bcmdl",
	"maps/objects/chozosancwall01x1corneroutb/chozosancwall01x1corneroutb.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_planereflection.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part05_n1_vignette01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part03_n3_vignette00.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_lshaft02.bcmdl",
	"maps/objects/chozomagemmypath02x4/chozomagemmypath02x4.bcmdl",
	"maps/objects/chozosancwall01x1/chozosancwall01x1.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel05.bcmdl",
	"maps/objects/chozosancpath01x4/chozosancpath01x4.bcmdl",
	"maps/objects/chozosancwall01x4b/chozosancwall01x4b.bcmdl",
	"maps/objects/chozosancpath02x1/chozosancpath02x1.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel24.bcmdl",
	"maps/objects/chozosancbgdoor/chozosancbgdoor.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_lshaft01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel03sg_casca017.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel06sg_casca020.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel04sg_casca016.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel07sg_casca021.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel27.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel02sg_casca018.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel05sg_casca019.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_lshaft01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel00sg_casca015.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part05_n1_breakablemodel01sg_casca022.bcmdl",
	"cutscenes/0067chozowarriorxpresentation/fx/chozopres_trail.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_lshaft01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part001_p_lshaft02.bcmdl",
	"maps/objects/chozosanccolumn02x2right/chozosanccolumn02x2right.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_lshaft03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel14.bcmdl",
	"cutscenes/0004quarantinedoorsopen/fx/kraid_camera_color.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part004_n1_lshaft03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_n3_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part003_n3_mapmodel16.bcmdl",
	"cutscenes/0113quarantinearrival/fx/airpressure.bcmdl",
	"maps/fx/dustlight/dustlight00.bcmdl",
	"maps/fx/dustlight/dustlight01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part03_n3_vignette01.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part03_n3_vignette05.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part05_n3_vignette02.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part05_n1_vignette03.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/vignette_part05_n1_vignette04.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n1_mapmodel029.bcmdl",
	"maps/fx/brownsmokes/fx/brownsmoke01_center.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part01_p_vignette.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part005_n3_matepaint.bcmdl",
	"maps/levels/c10_samus/s060_quarantine/models/part001_n3_planereflection.bcmdl",
	"maps/objects/chozosancflag01/chozosancflag01.bcmdl",
	"maps/fx/labdryice/fx/labdryicecorner00_left.bcmdl",
	"maps/objects/savestation001emmyl/savestation001emmyl.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_11.bcmdl",
	"actors/characters/emmysanc/models/emmysanc.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_05.bcmdl",
	"actors/characters/chozoprofessor/models/chozoprofessor.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_15.bcmdl",
	"actors/props/muralbreakeable_cut40/models/muralbreakeable_cut40.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_10c.bcmdl",
	"actors/props/ev_chozowall/models/ev_chozowall.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_17.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_11.bcmdl",
	"maps/objects/chozosanctower02/chozosanctower02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_mapmodel017.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_centralunit02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_centralunitl01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_06.bcmdl",
	"actors/props/db_reg_b2_010/models/db_reg_b2_010.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel09.bcmdl",
	"actors/props/db_reg_b2_006/models/db_reg_b2_006.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_p_lshaft001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_mapmodel007.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel04.bcmdl",
	"actors/props/db_reg_b2_009/models/db_reg_b2_009.bcmdl",
	"actors/props/db_reg_b2_011/models/db_reg_b2_011.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel06.bcmdl",
	"maps/objects/chozosanctower01/chozosanctower01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel01.bcmdl",
	"actors/props/mural_cut40/models/mural_cut40.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel25.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel16.bcmdl",
	"maps/objects/chozosancstatue/chozosancstatue.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_19.bcmdl",
	"actors/props/db_reg_b2_003/models/db_reg_b2_003.bcmdl",
	"maps/objects/statuegatesanctuarylow/statuegatesanctuarylow.bcmdl",
	"actors/props/db_reg_b2_001/models/db_reg_b2_001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel04.bcmdl",
	"maps/objects/chozosancpillar01/chozosancpillar01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel17.bcmdl",
	"maps/objects/chozobgwater02x4/chozobgwater02x4.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_mapmodel008.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_07.bcmdl",
	"actors/props/db_reg_b2_004/models/db_reg_b2_004.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel07.bcmdl",
	"maps/objects/chozosancstatue03/chozosancstatue03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_11.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_20.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel26.bcmdl",
	"actors/characters/superquetzoa/models/superquetzoa.bcmdl",
	"actors/props/professor_death/models/professor_death.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_09b.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel01.bcmdl",
	"maps/fx/fullflag01fx/fx/fullflag01fx_ext01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel05.bcmdl",
	"maps/fx/fullflag03fx/fx/fullflag03_ext01.bcmdl",
	"maps/fx/fullflag03fx/fx/fullflag03_ext02.bcmdl",
	"maps/objects/chozosancstatuel2/chozosancstatuel2.bcmdl",
	"actors/props/pool_water37x22_gen/models/pool_water37x22_gen.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_matte_01.bcmdl",
	"actors/props/db_reg_b2_005/models/db_reg_b2_005.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel12.bcmdl",
	"maps/objects/chozosancstatuebig01/chozosancstatuebig01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_matte01.bcmdl",
	"actors/props/db_reg_b2_008/models/db_reg_b2_008.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel02.bcmdl",
	"actors/props/pool_water_emmysanc_001/models/pool_water_emmysanc_001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_matte01.bcmdl",
	"maps/objects/chozosancstatuebig02/chozosancstatuebig02.bcmdl",
	"maps/objects/chozosancstatuebig02mirror/chozosancstatuebig02mirror.bcmdl",
	"actors/props/fedship_hol/models/fedship_hol.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_matte_01.bcmdl",
	"actors/props/db_reg_b2_007/models/db_reg_b2_007.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_lightshaftinside01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_centralunit00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_matte00.bcmdl",
	"maps/objects/chozosanccolumn05/chozosanccolumn05.bcmdl",
	"maps/objects/chozosancstatue05/chozosancstatue05.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaftinside01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_03.bcmdl",
	"maps/objects/chozosanccolumn07/chozosanccolumn07.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel03.bcmdl",
	"maps/objects/chozosanccolumn01x5left/chozosanccolumn01x5left.bcmdl",
	"maps/objects/chozosancstatue04/chozosancstatue04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_part006model.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_12.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_breakables00sg_casca035.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel15.bcmdl",
	"actors/props/ev_ph2drain_activator/models/ev_ph2drain_activator.bcmdl",
	"maps/objects/chozosancfrieze01/chozosancfrieze01.bcmdl",
	"actors/props/ev_ph2drain_platform/models/ev_ph2drain_platform.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_breakables00sg_casca021.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_breakables01sg_casca022.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part005_jp1_planereflect_01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel27.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel28.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_breakables00sg_casca139.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_breakables03sg_casca032.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_breakables01sg_casca140.bcmdl",
	"maps/fx/fullflag02fx/fx/fullflag02_ext01.bcmdl",
	"maps/fx/fullflag02fx/fx/fullflag02_ext02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_lightshaftinside01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mapmodel_18.bcmdl",
	"maps/fx/waterstream/waterstream04.bcmdl",
	"maps/objects/chozosancsidewall05slice/chozosancsidewall05slice.bcmdl",
	"actors/props/cut_professorpanelagua/models/cut_professorpanelagua.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part003_jg13_mapmodel_vignette.bcmdl",
	"maps/objects/chozosancsidewall01x1cornerdown/chozosancsidewall01x1cornerdown.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_15.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_lightshaftinside01.bcmdl",
	"maps/objects/chozosancsidewall01x1cornerup/chozosancsidewall01x1cornerup.bcmdl",
	"maps/objects/chozosanccolumn04/chozosanccolumn04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_decal04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel29.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel30.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_vignette.bcmdl",
	"maps/objects/chozosancfullflagn02/chozosancfullflagn02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_p_lshaft.bcmdl",
	"maps/objects/chozosanccolumn03a/chozosanccolumn03a.bcmdl",
	"maps/objects/chozosancbgwalljoint01/chozosancbgwalljoint01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_decal02.bcmdl",
	"maps/objects/chozosanccolumn03c/chozosanccolumn03c.bcmdl",
	"maps/objects/chozosancbgpath02x2/chozosancbgpath02x2.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel04.bcmdl",
	"maps/objects/chozohangcable03_a/chozohangcable03_a.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_decal00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaftinside05.bcmdl",
	"maps/objects/chozosancnest03/chozosancnest03.bcmdl",
	"maps/objects/chozosancstatuenew03/chozosancstatuenew03.bcmdl",
	"maps/objects/chozoallbggenwall06joint/chozoallbggenwall06joint.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_mapmodel_14.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part002_x3_vignette.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mapmodel_09.bcmdl",
	"maps/objects/chozosanchandrail01/chozosanchandrail01.bcmdl",
	"maps/objects/chozosancnest04/chozosancnest04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_tapa01.bcmdl",
	"actors/props/pool_water20x18_gen/models/pool_water20x18_gen.bcmdl",
	"maps/objects/chozosancbg02/chozosancbg02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part009_pb5_00.bcmdl",
	"maps/objects/chozosancnest02/chozosancnest02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_o6_lshaft01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_lightshaftinside01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_break00sg_casca123.bcmdl",
	"maps/objects/chozosancnest01/chozosancnest01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca05sg_casca098.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca06sg_casca133.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_o6_lshaft03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_breakables02sg_casca034.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaftinside03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaftinside02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_breakables01sg_casca033.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_decal03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_matte02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_lshaft01.bcmdl",
	"actors/items/powerup_spacejump/models/powerup_spacejump.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part004_s5_vignette00.bcmdl",
	"maps/objects/chozosancpathfront04x1/chozosancpathfront04x1.bcmdl",
	"maps/objects/chozosancpathfront01endr/chozosancpathfront01endr.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part010_r6_vignette.bcmdl",
	"maps/objects/chozoemmytunnelbg01t2/chozoemmytunnelbg01t2.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_tapa.bcmdl",
	"maps/objects/chozosancpathfront01x4/chozosancpathfront01x4.bcmdl",
	"maps/objects/chozosanclamp03/chozosanclamp03.bcmdl",
	"cutscenes/0040sancemmypresentation_part1/fx/metroidpulsetrails.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_matte02.bcmdl",
	"maps/objects/chozosancpathfront01endl/chozosancpathfront01endl.bcmdl",
	"maps/objects/chozosancpathfront02x1/chozosancpathfront02x1.bcmdl",
	"maps/objects/chozosancpath01x1/chozosancpath01x1.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_decal01.bcmdl",
	"maps/objects/chozosancpath01endl/chozosancpath01endl.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part011_jp1_vignette_00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca07sg_casca091.bcmdl",
	"maps/objects/chozosancpathfront03x1/chozosancpathfront03x1.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca09sg_casca089.bcmdl",
	"maps/objects/chozosancpath01endr/chozosancpath01endr.bcmdl",
	"maps/objects/chozosancpathfront01x1/chozosancpathfront01x1.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part007_o4_sg_vignette00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca12sg_casca084.bcmdl",
	"maps/objects/chozosanccolumn03b/chozosanccolumn03b.bcmdl",
	"maps/objects/chozostationcolumn06/chozostationcolumn06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca00sg_casca085.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca08sg_casca090.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca04sg_casca104.bcmdl",
	"maps/objects/chozosancsidewall01x1/chozosancsidewall01x1.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca11sg_casca083.bcmdl",
	"maps/fx/resin/resin_vignette.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_matte02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaftinside04.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca10sg_casca082.bcmdl",
	"maps/objects/chozosancstatueshield/chozosancstatueshield.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca01sg_casca088.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_sg_casca03sg_casca103.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_o6_lshaft02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part001_pb3_00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_breakables12sg_casca370sg_casca368.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_p_lightshaft01.bcmdl",
	"maps/objects/chozosancsidewall01x4/chozosancsidewall01x4.bcmdl",
	"maps/objects/chozosancbgwalljoint01b/chozosancbgwalljoint01b.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel12.bcmdl",
	"maps/objects/chozosanccolumn02corner/chozosanccolumn02corner.bcmdl",
	"actors/weapons/emmywave/fx/wavebeamimpact_cine.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_matte_02.bcmdl",
	"cutscenes/0040sancemmypresentation_part1/fx/smokeshotmesh.bcmdl",
	"maps/objects/chozosanccolumn06/chozosanccolumn06.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part008_r3_00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_planereflection.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_matte_02.bcmdl",
	"maps/objects/chozohangcable05_a/chozohangcable05_a.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part001_pb3_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part004_s5_tapa.bcmdl",
	"maps/objects/chozosanccolumn02x1/chozosanccolumn02x1.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_matte01.bcmdl",
	"maps/objects/chozosanccolumn01/chozosanccolumn01.bcmdl",
	"maps/objects/chozosanccolumn02x2left/chozosanccolumn02x2left.bcmdl",
	"maps/objects/chozoroomwall03/chozoroomwall03.bcmdl",
	"actors/props/pool_ice_30x2_gen/models/pool_ice_30x2_gen.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part007_o4_sg_vignette010.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part008_r3_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part010_r6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part006_pb6_01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette003.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette004.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_o5_lshaft01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette006.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette017.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mattepaintclouds01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette005.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_mattepaintclouds01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part003_jg13_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part004_s5_vignette03.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part007_o4_sg_vignette011.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part002_x3_vigbreakable_00.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasb001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasc001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasa001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasb.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasc.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascasa.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascas001.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_p_cascas.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part009_pb5_ocultavignette01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part004_s5_vignette02.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part008_r3_09.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part012_e11_sg_vignette007.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part008_r3_08.bcmdl",
	"maps/objects/chozosancbgwalljoint01c/chozosancbgwalljoint01c.bcmdl",
	"maps/objects/chozosanccolumn01b/chozosanccolumn01b.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part009_pb5_lightshaft01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mattepaintclouds02.bcmdl",
	"cutscenes/0040sancemmypresentation_part1/fx/dustslide_trail.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part004_s5_mattepaintclouds01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part006_pb6_matte01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/vignette_part007_o4_sg_vignette012.bcmdl",
	"cutscenes/0040sancemmypresentation_part2b/fx/fakelightshotbluebrigther.bcmdl",
	"cutscenes/0040sancemmypresentation_part1/fx/decalslide.bcmdl",
	"cutscenes/0040sancemmypresentation_part2b/fx/fakelightshotblue.bcmdl",
	"maps/fx/labdryice/fx/labdryice_vertical01medium.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part011_jp1_planereflect01.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part007_o4_sg_vignette013.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part013_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part014_n2_planereflection.bcmdl",
	"maps/levels/c10_samus/s070_basesanc/models/part012_e11_mapmodel18b.bcmdl",
	"actors/characters/sabotoru/models/sabotoru.bcmdl",
	"actors/characters/groundshocker/models/groundshocker.bcmdl",
	"actors/characters/quetshocker/models/quetshocker.bcmdl",
	"actors/characters/groundshocker/fx/raysground.bcmdl",
	"actors/characters/groundshocker/fx/raysup.bcmdl",
	"actors/characters/groundshocker/fx/rayscenter.bcmdl",
	"actors/characters/blindfly/models/blindfly.bcmdl",
	"actors/characters/emmysanc/fx/emmywave.bcmdl",
	"actors/characters/superquetzoa/fx/charge_rays.bcmdl",
	"actors/weapons/superquetzoavoidmissiles/fx/void_projectile.bcmdl",
	"actors/weapons/superquetzoaenergywave/fx/floor_rays.bcmdl",
	"actors/props/block_cut43/models/block_cut43.bcmdl",
	"actors/props/block_pbtube_001/models/block_pbtube_001.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel24.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel23.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel52.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel22.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel39.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel13.bcmdl",
	"actors/props/block_pbtube_002/models/block_pbtube_002.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel27.bcmdl",
	"actors/props/capsulelaunchershipyard/models/capsulelaunchershipyard.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_04.bcmdl",
	"actors/characters/chozocommanderx/models/chozocommanderx.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel45.bcmdl",
	"actors/events/mapev_bridgeparts/models/mapev_bridgeparts.bcmdl",
	"actors/characters/emmyshipyard/models/emmyshipyard.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel31.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel53.bcmdl",
	"cutscenes/0112endgame/fx/rocks_planet_01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel25.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel18.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel49.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel28.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel50.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_11.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel08.bcmdl",
	"actors/props/block_pbtube_003/models/block_pbtube_003.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_20.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel44.bcmdl",
	"actors/props/ev_escape_2_end/models/ev_escape_2_end.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel21.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel51.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_14.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel43.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel35.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel20.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel15.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel12.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel14.bcmdl",
	"actors/props/emmy_shipyard/models/emmy_shipyard.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel38.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel40.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel08.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel30.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel41.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_15.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel04.bcmdl",
	"actors/props/ev_escape_4/models/ev_escape_4.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel19.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel13.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_bichos.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel29.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel47c.bcmdl",
	"actors/props/planetzdr/models/planetzdr_end.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel42.bcmdl",
	"actors/props/samus_ship_s/models/samus_ship_s.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel00.bcmdl",
	"maps/objects/chozoaqwheeldevice01_a/chozoaqwheeldevice01_a.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel46b.bcmdl",
	"maps/objects/chozoshiptunnel01x1/chozoshiptunnel01x1.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel46.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel48.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_17.bcmdl",
	"maps/objects/communicationroom3door/communicationroom3door.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mapmodel03.bcmdl",
	"actors/props/block_pbtube_002/fx/explosion.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel47.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel14.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mapmodel02.bcmdl",
	"actors/characters/chozowarriorelite/models/chozowarriorelite.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel16.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel47b.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel17.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_13.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_hideable02.bcmdl",
	"maps/objects/chozoskybasecontroltop01_a/chozoskybasecontroltop01_a.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel05.bcmdl",
	"actors/props/ev_escape_2_init/models/ev_escape_2_init.bcmdl",
	"actors/props/block_pbtube_002/fx/cristal_fracture.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_hideable00.bcmdl",
	"maps/objects/chozoskybasecontroldesk01/chozoskybasecontroldesk01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel37.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel36.bcmdl",
	"actors/characters/chozocommander_facial/models/chozocommander_face.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_06_decals01.bcmdl",
	"actors/characters/takumaku_cut/models/takumaku_cut.bcmdl",
	"actors/props/ev_escape_1/models/ev_escape_1.bcmdl",
	"actors/props/centralunitshipyard/models/centralunitshipyard.bcmdl",
	"actors/props/cut_012_capsule/models/cut_012_capsule.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_02.bcmdl",
	"maps/objects/shipyardship01_a/shipyardship01_a.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables62sg_casca119.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables45sg_casca103.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables52sg_casca099.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables68sg_casca239.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables46sg_casca109.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables60sg_casca114.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables51sg_casca102.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables67sg_casca242.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_18.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mapmodelcwx001.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_08.bcmdl",
	"actors/events/mapev_cwxencounter02_ship/fx/shiprainsplash.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_px_skybasemodel03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_capsule.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_decal04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_decals00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables48sg_casca106.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables63sg_casca117.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_12.bcmdl",
	"maps/objects/chozoskycolumn02/chozoskycolumn02.bcmdl",
	"maps/objects/chozoskycolumn01/chozoskycolumn01.bcmdl",
	"cutscenes/0112endgame/fx/nebula_final_01.bcmdl",
	"actors/characters/bigx_commanderx/models/bigx_commanderx.bcmdl",
	"maps/objects/chozoshipcapsule/chozoshipcapsule.bcmdl",
	"maps/objects/chozoshipasset03/chozoshipasset03.bcmdl",
	"maps/objects/chozoskycolumn03/chozoskycolumn03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel11.bcmdl",
	"maps/objects/chozoskycolumn04/chozoskycolumn04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_06_decals03.bcmdl",
	"maps/fx/splash00/fx/splashout_00_3m.bcmdl",
	"maps/objects/chozoskycolumn07/chozoskycolumn07.bcmdl",
	"actors/props/block_hyperbeam/models/block_hyperbeam.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_decal05.bcmdl",
	"actors/props/capsulelaunchershipyard/fx/sphere_shipyard.bcmdl",
	"cutscenes/0108shipyard/fx/samus_splashenter.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_decal03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_21.bcmdl",
	"actors/props/ev_commanderx_rock01/models/ev_commanderx_rock01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables34sg_casca071.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_px_skybasemodel02.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/energy_absortion.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_fronthide.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_s6_mattepaint02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part001_o5_mattepaint01.bcmdl",
	"cutscenes/0071chozowarriorxelitepresentation/fx/fronttrail_prep01.bcmdl",
	"maps/objects/shipyardrock07/shipyardrock07.bcmdl",
	"cutscenes/0071chozowarriorxelitepresentation/fx/backtrail_prep01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part004_o6_vignette01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables10sg_casca089.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mattepaint02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables36sg_casca073.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables30sg_casca066.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_mapmodel11.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel09.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables32sg_casca068.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_decal02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables09sg_casca087.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables70sg_casca131.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables73sg_casca077.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_s6_mattepaint02.bcmdl",
	"timelines/x_transformation/fx/whirlwind_low.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables79.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_px_skybasemodel07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables78.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_decal00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables12sg_casca129.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mattepaint02.bcmdl",
	"maps/objects/chozoskypathroofend/chozoskypathroofend.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mattepaint03.bcmdl",
	"maps/objects/chozohangcable09_a/chozohangcable09_a.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables71sg_casca137.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/end_armmetroidnization.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part003_e1_mapmodel00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables72sg_casca136.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables01sg_casca132.bcmdl",
	"maps/objects/chozoskypathroofangle1/chozoskypathroofangle1.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables07sg_casca133.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_19.bcmdl",
	"maps/objects/chozobgstructure01corner1/chozobgstructure01corner1.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part002_o4_00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables08sg_casca134.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables06sg_casca135.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca08.bcmdl",
	"maps/objects/chozoskypathroofangle2/chozoskypathroofangle2.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca15.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables15sg_casca128.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part007_e11_vignette00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_hideable01.bcmdl",
	"maps/objects/chozoskypathrooframp/chozoskypathrooframp.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables74sg_casca088.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca14.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_breakables00sg_casca13.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/rays_energy_absortion.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part003_e1_vignette00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables77sg_casca085.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables76.bcmdl",
	"maps/objects/chozoskypathx4/chozoskypathx4.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_14.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_15.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables47sg_casca105.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables42sg_casca104.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables59sg_casca118.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables43sg_casca108.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables50sg_casca100.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables66sg_casca240.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables44sg_casca107.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables61sg_casca115.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables64sg_casca116.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables49sg_casca101.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables65sg_casca241.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables05sg_casca111.bcmdl",
	"maps/objects/chozoskypathroofx4/chozoskypathroofx4.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_16.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_13.bcmdl",
	"maps/objects/chozoskycolumn08/chozoskycolumn08.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part006_e6_00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_s6_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables14sg_casca126.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_hideable03.bcmdl",
	"actors/fx/escape_glass/fx/escape_glass.bcmdl",
	"maps/objects/chozoskycolumn05/chozoskycolumn05.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/cu_rays.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables13sg_casca127.bcmdl",
	"maps/objects/chozoskypathend/chozoskypathend.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables11sg_casca130.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables31sg_casca069.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_s6_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables35sg_casca072.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/melee.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_16.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_11.bcmdl",
	"maps/objects/chozoskypathroofx1/chozoskypathroofx1.bcmdl",
	"maps/objects/chozospenginebk11/chozospenginebk11.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables75.bcmdl",
	"maps/objects/chozoskypathramp/chozoskypathramp.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/centralunit_fresnel.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/waves_fresnel.bcmdl",
	"cutscenes/0108shipyard/fx/materia_x_commanderhead.bcmdl",
	"cutscenes/0108shipyard/fx/darkness_commander.bcmdl",
	"cutscenes/0112endgame/fx/materia_x_profesor.bcmdl",
	"cutscenes/0112endgame/fx/shipshiny.bcmdl",
	"maps/objects/chozoaqfence02left/chozoaqfence02left.bcmdl",
	"maps/objects/chozoaqfence02right/chozoaqfence02right.bcmdl",
	"cutscenes/0112endgame/fx/expanse_wave_01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_vignette_00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part002_o4_mapmodel33.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o1_lshaft01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_05.bcmdl",
	"maps/objects/chozoskypathx1/chozoskypathx1.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_08.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_09.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/spike_emissive.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables03.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/rays_secframe.bcmdl",
	"cutscenes/0108shipyard/fx/rays_sky.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_decal01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mattepaint01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mattepaint01.bcmdl",
	"maps/objects/chozohangcable06_a/chozohangcable06_a.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables05.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables06.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_px_skybasemodel05.bcmdl",
	"maps/fx/aquabubbles/capsulebubbles02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables29sg_casca067.bcmdl",
	"maps/objects/chozoskypathroofcorner/chozoskypathroofcorner.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables03.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables09.bcmdl",
	"cutscenes/0043emmymetroidnization/fx/voltaic_rays.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables04.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_17.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_23.bcmdl",
	"actors/props/planetzdr_background_plane/models/planetzdr_background_plane.bcmdl",
	"cutscenes/0112endgame/fx/rays_ship.bcmdl",
	"cutscenes/0108shipyard/fx/burn_sky.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o1_lshaft02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_breakables33sg_casca070.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part006_e6_mapmodel03.bcmdl",
	"cutscenes/0112endgame/fx/rays_hand.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables10.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables11.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables12.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables13.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables20.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables21.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables22.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables07.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables08.bcmdl",
	"cutscenes/0012metroidnizationstrongreactionevent/fx/melee.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables01.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o1_lshaft3.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_mapmodel_09.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_21.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_19.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_22.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_18.bcmdl",
	"maps/objects/magmaparticlesuniversal/magmaparticlesuniversal.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/vignette_part001_o5_vignette00.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_12.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part005_x2_breakable_20.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_px_skybasemodel06.bcmdl",
	"maps/objects/chozoaqfence02/chozoaqfence02.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part007_e11_mapmodel07.bcmdl",
	"actors/props/ev_escape_3/models/ev_escape_3.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part003_jp1_reflection.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables018.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables019.bcmdl",
	"maps/levels/c10_samus/s080_shipyard/models/part004_o6_breakables17.bcmdl",
	"cutscenes/0112endgame/fx/postpro_planet.bcmdl",
	"actors/characters/chozowarriorxelite/models/chozowarriorxelite.bcmdl",
	"actors/characters/chozowarriorelite/fx/shieldbreak.bcmdl",
	"actors/characters/emmyshipyard/fx/energy_absortion.bcmdl",
	"actors/props/cut_86_fackeaccpoint/models/cut_86_fackeaccpoint.bcmdl",
	"actors/props/block_pbcolumn/models/block_pbcolumn.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_p_cut0101.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel01.bcmdl",
	"actors/props/skybase/models/skybase.bcmdl",
	"actors/props/capsuleelevatorskybase/models/capsuleelevatorskybase.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_mapmodel04.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel00.bcmdl",
	"actors/characters/samus_facial/models/cut_samushyperfacial.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel05.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_mapmodel03.bcmdl",
	"maps/fx/skybasewindows/skybase_windows.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel07.bcmdl",
	"actors/props/block_pbcolumn/fx/fracture_cristal.bcmdl",
	"actors/props/capsule_commander/models/capsule_commander.bcmdl",
	"actors/characters/chozocommander_wing/models/chozocommander_wing_r.bcmdl",
	"cutscenes/0086commanderorbital/fx/accesspoint.bcmdl",
	"actors/props/block_pbcolumn/fx/incandescent.bcmdl",
	"maps/objects/chozoskybasestatue02/chozoskybasestatue02.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel09.bcmdl",
	"maps/objects/chozoskybasestatue01/chozoskybasestatue01.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_mapmodel05_decals.bcmdl",
	"maps/objects/chozoskybasestatue01b/chozoskybasestatue01b.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel06.bcmdl",
	"actors/props/shipyardrock02/models/shipyardrock02.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel04.bcmdl",
	"cutscenes/100commandershowswings/fx/explosion_wavebeam.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_mapmodel02_sky005_hideable.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel10.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser.bcmdl",
	"actors/weapons/wavebeam/fx/explosion.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_energyabsorb.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_mapmodel02_sky004.bcmdl",
	"actors/props/cut_100_comandercap/models/cut_100_comandercap.bcmdl",
	"actors/props/shipyardrock03/models/shipyardrock03.bcmdl",
	"cutscenes/0108fallofskybase/fx/skybasewind.bcmdl",
	"maps/objects/chozoskycolumn09/chozoskycolumn09.bcmdl",
	"actors/props/shipyardrock01/models/shipyardrock01.bcmdl",
	"actors/props/wplatform_cm_elevator/models/wplatform_cm_elevator.bcmdl",
	"cutscenes/0108fallofskybase/fx/energytosamus_helix.bcmdl",
	"actors/props/shipyardrock07/models/shipyardrock07.bcmdl",
	"cutscenes/0101commanderlosehiswings/fx/explosion_game.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_mapmodel11_sky1.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca1002.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca2002.bcmdl",
	"cutscenes/0108fallofskybase/fx/energytosamus_hand.bcmdl",
	"cutscenes/0108fallofskybase/fx/energytobase.bcmdl",
	"cutscenes/0108fallofskybase/fx/energytosamus.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_p_lshaft01.bcmdl",
	"actors/props/shipyardrock06/models/shipyardrock06.bcmdl",
	"actors/props/commander_elevator/models/commanderelevator.bcmdl",
	"cutscenes/0108fallofskybase/fx/raystobase.bcmdl",
	"actors/props/capsuleelevatorskybase/fx/capsule_sphere.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca1003.bcmdl",
	"cutscenes/0108fallofskybase/fx/skybasetrails.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca1000.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca2001.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/vignette_part004_jp5_00.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_planereflect01.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca2004.bcmdl",
	"actors/props/skybaseclouds_b/models/skybaseclouds_b.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_handrays.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_lshaft03.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/vignette_part001_jp6_00.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca1001.bcmdl",
	"cutscenes/0108fallofskybase/fx/dissolveenergygauntlet.bcmdl",
	"cutscenes/0108fallofskybase/fx/dissolvedots.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca2003.bcmdl",
	"maps/objects/chozoskycolumn06/chozoskycolumn06.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_floorrays.bcmdl",
	"actors/weapons/icemissile/fx/muzzle_3d.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_handrays_disperse.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca1004.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_sg_casca2000.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_lshaft04.bcmdl",
	"cutscenes/100commandershowswings/fx/trails_feet.bcmdl",
	"cutscenes/0101commanderlosehiswings/fx/wavebeam_chargefume.bcmdl",
	"cutscenes/0101commanderlosehiswings/fx/wavebeam_projectile_exterior.bcmdl",
	"cutscenes/100commandershowswings/fx/wind_wings.bcmdl",
	"cutscenes/100commandershowswings/fx/windown.bcmdl",
	"actors/props/skybaseclouds/models/skybaseclouds.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_jp5_planereflect02.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_footrays.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part001_jp6_lshaft02.bcmdl",
	"cutscenes/0086commanderorbital/fx/roomdissolvevertical.bcmdl",
	"cutscenes/0108fallofskybase/fx/wavebeamimpact_cine.bcmdl",
	"cutscenes/0086commanderorbital/fx/roomdissolve.bcmdl",
	"cutscenes/100commandershowswings/fx/rays_floor.bcmdl",
	"cutscenes/100commandershowswings/fx/rays_fast_body.bcmdl",
	"cutscenes/100commandershowswings/fx/ghostdash_trail.bcmdl",
	"cutscenes/100commandershowswings/fx/aura_charge.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_p0_lshaft01.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part004_p0_lshaft02.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_claw_end_seq1.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_claw_seq1.bcmdl",
	"cutscenes/0108fallofskybase/fx/handragetrail.bcmdl",
	"cutscenes/0108fallofskybase/fx/samus_raysabsorb.bcmdl",
	"maps/levels/c10_samus/s090_skybase/models/part002_n1_planereflection.bcmdl",
	"cutscenes/0086commanderorbital/fx/bloomplane.bcmdl",
	"cutscenes/0086commanderorbital/fx/expansivewave.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch.bcmdl",
	"actors/characters/chozocommander/fx/zerolaser.bcmdl",
	"actors/characters/chozocommander/fx/hyperspark_helix.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_statue.bcmdl",
	"actors/weapons/chozocommanderenergyshardsfragment/fx/fragment.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch_charging.bcmdl",
	"actors/weapons/chozocommanderenergyshardssphere/fx/energyshards_init.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch_charging_rays.bcmdl",
	"actors/characters/chozocommander/fx/hyperdash_air.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_floorsmoke.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack02_base.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack02_trail.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack02_end.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack03_base.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack03_trail.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack01_trail.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack03_end.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack01_end.bcmdl",
	"actors/characters/chozocommander/fx/hyperdash_trail.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_zerolaser_attack01_base.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_claw_seq1.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_commander_counter_kistrike.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_claw_seq2_end.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_claw_seq2.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_claw_seq1_end.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_commander_counter_kistrike_end.bcmdl",
	"actors/characters/chozocommander/fx/air_charge_trail.bcmdl",
	"actors/characters/chozocommander/fx/air_charge.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch_warning.bcmdl",
	"actors/characters/chozocommander/fx/hyperspark_cap.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_02.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch_back.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_01.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_02_end.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_03.bcmdl",
	"actors/characters/chozocommander/fx/beamburst.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_01_end.bcmdl",
	"actors/characters/chozocommander/fx/tricombo_03_end.bcmdl",
	"actors/characters/chozocommander/fx/zerolaser_end.bcmdl",
	"actors/characters/chozocommander/fx/aurascratch_back_fast.bcmdl",
	"actors/characters/chozocommander/fx/plane_powerpulse.bcmdl",
	"actors/characters/samus/models/samusgravity.bcmdl",
	"actors/characters/samus/models/samushyper.bcmdl",
	"actors/characters/samus/models/samuspower.bcmdl",
	"actors/characters/samus/models/samusvaria.bcmdl",
	"actors/characters/morphball/fx/morphballicefracture.bcmdl",
	"actors/characters/samus/fx/samusfallicefracture.bcmdl",
	"actors/characters/samus/fx/samusicefracture.bcmdl",
	"actors/characters/samuszerolow/models/samuszerolow.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_3d.bcmdl",
	"actors/props/ice_cube/fx/ice_explosion.bcmdl",
	"system/fx/generic/save_mesh_end.bcmdl",
	"actors/props/samus_deadsuit/models/samus_deadsuit.bcmdl",
	"system/fx/generic/save_mesh.bcmdl",
	"actors/characters/morphball/models/morphballpower.bcmdl",
	"actors/characters/morphball/models/morphballvaria.bcmdl",
	"actors/characters/morphball/models/morphballgravity.bcmdl",
	"actors/weapons/wavebeam/fx/wavebeam_chargedball.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/cannon_energy.bcmdl",
	"actors/characters/samus/fx/cannon_energy_magma.bcmdl",
	"actors/characters/samus/fx/cannon_energy_cave.bcmdl",
	"actors/characters/samus/fx/cannon_energy_lab.bcmdl",
	"actors/characters/samus/fx/cannon_energy_sanc.bcmdl",
	"actors/characters/samus/fx/cannon_energy_emmyshipyard.bcmdl",
	"actors/characters/morphball/models/morphballhyper.bcmdl",
	"actors/weapons/wavebeam/fx/wavebeam_chargedprojectile.bcmdl",
	"actors/weapons/specialburst/fx/spbcone.bcmdl",
	"actors/weapons/powerbeam/fx/diffusion_explosion_game.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_charge.bcmdl",
	"maps/blocks/breakable_block_screwattack/breakable_block_screwattack_respawn.bcmdl",
	"maps/blocks/breakable_block_missile/breakable_block_missile_respawn.bcmdl",
	"maps/blocks/breakable_block_bomb/breakable_block_bomb_respawn.bcmdl",
	"actors/weapons/powerbeam/models/powerbeam_waves.bcmdl",
	"maps/blocks/breakable_block_weight/breakable_block_weight_respawn.bcmdl",
	"maps/blocks/breakable_block_speedbuster/breakable_block_speedbuster_respawn.bcmdl",
	"actors/weapons/specialrocket/fx/specialrocket_projectile.bcmdl",
	"actors/weapons/specialrocket/models/specialburst_rocketprojectile.bcmdl",
	"system/fx/generic/rings_teleport.bcmdl",
	"actors/characters/samus/fx/samus_splashenter.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy_forest.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy_magma.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy_sanc.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy_shipyard.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy.bcmdl",
	"actors/characters/samus/fx/shoulder_energy_emmy_lab.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_cannoncover.bcmdl",
	"actors/weapons/wavebeam/fx/wavebeam_projectile.bcmdl",
	"maps/blocks/breakable_block_powerbeam/breakable_block_powerbeam_respawn.bcmdl",
	"actors/weapons/plasmabeam/fx/plasmabeam_chargedprojectile.bcmdl",
	"actors/props/teleporter/fx/teleport_trails.bcmdl",
	"actors/weapons/specialburst/fx/spbenergy.bcmdl",
	"actors/weapons/specialburst/fx/chargeenergy.bcmdl",
	"actors/weapons/plasmabeam/fx/plasmabeam_projectile.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_3d_chargeenergy.bcmdl",
	"actors/characters/chozowarriorx/fx/dashshot.bcmdl",
	"actors/characters/xparasite/models/xparasite.bcmdl",
	"actors/weapons/powerbeam/models/powerbeamcharged_projectile.bcmdl",
	"actors/weapons/widebeam/models/widebeamcharged_projectile.bcmdl",
	"maps/blocks/breakable_block_supermissile/breakable_block_supermissile_respawn.bcmdl",
	"actors/weapons/specialburst/models/specialburst_ball.bcmdl",
	"actors/characters/samus/fx/rays_trail.bcmdl",
	"actors/characters/samus/fx/shoulder_energy.bcmdl",
	"timelines/x_transformation/fx/whirlwind.bcmdl",
	"timelines/x_transformation/fx/whirlwind_out.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_3d_burst.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_3d_impact.bcmdl",
	"actors/characters/samus/fx/speedbooster_spin.bcmdl",
	"actors/weapons/plasmabeam/fx/explosion_game.bcmdl",
	"actors/weapons/wavebeam/fx/explosion_game.bcmdl",
	"actors/weapons/plasmabeam/fx/auras_chargeprojectile.bcmdl",
	"actors/characters/samus/fx/shinespark_launchcone.bcmdl",
	"actors/characters/samus/fx/absortion_metroidnization.bcmdl",
	"actors/characters/samus/fx/forearm_energy_shipyard.bcmdl",
	"actors/characters/samus/fx/forearm_energy_forest.bcmdl",
	"actors/characters/samus/fx/forearm_energy_lab.bcmdl",
	"actors/characters/samus/fx/forearm_energy_magma.bcmdl",
	"actors/characters/samus/fx/forearm_energy_sanc.bcmdl",
	"actors/characters/samus/fx/forearm_energy.bcmdl",
	"actors/characters/samus/fx/splash_lavaenter.bcmdl",
	"timelines/x_transformation/fx/splash_impact.bcmdl",
	"actors/characters/samus/fx/thigh_energy_forest.bcmdl",
	"actors/characters/samus/fx/thigh_energy_shipyard.bcmdl",
	"actors/characters/samus/fx/thigh_energy.bcmdl",
	"actors/characters/samus/fx/thigh_energy_lab.bcmdl",
	"actors/characters/samus/fx/thigh_energy_magma.bcmdl",
	"actors/characters/samus/fx/thigh_energy_sanc.bcmdl",
	"actors/characters/samus/fx/calf_energy_forest.bcmdl",
	"actors/characters/samus/fx/calf_energy_lab.bcmdl",
	"actors/characters/samus/fx/calf_energy_magma.bcmdl",
	"actors/characters/samus/fx/calf_energy_sanc.bcmdl",
	"actors/characters/samus/fx/calf_energy_shipyard.bcmdl",
	"actors/characters/samus/fx/calf_energy.bcmdl",
	"actors/characters/samus/fx/upperarm_energy_forest.bcmdl",
	"actors/characters/samus/fx/upperarm_energy_magma.bcmdl",
	"actors/characters/samus/fx/upperarm_energy_shipyard.bcmdl",
	"actors/characters/samus/fx/upperarm_energy.bcmdl",
	"actors/characters/samus/fx/upperarm_energy_lab.bcmdl",
	"actors/characters/samus/fx/upperarm_energy_sanc.bcmdl",
	"actors/weapons/hyperbeam/fx/zerolaser.bcmdl",
	"actors/characters/samus/fx/sonar_sphere.bcmdl",
	"actors/characters/samus/fx/hyperspark_helix.bcmdl",
	"actors/characters/samus/fx/absortion_parasite.bcmdl",
	"system/fx/death/frozen_dissolve_internal.bcmdl",
	"system/fx/death/dissolve_dir.bcmdl",
	"system/fx/death/dissolve_internal.bcmdl",
	"system/fx/death/frozen_dissolve_dir.bcmdl",
	"actors/characters/morphball/fx/grab_kraid_vel.bcmdl",
	"actors/characters/samus/fx/speedbooster_cover.bcmdl",
	"actors/weapons/specialrocket/fx/specialrocket_cameradistortion.bcmdl",
	"actors/characters/chozowarriorx/fx/mudfluid04fx.bcmdl",
	"actors/weapons/specialrocket/fx/specialrocket_burstcone.bcmdl",
	"actors/weapons/supermissile/fx/tail.bcmdl",
	"actors/weapons/missile/fx/tail.bcmdl",
	"actors/weapons/icemissile/fx/tail.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy_shipyard.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy_forest.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy_lab.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy_magma.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy_sanc.bcmdl",
	"actors/characters/samus/fx/hand_absortion_emmy.bcmdl",
	"cutscenes/0003firstcomunicationfakeadam/fx/energytube.bcmdl",
	"actors/weapons/widebeam/models/widebeam_projectile.bcmdl",
	"actors/weapons/powerbeam/models/powerbeam_projectile.bcmdl",
	"cutscenes/0003firstcomunicationfakeadam/fx/cannon_smallcover.bcmdl",
	"actors/weapons/specialrocket/fx/cannon_sprcover.bcmdl",
	"actors/characters/samus/fx/cannon_smallcover.bcmdl",
	"actors/weapons/powerbomb/fx/explosion.bcmdl",
	"actors/characters/samus/fx/splash_lavaexit.bcmdl",
	"actors/characters/samus/fx/body_energy_shipyard.bcmdl",
	"actors/characters/samus/fx/body_energy_forest.bcmdl",
	"actors/characters/samus/fx/body_energy_lab.bcmdl",
	"actors/characters/samus/fx/body_energy_magma.bcmdl",
	"actors/characters/samus/fx/body_energy_sanc.bcmdl",
	"actors/characters/samus/fx/body_energy.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_3d_end.bcmdl",
	"system/fx/generic/savecards_general.bcmdl",
	"actors/weapons/supermissile/models/supermissile.bcmdl",
	"actors/weapons/lockonmissile/models/lockonmissile.bcmdl",
	"actors/weapons/powerbomb/fx/implosion.bcmdl",
	"cutscenes/0003firstcomunicationfakeadam/fx/tubelighting.bcmdl",
	"actors/characters/samus/fx/rays_emmywave.bcmdl",
	"actors/weapons/specialrocket/fx/specialrocket_dashshot.bcmdl",
	"actors/weapons/grapplebeam/fx/grapplebeam.bcmdl",
	"actors/weapons/icemissile/models/icemissile.bcmdl",
	"actors/weapons/missile/models/missile.bcmdl",
	"actors/characters/samus/fx/fresnel_light_renderlayer.bcmdl",
	"actors/weapons/powerbomb/fx/powerbomb_purefresnel.bcmdl",
	"cutscenes/0048firstcupowerobtention/fx/cannon_fresnel.bcmdl",
	"actors/characters/morphball/fx/opticalcamo.bcmdl",
	"actors/characters/morphball/fx/powerbomb_fresnel.bcmdl",
	"actors/characters/samus/fx/animfresnel_vertical.bcmdl",
	"actors/characters/samus/fx/handfresnel_emmy.bcmdl",
	"actors/characters/samus/fx/savestation_fresnel.bcmdl",
	"actors/characters/samus/fx/teleport_fresnel.bcmdl",
	"actors/weapons/emmywave/fx/wavebeamimpact.bcmdl",
	"system/fx/sonar/custommaterials/sonarbreakableorganic.bcmdl",
	"timelines/x_transformation/fx/liquishthing.bcmdl",
	"actors/characters/samus/fx/frozenstate.bcmdl",
	"actors/characters/samus/fx/opticalcamo.bcmdl",
	"actors/characters/samus/models/fresnel.bcmdl",
	"actors/characters/samus/fx/damage.bcmdl",
	"system/fx/generic/savecards_basic.bcmdl",
	"actors/characters/morphball/fx/emmywave.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_seq1.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_end_seq1.bcmdl",
	"actors/weapons/hyperbeam/fx/hyperbeam_charge_floorsmoke.bcmdl",
	"actors/characters/samus/fx/uppercut_trail.bcmdl",
	"actors/characters/morphball/models/morphball2spider.bcmdl",
	"actors/characters/samus/models/shieldimmune.bcmdl",
	"actors/characters/samus/models/magnetglove_rays.bcmdl",
	"actors/weapons/lockonmissile/fx/lockon_target.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_samus_counter_kistrike_end.bcmdl",
	"actors/characters/chozocommander/fx/shootinggrab_samus_counter_kistrike.bcmdl",
	"actors/weapons/plasmabeam/fx/plasmabeam_chargefume.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_end_seq2.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_end_seq2_turn.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_seq2.bcmdl",
	"actors/characters/chozocommander/fx/ultimategrab_samus_counter_seq2_turn.bcmdl",
	"actors/characters/samus/fx/speedbooster_start.bcmdl",
	"actors/characters/samus/fx/cannon_fresnel_trail.bcmdl",
	"actors/weapons/powerbomb/fx/burnexplosion.bcmdl",
	"actors/characters/samus/fx/meleefloorslide_scorpius.bcmdl",
	"actors/characters/samus/fx/meleefloorslide.bcmdl",
	"system/fx/generic/savecards_chozocards.bcmdl",
	"actors/weapons/specialrocket/fx/specialrocket_floorsmokes.bcmdl",
	"actors/characters/samus/fx/rays_hand.bcmdl",
	"actors/characters/samus/fx/hyperspark_cap.bcmdl",
	"actors/weapons/bomb/models/bomb.bcmdl",
	"actors/weapons/powerbomb/models/powerbomb.bcmdl",
	"actors/characters/samus/fx/melee.bcmdl",
	"actors/characters/samus/fx/meleerun.bcmdl",
	"actors/weapons/specialburst/models/specialburst_burstprojectile.bcmdl",
	"system/fx/laser/laser.bcmdl",
	"system/fx/laser/laser_foggy_addblend_falloff.bcmdl",
	"actors/characters/emmycave/fx/rays_absortion.bcmdl",
	"actors/weapons/linebomb/models/bomb.bcmdl",
	"system/fx/sonar/models/sonarbreakabletile.bcmdl",
	"actors/weapons/specialburst/models/specialburst_bursttail.bcmdl",
	"actors/props/teleporter/fx/bigtrail_teleport.bcmdl",
	"actors/weapons/hyperbeam/fx/zerolaser_end.bcmdl",
	"actors/props/teleporter/fx/reverse_bigtrail.bcmdl",
	"actors/characters/samus/fx/ocduringchasequad.bcmdl",
	"actors/weapons/lockonmissilemarker/fx/lockon_bloom.bcmdl",
	"actors/weapons/lockonmissilemarker/fx/lockon_marker.bcmdl",
	"actors/characters/samus/fx/death_plane.bcmdl",
	"actors/characters/samus/fx/planesonar.bcmdl",
	"actors/props/teleporter/models/teleporter.bcmdl",
	"maps/blocks/breakable_block_powerbeam/breakable_block_powerbeamdestroy.bcmdl",
	"maps/blocks/breakable_block_missile/breakable_block_missile.bcmdl",
	"maps/blocks/breakable_block_bomb/breakable_block_bomb.bcmdl",
	"maps/blocks/breakable_block_powerbomb/breakable_block_powerbomb.bcmdl",
	"maps/blocks/breakable_block_screwattack/breakable_block_screwattack.bcmdl",
	"maps/blocks/breakable_block_weight/breakable_block_weight.bcmdl",
	"maps/blocks/breakable_block_speedbuster/breakable_block_speedbuster.bcmdl",
	"maps/blocks/breakable_block_powerbeam/breakable_block_powerbeam.bcmdl",
	"actors/props/barelyice/models/barelyice00_weak.bcmdl",
	"actors/props/barelyice/models/barelyice00_strong.bcmdl",
	"maps/blocks/breakable_block_supermissile/breakable_block_supermissile.bcmdl",
	"actors/props/barelyice/models/barelyice01_strong.bcmdl",
	"actors/props/barelyice/models/barelyice01_weak.bcmdl",
	"actors/props/teleporter/models/teleporttunnelparticles.bcmdl",
	"actors/props/barelyice/models/barelyice02_strong.bcmdl",
	"actors/props/barelyice/models/barelyice02_weak.bcmdl",
	"maps/blocks/breakable_block_undefined/breakable_block_undefined.bcmdl",
	"system/fx/custommaterials/immune.bcmdl",
	"system/fx/custommaterials/immune_blink.bcmdl",
	"system/engine/models/damagehard.bcmdl",
	"maps/blocks/breakable_block_baby/breakable_block_baby.bcmdl",
	"system/engine/models/lightsproxy/omni.bcmdl",
	"system/engine/models/lightsproxy/segment.bcmdl",
	"system/engine/models/lightsproxy/spot.bcmdl",
	"system/engine/models/disolve.bcmdl",
	"system/engine/models/damage.bcmdl",
]

@pytest.mark.parametrize("bcmdl_path", ALL_BCMDL_NO_TOC9)
def test_can_parse(dread_file_tree, bcmdl_path):
    dread_file_tree.get_parsed_asset(bcmdl_path)

@pytest.mark.parametrize("bcmdl_path", ALL_BCMDL_NO_TOC9)
def test_compare_dread_all(dread_file_tree, bcmdl_path):
    parse_build_compare_editor(BCMDL, dread_file_tree, bcmdl_path)

def test_change_material(dread_file_tree):
    model = dread_file_tree.get_parsed_asset("actors/props/doorshieldsupermissile/models/doorshieldsupermissile.bcmdl", 
                                             type_hint=Bcmdl)

    # ensure replacing it with the exact length works
    replace = "actors/props/doorshieldsupermissile/models/imats/doorshieldsupermissile_mp_opaque_69.bsmat"
    model.change_material_path("mp_opaque_01", replace)
    encoded = BCMDL.build(model.raw, target_game=dread_file_tree.target_game)

    assert encoded[0x5845:0x58A0] == (b"actors/props/doorshieldsupermissile/models/imats/" 
                                      b"doorshieldsupermissile_mp_opaque_69.bsmat\0")

    # ensure replacing it with a shorter length works
    replace = "actors/props/doorshieldsupermiss/models/imats/doorshieldsupermiss_mp_opaque_01.bsmat"
    model.change_material_path("mp_opaque_01", replace)
    encoded2 = BCMDL.build(model.raw, target_game=dread_file_tree.target_game)

    assert encoded2[0x5845:0x58A0] == (b"actors/props/doorshieldsupermiss/models/imats/"
                                       b"doorshieldsupermiss_mp_opaque_01.bsmat\0\0\0\0\0\0\0")
    
    long_path = "actors/props/doorshieldsupermissile/models/imats/doorshieldsupermissile_mp_opaque_420.bsmat"
    expectation = pytest.raises(ValueError)
    with expectation:
        model.change_material_path("mp_opaque_01", long_path)